/**
 * Real-time changes for elements in the Customizer preview.
 *
 * @since 4.0.0
 */
( function( $ ) {
	'use strict';

	var style = $( '#vantage-color-scheme-css' );

	if ( !style.length ) {
		style = $( 'head' ).append( '<style type="text/css" id="vantage-color-scheme-css" />' )
			.find( '#vantage-color-scheme-css' );
	}

	/**
	 * Site title.
	 *
	 * @since 4.0.0
	 */
	wp.customize( 'blogname', function( value ) {
		value.bind( function( to ) {
			$( '.site-title a' ).text( to );
		} );
	} );

	/**
	 * Background color.
	 *
	 * @since 4.0.0
	 */
	wp.customize( 'header_text_site_title', function( value ) {
		value.bind( function( to ) {
			$( '.site-title' ).css( {
				'clip': 'rect(1px, 1px, 1px, 1px)',
				'position': 'absolute'
			} );
		} );
	} );

	/**
	 * Site tagline.
	 *
	 * @since 4.0.0
	 */
	wp.customize( 'blogdescription', function( value ) {
		value.bind( function( to ) {
			$( '.site-description' ).text( to );
		} );
	} );

	/**
	 * Color schemes.
	 *
	 * @since 4.0.0
	 */
	wp.customize( 'color_scheme', function( value ) {
		value.bind( function( to ) {
			$( 'body' )
				.removeClass( 'theme-aqua theme-blue theme-green theme-orange theme-red theme-custom' )
				.addClass( 'theme-' + to );
		} );
	} );

	/**
	 * Custom color.
	 *
	 * @since 4.0.0
	 */
	wp.customize( 'color_scheme_custom', function( value ) {
		value.bind( function( to ) {

			// Update custom color CSS.
			var style = $( '#custom-theme-colors' ),
				color = style.data( 'color' ),
				css = style.html();

			// Find and replace all instances of the color hex.
			css = css.split( color ).join( to );
			style.html( css ).data( 'color', to );
		} );
	} );

	/**
	 * Background color.
	 *
	 * @since 4.0.0
	 */
	wp.customize( 'background_color', function( value ) {
		value.bind( function( to ) {
			$( '#content.off-canvas-content' ).css( 'background-color', to );
		} );
	} );

	/**
	 * Header background color.
	 *
	 * @since 4.0.0
	 */
	wp.customize( 'header_background_color', function( value ) {
		value.bind( function( to ) {
			$( '#top-bar-primary, #top-bar-primary #menu-primary, .top-bar, .top-bar > ul' ).css( 'background-color', to );
		} );
	} );

	/**
	 * Header text color.
	 *
	 * @since 4.1.0
	 */
	wp.customize( 'header_text_color', function( value ) {
		value.bind( function( to ) {
			$( '.top-bar li.menu-item a' ).css( 'color', to );
		} );
	} );

	/**
	 * Footer color.
	 *
	 * @since 4.0.0
	 */
	wp.customize( 'footer_background_color', function( value ) {
		value.bind( function( to ) {
			$( '.site-footer' ).css( 'background-color', to );
		} );
	} );

} )( jQuery );
