/* General theme scripts */

jQuery( function( $ ) {
	"use strict";

	/**
	 * Typed.js on home page cover.
	 *
	 * @since 4.0.0
	 */
	if ( typeof( typedStrings ) !== 'undefined' ) {
		$( '.home-cover .element' ).typed( {
			strings: typedStrings,
			typeSpeed: 0,
			startDelay: 200,
			backSpeed: 0,
			backDelay: 2500,
			loop: true,
			loopCount: 3,
		} );
	}

	/**
	 * Listing plan selection step.
	 *
	 * @since 4.0.0
	 */
	$( '#listing-plans tr' ).click( function() {
		$( this ).find( 'input[type=radio]' ).prop( 'checked', true );
	} );


	/* listing layout grid or list view toggle buttons */
	$( '#listing-layout button' ).click( function() {
		if ( $( this ).hasClass( 'list' ) ) {
			$( this ).toggleClass( 'disabled' ).toggleClass( 'hollow' );
			$( '.listing-wrap' ).removeClass( 'medium-up-3' ).addClass( 'medium-up-12 list-view' );
			$( '#grid_view' ).removeClass( 'disabled hollow' );
		} else if ( $( this ).hasClass( 'grid' ) ) {
			$( this ).toggleClass( 'disabled' ).toggleClass( 'hollow' );
			$( '.listing-wrap' ).removeClass( 'medium-up-12 list-view' ).addClass( 'medium-up-3' );
			$( '#list_view' ).removeClass( 'disabled hollow' );
		}
	} );


	/**
	 * AJAX listing favorites.
	 *
	 * @since 4.0.0
	 */
	$( document ).on( 'click', 'a.fave-button', function( e ) {

		e.preventDefault();

		// Save the relative location.
		var that = $( this );

		// Pack up the values we need.
		var data = {
			'action': 'vantage_favorites',
			'id': that.attr( 'data-id' ),
			'type': that.attr( 'data-type' ),
			'nonce': that.attr( 'data-nonce' ),
		};

		// Send the ajax request.
		$.ajax( {
			type: 'post',
			dataType: 'json',
			context: that,
			data: data,
			url: AppThemes.ajaxurl,
			beforeSend: function() {
				that.addClass( 'fave-clicked' );
				that.fadeTo( 'fast', 0.5 );
				that.removeAttr( 'href' );
			}
		} ).done( function( r ) {
			that.removeClass( 'fave-clicked' );
			that.fadeTo( 'fast', 1 );
			if ( r.success ) {
				that.attr( 'data-type', r.data.type );
				$( '.fave-text', that ).text( r.data.text );
				$( 'i', that ).attr( 'class', r.data.icon );
				$( 'i', that ).attr( 'title', r.data.text );
			} else {
				alert( r.data );
			}
		} );

		return false;

	} );


	/**
	 * AJAX single listing widget contact owner popup.
	 *
	 * @since 4.0.0
	 */
	if ( $( 'form#va-contact-form' ).length ) {

		/* listing contact owner ajax */
		var $vaForm = $( 'form#va-contact-form' );
		var $vaResp = $( '#va-contact-form-response' );
		var $vaWrap = $( '#va-contact-form-wrap' );
		var $vaSubmit = $( '#va-contact-submit' );

		// Validate the form before posting.
		if ( $vaForm.length ) {
			$vaForm.validate();
		}

		$vaForm.on( 'submit', function( e ) {

			e.preventDefault();

			// Make sure form has passed validation.
			if ( !$( this ).valid() ) {
				return;
			}

			// Pack up the values we need.
			var data = {
				'action': 'vantage_contact_owner',
				'id': $( '#post_ID' ).val(),
				'nonce': $( '#_wpnonce' ).val(),
				'name': $( '#contact_name' ).val(),
				'email': $( '#contact_email' ).val(),
				'message': $( '#contact_message' ).val(),
				'honeypot': $( '#contact_username' ).val()
			};

			// Send the ajax request.
			$.ajax( {
				type: 'post',
				dataType: 'json',
				data: data,
				url: AppThemes.ajaxurl,
				beforeSend: function() {
					$vaResp.html( '' ).removeClass( 'notice error' );
					$vaSubmit.attr( 'disabled', true );
					$( 'i.fa-spinner' ).css( 'display', 'inline-block' );
					$vaWrap.css( 'opacity', '0.5' );
				}
			} ).done( function( r ) {
				$vaSubmit.attr( 'disabled', false );
				$( 'i.fa-spinner' ).css( 'display', 'none' );
				$vaWrap.css( 'opacity', '1' );

				if ( r.success ) {
					$vaWrap.css( 'display', 'none' );
					$vaResp.html( r.data ).removeClass( 'error' ).addClass( 'notice success' );
				}

				// Show the success or error message.
				$vaResp.html( r.data ).addClass( 'notice error' );
			} );

			return false;
		} );
	}


	/**
	 * AJAX delete listing on user edit area.
	 *
	 * @since 4.0.0
	 */
	$( document ).on( 'click', 'a.listing-delete-link', function( e ) {

		e.preventDefault();

		var ask = confirm( vantageSettings.delete_item );

		if ( ask ) {

			// Save the relative location.
			var that = $( this ).closest( 'tr' );

			// Pack up the values we need.
			var data = {
				'action': 'vantage_delete_listing',
				'id': that.attr( 'data-id' ),
				'nonce': that.attr( 'data-nonce' )
			};

			// Send the ajax request.
			$.ajax( {
				type: 'post',
				dataType: 'json',
				data: data,
				url: AppThemes.ajaxurl,
				beforeSend: function() {
					that.css( {
						backgroundColor: '#faa'
					} ).fadeOut( 600 );
				}
			} ).done( function( r ) {
				// There was an error so bring the tr back.
				if ( false == r.success ) {
					that.css( {
						backgroundColor: ''
					} ).fadeIn( 300, function() {
						alert( r.data );
					} );
				}
			} );

			return false;
		}
	} );


	/**
	 * Single listing widget image popup slider.
	 *
	 * @since 4.0.0
	 */
	function revealSlickSlider() {
		"use strict";

		var slider = $( '#listing-carousel' );

		if ( null === slider ) {
			return;
		}

		// Init the slider.
		slider.slick( {
			fade: true,
			dots: true,
		} );

		// Define the links to trigger the modal window.
		$( '.listing-photo-grid a' ).click( function( e ) {
			e.preventDefault();

			// Open the modal window.
			$( '#listingPhotosModal' ).foundation( 'open' );

			// Re-draw position to allow first image to load.
			slider.slick( 'setPosition', 0 );

			// Go to the slide image clicked on.
			slider.slick( 'slickGoTo', parseInt( $( this ).data( 'index' ) ) );
		} );
	}

	revealSlickSlider();

	/**
	 * Show a preview of the uploaded cover photo on the edit-profile.php page.
	 *
	 * @since 4.0.0
	 */
	function authorCoverPhotoPreview( input ) {

		if ( typeof( FileReader ) == 'undefined' ) {
			return;
		}

		if ( input.files && input.files[ 0 ] ) {

			var file = input.files[ 0 ];
			var fileSrc = $( '.image-cover-preview' );
			var fileTxt = $( '#image-cover-filename' );

			// Only show preview of image file types.
			if ( !/\.(jpe?g|png|gif)$/i.test( file.name ) ) {
				alert( vantageSettings.invalid_image_type );
				fileSrc.attr( 'src', vantageSettings.image_placeholder );
				fileTxt.text( '' );
				return;
			}

			var reader = new FileReader();

			reader.onload = function( e ) {
				$( '#image-cover-preview-link' ).show();
				fileSrc.attr( 'src', e.target.result );
				$( '#image-cover-delete-link' ).hide();
				fileTxt.text( file.name + ' (' + humanFileSize( file.size, true ) + ')' );
			}

			reader.readAsDataURL( file );
		}
	}

	$( '#cover_image' ).on( 'change', function() {
		authorCoverPhotoPreview( this );
	} );

	/**
	 * AJAX delete cover image on user edit profile page.
	 *
	 * @since 4.0.0
	 */
	$( document ).on( 'click', '#image-cover-delete-link', function( e ) {

		var ask = confirm( vantageSettings.delete_item );

		if ( ask ) {

			// Save the relative location.
			var that = $( this ).parent();

			// Pack up the values we need.
			var data = {
				'action': 'vantage_delete_cover_image',
				'nonce': that.attr( 'data-nonce' )
			};

			// Send the ajax request.
			$.ajax( {
				type: 'post',
				dataType: 'json',
				data: data,
				url: AppThemes.ajaxurl,
				beforeSend: function() {
					that.fadeOut( 600 );
				}
			} ).done( function( r ) {
				// There was an error so bring the image back.
				if ( false == r.success ) {
					that.fadeIn( 300, function() {
						alert( r.data );
					} );
				}
			} );
		}
		return false;
	} );

} ); // End main function wrapper.
