/**
 * Google Maps custom scripts.
 *
 * @since 4.0.0
 */
jQuery( function( $ ) {
	$( "#search_location" ).on( "onPlaceChange", function( e, data ) {
		var lat = $( 'input[name="lat"]' );
		var lng = $( 'input[name="lng"]' );
		if ( typeof data !== "undefined" ) {
			lat.val( data.lat );
			lng.val( data.lng );
			$( this ).val( data.formatted_address );
		}
	} );
	$( "#search_location" ).on( "onSubmitEmptyPlace", function( e ) {
		$( 'input[name="lat"]' ).val( "" );
		$( 'input[name="lng"]' ).val( "" );
	} );
	/**
	 * Renders a Google Maps canvas on search results, category, single, and archive pages.
	 *
	 * @since 4.0.0
	 */
	function vaMapMainInit() {
		var mapCanvas = document.getElementById( "listings-map" );
		// Exit if no map div is found.
		if ( null === mapCanvas ) {
			return;
		}
		// Create an empty LatLngBounds object.
		var bounds = new google.maps.LatLngBounds();
		// Setup the map object and parameters.
		var map = new google.maps.Map( mapCanvas, {
			scrollwheel: false,
			styles: appthemes_google_map_localize_script.mapOptions.styles,
			fullscreenControl: true,
			rotateControl: true
		} );
		// Remove the pre-loader after the canvas renders.
		map.addListener( "tilesloaded", function() {
			if ( $( "#map-loading" ).length ) {
				$( "#map-loading" ).hide();
			}
		} );
		var markers = [];
		// Loop through all listing results and generate the markers.
		$( ".listing-map-data" ).each( function() {
			var lat = $( this ).data( "lat" );
			var lng = $( this ).data( "lng" );
			var title = $( this ).data( "title" );
			var image = $( this ).data( "image" );
			var address = $( this ).data( "address" );
			var permalink = $( this ).data( "permalink" );
			if ( lat == 0 || lng == 0 ) {
				return true;
			}
			if ( typeof lat == "undefined" || typeof lng == "undefined" ) {
				return true;
			}
			// Build the infoBubble content.
			var contentString = '<a href="' + permalink + '">' + '<img src="' + image + '">' + '<div class="info-window-body">' + "<h3>" + title + "</h3>" + '<span class="info-window-address">' + address + "</span>" + "</div>" + "</a>";
			// Setup the infoBubble object.
			var infoBubble = new InfoBubble( {
				map: map,
				content: contentString,
				padding: 15,
				borderColor: "#F3F3F4",
				borderRadius: 4,
				minHeight: 100,
				maxHeight: 100,
				minWidth: 250,
				maxWidth: 250,
				shadowStyle: 0,
				arrowPosition: 50,
				disableAutoPan: false,
				hideCloseButton: true,
				backgroundClassName: "info-window-wrap"
			} );
			// Setup each marker on the map.
			var marker = new RichMarker( {
				position: new google.maps.LatLng( lat, lng ),
				map: map,
				flat: true,
				draggable: false,
				content: '<span class="fa-stack map-rich-marker">' + '<i class="fa fa-circle fa-stack-2x"></i>' + '<i class="fa fa-university fa-stack-1x fa-inverse"></i>' + "</span>"
			} );
			// Open the infoBubble when the marker is clicked.
			marker.addListener( "click", function() {
				infoBubble.open( map, marker );
			} );
			// Extend the bounds to include each marker's position.
			bounds.extend( marker.position );
			// Add each marker to the array.
			markers.push( marker );
			// Close the infoBubble when clicked anywhere.
			google.maps.event.addListener( map, "click", function() {
				infoBubble.close();
			} );
			// Hack to offset the infoBubble window.
			InfoBubble.prototype.getAnchorHeight_ = function() {
				return 35;
			};
		} );
		// If no results are found, set wide bounds manually.
		if ( bounds.isEmpty() ) {
			var m1 = new google.maps.LatLng( 30.949818772225193, ( -80.61093749999998 ) );
			var m2 = new google.maps.LatLng( 64.57227292219262, 81.81093750000002 );
			bounds = new google.maps.LatLngBounds( m1, m2 );
			// Show message if no results were found.
			map.addListener( "tilesloaded", function() {
				$( "#map-no-results" ).fadeIn();
			} );
		}
		// Fit the map to the newly inclusive bounds.
		map.fitBounds( bounds );
		/**
		 * Adds a radius circle around the searched area.
		 * Note: need to add 'distance' library to at-google-maps-api script.
		 * Eventually add and make an admin option to enable.
		 *
		 * @since 4.x.x
		 */
		// var anchor = new google.maps.LatLng( 37.3382082, -121.88632860000001 );
		//
		// // Add circle overlay and bind to marker
		// var cityCircle = new google.maps.Circle( {
		// 	strokeColor: '#565656',
		// 	strokeOpacity: 0.5,
		// 	strokeWeight: 1,
		// 	fillColor: '#565656',
		// 	fillOpacity: 0.1,
		// 	map: map,
		// 	center: anchor,
		// 	radius: 16093 * 5, // 10 miles in metres
		// } );
		//
		// google.maps.event.addListener( cityCircle, 'mouseover', function() {
		// 	cityCircle.setOptions( {
		// 		fillOpacity: 0,
		// 		strokeOpacity: 0
		// 	} );
		// } )
		//
		// google.maps.event.addListener( cityCircle, 'mouseout', function() {
		// 	cityCircle.setOptions( {
		// 		fillOpacity: 0.35,
		// 		strokeOpacity: 0.8
		// 	} );
		// } );
		// Need to set the zoom level after the bounds executes.
		// Basically used for one marker instances like single listings.
		google.maps.event.addListenerOnce( map, "bounds_changed", function() {
			if ( this.getZoom() > 15 ) {
				this.setZoom( 15 );
			}
		} );
		// Use custom cluster images. Name your images m[1-5].png
		var options = {};
		// Build out the group clustering.
		var markerCluster = new MarkerClusterer( map, markers, options );
	}
	// Trigger the listener.
	google.maps.event.addDomListener( window, "load", vaMapMainInit );
} );

/*!
 * jQuery Address Autocomplete Plugin.
 *
 * Use class 'app-address-field' to apply plugin automatically.
 *
 * @version 1.0.0
 * @author  AppThemes
 */
( function( $ ) {
	$.fn.appAddressAutocomplete = function() {
		// Requires an api key to run.
		if ( false == appthemes_google_map_localize_script.hasApiKey ) {
			return this;
		}
		return this.each( function() {
			var input = this,
				name = $( input ).attr( "name" ),
				api = new google.maps.places.Autocomplete( input, {
					types: []
				} );
			var cont = $( '<input type="hidden" name="' + name + '_geo_data" value=""/>' );
			$( input ).after( cont );

			function onPlaceChange() {
				var place = api.getPlace();
				if ( !place.geometry && "" !== $.trim( $( input ).val() ) ) {
					window.alert( appthemes_google_map_localize_script.no_geocode );
					cont.val( "" );
					$( input ).trigger( "onPlaceChange" );
					return;
				}
				var data = {
					lat: place.geometry.location.lat(),
					lng: place.geometry.location.lng(),
					formatted_address: place.formatted_address,
					place_id: place.place_id,
					address_components: place.address_components
				};
				$( input ).val( place.formatted_address );
				$( input ).trigger( "onPlaceChange", [ data ] );
				cont.val( decodeURIComponent( $.param( data ) ) );
			}
			// Trigger if location field value changes.
			api.addListener( "place_changed", onPlaceChange );
			// Don't submit form when enter key (13) is pressed to select location.
			$( input ).keydown( function( e ) {
				if ( e.which == 13 && $( ".pac-container:visible" ).length ) {
					e.preventDefault();
				}
			} );
			// Remove the lat/lng values if the location field is empty.
			$( "form" ).submit( function( e ) {
				// Get the location value and trim it.
				var loc = $.trim( $( input ).val() );
				// Check if empty of not
				if ( loc === "" ) {
					$( input ).trigger( "onSubmitEmptyPlace" );
					cont.val( "" );
				}
			} );
		} );
	};
} )( jQuery );

jQuery( document ).ready( function( $ ) {
	$( ".app-address-field" ).appAddressAutocomplete();
} );

/**
 * General helper scripts.
 *
 * @since 4.0.0
 */
/**
 * Convert bytes into readable human file sizes.
 *
 * @param int bytes Raw number we want to convert.
 *
 * @since 4.0.0
 */
function humanFileSize( bytes ) {
	var thresh = 1e3;
	if ( Math.abs( bytes ) < thresh ) {
		return bytes + " B";
	}
	var units = [ "KB", "MB", "GB", "TB", "PB", "EB", "ZB", "YB" ];
	var u = -1;
	do {
		bytes /= thresh;
		++u;
	} while ( Math.abs( bytes ) >= thresh && u < units.length - 1 );
	return bytes.toFixed( 0 ) + " " + units[ u ];
}

/* Kick-off Foundation */
jQuery( document ).foundation();

/* General theme scripts */
jQuery( function( $ ) {
	"use strict";
	/**
	 * Typed.js on home page cover.
	 *
	 * @since 4.0.0
	 */
	if ( typeof typedStrings !== "undefined" ) {
		$( ".home-cover .element" ).typed( {
			strings: typedStrings,
			typeSpeed: 0,
			startDelay: 200,
			backSpeed: 0,
			backDelay: 2500,
			loop: true,
			loopCount: 3
		} );
	}
	/**
	 * Listing plan selection step.
	 *
	 * @since 4.0.0
	 */
	$( "#listing-plans tr" ).click( function() {
		$( this ).find( "input[type=radio]" ).prop( "checked", true );
	} );
	/* listing layout grid or list view toggle buttons */
	$( "#listing-layout button" ).click( function() {
		if ( $( this ).hasClass( "list" ) ) {
			$( this ).toggleClass( "disabled" ).toggleClass( "hollow" );
			$( ".listing-wrap" ).removeClass( "medium-up-3" ).addClass( "medium-up-12 list-view" );
			$( "#grid_view" ).removeClass( "disabled hollow" );
		} else if ( $( this ).hasClass( "grid" ) ) {
			$( this ).toggleClass( "disabled" ).toggleClass( "hollow" );
			$( ".listing-wrap" ).removeClass( "medium-up-12 list-view" ).addClass( "medium-up-3" );
			$( "#list_view" ).removeClass( "disabled hollow" );
		}
	} );
	/**
	 * AJAX listing favorites.
	 *
	 * @since 4.0.0
	 */
	$( document ).on( "click", "a.fave-button", function( e ) {
		e.preventDefault();
		// Save the relative location.
		var that = $( this );
		// Pack up the values we need.
		var data = {
			action: "vantage_favorites",
			id: that.attr( "data-id" ),
			type: that.attr( "data-type" ),
			nonce: that.attr( "data-nonce" )
		};
		// Send the ajax request.
		$.ajax( {
			type: "post",
			dataType: "json",
			context: that,
			data: data,
			url: AppThemes.ajaxurl,
			beforeSend: function() {
				that.addClass( "fave-clicked" );
				that.fadeTo( "fast", .5 );
				that.removeAttr( "href" );
			}
		} ).done( function( r ) {
			that.removeClass( "fave-clicked" );
			that.fadeTo( "fast", 1 );
			if ( r.success ) {
				that.attr( "data-type", r.data.type );
				$( ".fave-text", that ).text( r.data.text );
				$( "i", that ).attr( "class", r.data.icon );
				$( "i", that ).attr( "title", r.data.text );
			} else {
				alert( r.data );
			}
		} );
		return false;
	} );
	/**
	 * AJAX single listing widget contact owner popup.
	 *
	 * @since 4.0.0
	 */
	if ( $( "form#va-contact-form" ).length ) {
		/* listing contact owner ajax */
		var $vaForm = $( "form#va-contact-form" );
		var $vaResp = $( "#va-contact-form-response" );
		var $vaWrap = $( "#va-contact-form-wrap" );
		var $vaSubmit = $( "#va-contact-submit" );
		// Validate the form before posting.
		if ( $vaForm.length ) {
			$vaForm.validate();
		}
		$vaForm.on( "submit", function( e ) {
			e.preventDefault();
			// Make sure form has passed validation.
			if ( !$( this ).valid() ) {
				return;
			}
			// Pack up the values we need.
			var data = {
				action: "vantage_contact_owner",
				id: $( "#post_ID" ).val(),
				nonce: $( "#_wpnonce" ).val(),
				name: $( "#contact_name" ).val(),
				email: $( "#contact_email" ).val(),
				message: $( "#contact_message" ).val(),
				honeypot: $( "#contact_username" ).val()
			};
			// Send the ajax request.
			$.ajax( {
				type: "post",
				dataType: "json",
				data: data,
				url: AppThemes.ajaxurl,
				beforeSend: function() {
					$vaResp.html( "" ).removeClass( "notice error" );
					$vaSubmit.attr( "disabled", true );
					$( "i.fa-spinner" ).css( "display", "inline-block" );
					$vaWrap.css( "opacity", "0.5" );
				}
			} ).done( function( r ) {
				$vaSubmit.attr( "disabled", false );
				$( "i.fa-spinner" ).css( "display", "none" );
				$vaWrap.css( "opacity", "1" );
				if ( r.success ) {
					$vaWrap.css( "display", "none" );
					$vaResp.html( r.data ).removeClass( "error" ).addClass( "notice success" );
				}
				// Show the success or error message.
				$vaResp.html( r.data ).addClass( "notice error" );
			} );
			return false;
		} );
	}
	/**
	 * AJAX delete listing on user edit area.
	 *
	 * @since 4.0.0
	 */
	$( document ).on( "click", "a.listing-delete-link", function( e ) {
		e.preventDefault();
		var ask = confirm( vantageSettings.delete_item );
		if ( ask ) {
			// Save the relative location.
			var that = $( this ).closest( "tr" );
			// Pack up the values we need.
			var data = {
				action: "vantage_delete_listing",
				id: that.attr( "data-id" ),
				nonce: that.attr( "data-nonce" )
			};
			// Send the ajax request.
			$.ajax( {
				type: "post",
				dataType: "json",
				data: data,
				url: AppThemes.ajaxurl,
				beforeSend: function() {
					that.css( {
						backgroundColor: "#faa"
					} ).fadeOut( 600 );
				}
			} ).done( function( r ) {
				// There was an error so bring the tr back.
				if ( false == r.success ) {
					that.css( {
						backgroundColor: ""
					} ).fadeIn( 300, function() {
						alert( r.data );
					} );
				}
			} );
			return false;
		}
	} );
	/**
	 * Single listing widget image popup slider.
	 *
	 * @since 4.0.0
	 */
	function revealSlickSlider() {
		"use strict";
		var slider = $( "#listing-carousel" );
		if ( null === slider ) {
			return;
		}
		// Init the slider.
		slider.slick( {
			fade: true,
			dots: true
		} );
		// Define the links to trigger the modal window.
		$( ".listing-photo-grid a" ).click( function( e ) {
			e.preventDefault();
			// Open the modal window.
			$( "#listingPhotosModal" ).foundation( "open" );
			// Re-draw position to allow first image to load.
			slider.slick( "setPosition", 0 );
			// Go to the slide image clicked on.
			slider.slick( "slickGoTo", parseInt( $( this ).data( "index" ) ) );
		} );
	}
	revealSlickSlider();
	/**
	 * Show a preview of the uploaded cover photo on the edit-profile.php page.
	 *
	 * @since 4.0.0
	 */
	function authorCoverPhotoPreview( input ) {
		if ( typeof FileReader == "undefined" ) {
			return;
		}
		if ( input.files && input.files[ 0 ] ) {
			var file = input.files[ 0 ];
			var fileSrc = $( ".image-cover-preview" );
			var fileTxt = $( "#image-cover-filename" );
			// Only show preview of image file types.
			if ( !/\.(jpe?g|png|gif)$/i.test( file.name ) ) {
				alert( vantageSettings.invalid_image_type );
				fileSrc.attr( "src", vantageSettings.image_placeholder );
				fileTxt.text( "" );
				return;
			}
			var reader = new FileReader();
			reader.onload = function( e ) {
				$( "#image-cover-preview-link" ).show();
				fileSrc.attr( "src", e.target.result );
				$( "#image-cover-delete-link" ).hide();
				fileTxt.text( file.name + " (" + humanFileSize( file.size, true ) + ")" );
			};
			reader.readAsDataURL( file );
		}
	}
	$( "#cover_image" ).on( "change", function() {
		authorCoverPhotoPreview( this );
	} );
	/**
	 * AJAX delete cover image on user edit profile page.
	 *
	 * @since 4.0.0
	 */
	$( document ).on( "click", "#image-cover-delete-link", function( e ) {
		var ask = confirm( vantageSettings.delete_item );
		if ( ask ) {
			// Save the relative location.
			var that = $( this ).parent();
			// Pack up the values we need.
			var data = {
				action: "vantage_delete_cover_image",
				nonce: that.attr( "data-nonce" )
			};
			// Send the ajax request.
			$.ajax( {
				type: "post",
				dataType: "json",
				data: data,
				url: AppThemes.ajaxurl,
				beforeSend: function() {
					that.fadeOut( 600 );
				}
			} ).done( function( r ) {
				// There was an error so bring the image back.
				if ( false == r.success ) {
					that.fadeIn( 300, function() {
						alert( r.data );
					} );
				}
			} );
		}
		return false;
	} );
} );
