<?php
/**
 * The author page template file
 *
 * @package Vantage\Templates
 * @since 4.0.0
 */

$author        = get_user_by( 'id', get_query_var( 'author' ) );

$first         = get_the_author_meta( 'first_name', $author->ID );
$display       = $first ? $first : get_the_author_meta( 'display_name', $author->ID );

$post_count    = count_user_posts( $author->ID );
$listing_count = count_user_posts( $author->ID, VA_LISTING_PTYPE );
?>

<div id="author-<?php esc_attr_e( $author->ID ); ?>" class="author-page">

	<section <?php echo apply_filters( 'va_background_cover', 'hero-author entry-cover text-center', array( 'size' => 'full' ) ); ?>></section>

	<div id="primary" class="content-area">

		<main id="main" class="site-main" role="main">

			<div class="row">

				<div class="medium-3 columns text-center">

					<div class="post-user post-user-profile">

						<?php echo get_avatar( $author->ID, 300 ); ?>
						<h4 class="user-display-name"><?php echo esc_attr( $display ); ?></h4>

					</div>

				</div> <!-- .columns -->

				<div class="medium-9 columns">

					<div class="stats-row stats-user-profile">

						<div class="stat-item">
							<h2 class="value"><?php echo number_format_i18n( $post_count ); ?></h2>
							<h5 class="name"><?php printf( _n( 'Post', 'Posts', $post_count, APP_TD ) ); ?></h5>
						</div>
						<div class="stat-item">
							<h2 class="value"><?php echo number_format_i18n( $listing_count ); ?></h2>
							<h5 class="name"><?php printf( _n( 'Listing', 'Listings', $listing_count, APP_TD ) ); ?></h5>
						</div>

					</div> <!-- .stats-row -->

					<?php
					// Get any social networks that have values.
					if ( array_filter( $social_networks = va_get_available_user_networks( true ) ) ) :
					?>
					<ul class="social-icons">
						<?php foreach ( $social_networks as $social => $username ) { ?>
						<li class="<?php echo esc_attr( $social ); ?>">
							<a class="fa-icon fa-<?php esc_attr_e( $social ); ?>" href="<?php echo va_get_social_account_url( $social, $username ); ?>" title="<?php echo esc_attr( va_get_social_network_title( $social ) ); ?>" target="_blank"></a>
						</li>
						<?php } ?>
					</ul>
				<?php endif; ?>

					<?php if ( $authordesc = get_the_author_meta( 'description', $author->ID ) ) : ?>
						<div class="content-wrap author-desc-wrap m-t-3">
							<div class="content-inner">
								<h3 class="widget-title"><?php _e( 'About Me', APP_TD ); ?></h3>
								<?php echo wpautop( $authordesc ); ?>
							</div>
						</div>
					<?php endif; ?>

					<?php
					/**
					 * Fires after the author description.
					 *
					 * @since 4.0.0
					 *
					 * @param array $author The author array.
					 */
					do_action( 'va_author_profile_after_about', $author );
					?>

				</div> <!-- .columns -->

			</div> <!-- .row -->

			<?php
			/**
			 * Fires after the author profile.
			 *
			 * @since 4.0.0
			 *
			 * @param array $author The author array.
			 */
			do_action( 'va_author_profile_after', $author );
			?>

		</main>

	</div> <!-- #primary -->

</div> <!-- #author-id -->
