<?php
/**
 * Theme functions file
 *
 * DO NOT MODIFY THIS FILE. Make a child theme instead: http://codex.wordpress.org/Child_Themes
 *
 * @package Vantage
 *
 * @since 4.0.0
 */


// Constants.
define( 'VA_VERSION', '4.1.1' );

define( 'VA_META_KEY_PREFIX', 'va_' );

define( 'VA_LISTING_PTYPE', 'listing' );
define( 'VA_LISTING_CATEGORY', 'listing_category' );
define( 'VA_LISTING_TAG', 'listing_tag' );
define( 'VA_LISTING_FAVORITES', 'va_favorites' );

define( 'VA_ITEM_FEATURED_HOME', VA_LISTING_PTYPE . '-featured-home' );
define( 'VA_ITEM_FEATURED_CAT', VA_LISTING_PTYPE . '-featured-cat' );

define( 'VA_ATTACHMENT_FILE', 'file' );
define( 'VA_ATTACHMENT_GALLERY', 'gallery' );

// TODO: remove APPTHEMES_PRICE_PLAN_PTYPE constant and use listing type related.
define( 'APPTHEMES_PRICE_PLAN_PTYPE', 'listing-pricing-plan' );

define( 'APP_TD', 'vantage' );

// Listing Core Constants.
if ( ! defined( 'APP_LISTING_DIR_NAME' ) ) {
	define( 'APP_LISTING_DIR_NAME', 'core' );
}

if ( ! defined( 'APP_LISTING_DIR' ) ) {
	define( 'APP_LISTING_DIR', dirname( __FILE__ ) . '/includes/' . APP_LISTING_DIR_NAME );
}

if ( ! defined( 'APP_LISTING_URI' ) ) {
	define( 'APP_LISTING_URI', get_template_directory_uri() . '/includes/' . APP_LISTING_DIR_NAME );
}

// Listings type constants.
define( 'VA_LISTINGS_DIR', dirname( __FILE__ ) . '/includes/listings' );
define( 'VA_LISTINGS_URI', get_template_directory_uri() . '/includes/listings' );

global $va_options;

// Framework.
require dirname( __FILE__ ) . '/framework/load.php';
require dirname( __FILE__ ) . '/theme-framework/load.php';

require_once APP_FRAMEWORK_DIR . '/load-p2p.php';

add_theme_support( 'app-listing', array( 'dirname' => 'core' ) );

$load_files = array(
	'class-autoload.php',
	'ajax-actions.php',
	'helpers.php',
	'payments/load.php',
	'addons/load.php',
	'recurring/recurring-payments.php',
	'checkout/load.php',
	//'search-index/load.php',
	'custom-forms/form-builder.php',
	'core/load.php',
	'listings/load.php',
	'maps/load.php',
	'options.php',
	'author.php',
	'categories.php',
	'class-ajax.php',
	'class-refine-search.php',
	'class-search.php',
	'class-shortcodes.php',
	'structured-data/class-structured-data.php',
	'class-structured-data.php',
	'class-widget.php',
	'comments.php',
	'core.php',
	'custom-forms.php',
	'custom-comment-type-helper.php',
	'custom-post-type-helper.php',
	'customizer/class-customizer.php',
	'dashboard.php',
	'deprecated.php',
	'emails.php',
	'favorites.php',
	'delete-listing.php',
	'featured.php',
	'files.php',
	'images.php',
	'listing-activate.php',
	'listing-contact-owner.php',
	'listing-purchase.php',
	'listing-status.php',
	'locale.php',
	'menu-walkers.php',
	'menus.php',
	'sidebars.php',
	'template-tags.php',
	'users.php',
	'social.php',
	'theme-support.php',
	'enqueue-scripts.php',
	'integrations/amp/class-amp.php',
	'integrations/critic/class-critic.php',
	'integrations/wordpress-seo/class-wordpress-seo.php',
	'integrations/foundation-framework/class-foundation-framework.php',
	'integrations/woocommerce/class-woocommerce.php',
	'views/class-authentication.php',
	'views/class-edit-profile.php',
	'views/class-listing-archive.php',
	'views/class-listing-search.php',
	'views/class-listing-single.php',
	'views/class-user-dashboard.php',
);
appthemes_load_files( dirname( __FILE__ ) . '/includes/', $load_files );

$load_classes = array(
	'VA_Login_Redirect_View',
	'VA_Edit_User_Profile',
	'VA_Listing_Archive_View',
	'VA_Listing_Search_View',
	'VA_Listing_Single_View',
	'VA_User_Dashboard_View',
	'APP_Google_Maps',
);
appthemes_add_instance( $load_classes );

global $vantage;
$vantage = new stdClass();

$builder  = new VA_Business_Listing_Builder();
$director = new APP_Listing_Director();

$vantage->{VA_LISTING_PTYPE} = $director->build( VA_LISTING_PTYPE, $builder );

global $va_locale;
$va_locale = new VA_Locale;

APP_Mail_From::init();
APP_Google_Geocoding::init();

// Admin only.
if ( is_admin() ) {
	require_once( APP_FRAMEWORK_DIR . '/admin/importer.php' );

	$load_files = array(
		'admin.php',
		'listing-list.php',
		'class-admin-dashboard.php',
		'class-admin-importer.php',
		'class-admin-settings.php',
		'class-admin-setup.php',
		'class-admin-taxonomies.php',
		'users.php',
		'addons-mp/load.php',
		'metaboxes/class-metabox-listing-moderation.php',
	);
	appthemes_load_files( dirname( __FILE__ ) . '/includes/admin/', $load_files );

	$load_classes = array(
		'APP_System_Info',
		'VA_Admin_Settings' => array( $va_options ),
		'VA_Admin_Setup'    => array( $va_options ),
		'VA_Metabox_Listing_Moderation',
	);
	appthemes_add_instance( $load_classes );
}

/**
 * Include all the widgets we need.
 *
 * @since   4.0.0
 */
function va_widgets_init() {

	VA_Autoload::register( 'VA_', dirname( __FILE__ ) . '/includes/widgets' );

	$widgets = array(
		'VA_Widget_Listing_Content',
		'VA_Widget_Listing_Author',
		'VA_Widget_Listing_Author_Stats',
		'VA_Widget_Listing_Map',
		'VA_Widget_Listing_Comments',
		'VA_Widget_Listing_Reveal_Gallery',
		//'VA_Widget_Listing_Slider_Gallery',
		'VA_Widget_Listing_Latest',
		'VA_Widget_Listing_Featured',
		'VA_Widget_Post_Latest',
		'VA_Widget_Listing_Custom_Fields',
		'VA_Widget_Listing_Refine_Search',
		'VA_Widget_Callout_Box',
	);

	appthemes_add_instance( $widgets );
}
va_widgets_init();

/**
 * Remove the wp-admin session expired login modal window since our custom
 * templates aren't able to fit nicely inside them.
 *
 * @since 4.0.0
 *
 * @todo Find a way to not use our custom login template when the session expires.
 */
remove_action( 'admin_enqueue_scripts', 'wp_auth_check_load' );

/**
 * Kick everything off.
 */
appthemes_init();
