<?php
/**
 * Handles importing listings.
 *
 * @since 4.0.0
 *
 */

 /**
  * VA_Admin_Importer class.
  * Was previously named
  *
  * @since 4.0.0
  */
class VA_Admin_Importer extends APP_Importer {

	function setup() {

		$this->textdomain = APP_TD;

		$post_type_obj = get_post_type_object( $this->post_type );

		$this->args = array(
			'page_title'  => __( 'Import ' . $post_type_obj->labels->name, APP_TD ),
			'menu_title'  => __( 'Import ' . $post_type_obj->labels->name, APP_TD ),
			'page_slug'   => 'app-importer-' . $post_type_obj->name,
			'parent'      => 'app-dashboard',
			'screen_icon' => 'tools',
		);

		add_filter( 'appthemes_importer_import_row_data', array( $this, 'prevent_duplicate' ), 10, 1 );
		add_action( 'appthemes_importer_import_row_after', array( $this, 'import_row_after' ), 10, 2 );
		add_action( 'appthemes_after_import_upload_row', array( $this, '_import_options' ) );

		if ( isset( $_GET['sample'] ) ) {
			$this->_generate_sample();
		}
	}

	public function _import_options() {

		if ( empty( $_GET['page'] ) || $_GET['page'] !== 'app-importer-' . $this->post_type  ) {
			return;
		}

		$download_url = add_query_arg( 'sample', 1 );
		$download_url = wp_nonce_url( $download_url, 'get-sample-file' );
		?>
			<tr>
				<th>
					<label><?php _e( 'Template', APP_TD ); ?></label>
				</th>
				<td>
					<?php echo sprintf( __( 'Download the  <a href="%s">sample file</a> (.csv) and open it in a spreadsheet program to get started.', APP_TD ), $download_url ); ?>
				</td>
			</tr>
			<tr>
				<th>
					<label><?php _e( 'Geocoding', APP_TD ); ?></label>
				</th>
				<td>
					<fieldset>
						<label><input type="checkbox" name="geocode_imported" value="1" /><?php _e( 'Geocode listings on import', APP_TD ); ?></label>
					</fieldset>
					<p class="description"><?php _e( 'Limit of 2,500 requests per 24 hour period (unless you have a premium Google Maps API account).', APP_TD ); ?></p>
				</td>
			</tr>
		<?php
	}

	/**
	 * Prevents duplicate entries while importing.
	 *
	 * @param array $data
	 *
	 * @return array|bool
	 */
	public function prevent_duplicate( $data ) {

		if ( ! empty( $data['post_meta']['va_id'] ) ) {

			if ( va_get_listing_by_ref( $data['post_meta']['va_id'] ) ) {
				return false;
			}
		}

		return $data;
	}

	public function import_row_after( $listing_id, $row ) {

		if ( $this->post_type != get_post_type( $listing_id ) ) {
			return;
		}

		if ( empty( $_POST['geocode_imported'] ) || empty( $row['address'] ) ) {
			return;
		}

		if ( ! empty( $row['lat'] ) && ! empty( $row['lng'] ) ) {
			return;
		}

		APP_Google_Geocoding::insert_geo_data( $listing_id, $row['address'] );
	}

	protected function _generate_sample() {

		check_admin_referer( 'get-sample-file' );

		$sample_data = $this->get_sample_data();

		$keys = array_keys( $sample_data );
		$vals = array_values( $sample_data );

		$string = $this->array2csv( $keys ) . $this->array2csv( $vals );

		header( "Content-type: application/x-msdownload", true, 200 );
		header( "Content-Disposition: attachment; filename='listings.csv'" );
		header( "Pragma: no-cache" );
		header( "Expires: 0" );
		echo $string;
		exit();
	}

	public function get_sample_data() {

		$img_url = get_template_directory_uri() . '/assets/images/admin/install/';

		$images = array(
			$img_url . 'sprinkles-cupcakes-cover.jpg',
			$img_url . 'sprinkles-cupcakes-view.jpg',
			$img_url . 'sprinkles-cupcakes-counter.jpg',
			$img_url . 'sprinkles-cupcakes-close-up.jpg',
		);

		$featured = $images[0];
		$images   = implode( ', ', $images );

		$data = array(
			'id'                  => va_generate_id(),
			'title'               => 'Sprinkles Cupcakes',
			'description'         => '<p>We are a Beverly Hills, California-based cupcake bakery chain established in 2005.</p> <p>Sprinkles is considered one of the first cupcake bakeries. We offers cupcakes, ice cream, plus a selection for dogs. See our daily menu with descriptions of each flavor, and online ordering for pick-up or local delivery.</p> <p>Choose from our rotating daily menu of gourmet cupcake flavors like banana, black and white, chai latte, cuban coffee, dark chocolate, red velvet, strawberry, vanilla, and more.</p> <p>https://www.youtube.com/watch?v=dZSHd6trOPo</p>',
			VA_LISTING_CATEGORY   => 'Dessert',
			VA_LISTING_TAG        => 'Cupcakes, Bakeries, Desserts',
			'author'              => '',
			'date'                => '',
			'slug'                => '',
			'status'              => 'publish',
			'attachments'         => $images,
			'featured_attachment' => $featured,
			'lat'                 => '34.069577',
			'lng'                 => '-118.406061',
			'address'             => '9635 S Santa Monica Blvd, Beverly Hills, CA 90210',
			'formatted_address'   => '9635 S Santa Monica Blvd, Beverly Hills, CA 90210, USA',
			'place_id'            => 'ChIJz_1aFQi8woARGfGWu6xy0gg',
			'street_number'       => '9635',
			'street'              => 'South Santa Monica Boulevard',
			'city'                => 'Beverly Hills',
			'state_short'         => 'CA',
			'state_long'          => 'California',
			'postal_code'         => '90210',
			'country_short'       => 'US',
			'country_long'        => 'United States',
			'phone'               => '(310) 274-8765',
			'website'             => 'http://sprinkles.com/locations/california/beverly-hills/cupcakes',
			'email'               => '',
			'twitter'             => 'sprinkles',
			'facebook'            => 'sprinkles',
			'google-plus'         => '+sprinkles',
			'instagram'           => 'sprinklescupcakes',
			'youtube'             => 'sprinkles',
			'pinterest'           => '',
			'listing_duration'    => 30,
		);

		return $data;
	}

	/**
	 * Formats a line (passed as a fields  array) as CSV and returns the CSV as a string.
	 */
	protected function array2csv( array &$fields, $delimiter = ',', $enclosure = '"', $encloseAll = false ) {
		$delimiter_esc	 = preg_quote( $delimiter, '/' );
		$enclosure_esc	 = preg_quote( $enclosure, '/' );

		$output = array();
		foreach ( $fields as $field ) {
			// Enclose fields containing $delimiter, $enclosure or whitespace
			if ( $encloseAll || preg_match( "/(?:${delimiter_esc}|${enclosure_esc}|\s)/", $field ) ) {
				$output[] = $enclosure . str_replace( $enclosure, $enclosure . $enclosure, $field ) . $enclosure;
			} else {
				$output[] = $field;
			}
		}

		return implode( $delimiter, $output ). "\n";
	}

}

/**
 * [va_csv_importer description]
 *
 * @todo review and put in class above? Change hook for sure.
 *
 * @since   1.x.x
 */
function va_csv_importer() {
	$fields = array(
		'title'       => 'post_title',
		'description' => 'post_content',
		'author'      => 'post_author',
		'date'        => 'post_date',
		'slug'        => 'post_name',
		'status'      => 'post_status',
	);

	$args = array(
		'taxonomies'    => array( VA_LISTING_CATEGORY, VA_LISTING_TAG ),
		'custom_fields' => array(
			'id'                => 'va_id',
			'address'           => array(),
			'formatted_address' => 'geo_formatted_address',
			'place_id'          => 'geo_place_id',
			'street_number'     => 'geo_street_number',
			'street'            => 'geo_street',
			'city'              => 'geo_city',
			'state_short'       => 'geo_state_short',
			'state_long'        => 'geo_state_long',
			'postal_code'       => 'geo_postal_code',
			'country_short'     => 'geo_country_short',
			'country_long'      => 'geo_country_long',
			'phone'             => array(),
			'website'           => array(),
			'email'             => array(),
			'listing_duration'  => array( 'internal_key' => '_listing_duration', 'default' => 0 ),
		),
		'geodata'       => true,
		'attachments'   => true,
	);

	foreach ( va_get_allowed_listing_networks() as $social_network ) {
		$args['custom_fields'][ $social_network ] = array();
	}

	$args = apply_filters( 'va_csv_importer_args', $args );

	appthemes_add_instance( 'VA_Admin_Importer', array( VA_LISTING_PTYPE, $fields, $args ) );
}
add_action( 'wp_loaded', 'va_csv_importer' );
