<?php
/**
 * Admin setup page setup.
 *
 * @package Framework\Setup
 */

/**
 * Setup the admin pages class.
 */
class VA_Admin_Setup extends APP_Tabs_Page {

	/**
	 * Constructor
	 */
	public function setup() {

		new APP_Progress_Ajax_Upgrade_View( 'upgrade_theme', 'vantage_version' );
		new APP_Progress_Ajax_Upgrade_View( 'install_theme_samples', 'vantage_version' );

		add_action( 'appthemes_register_checkout_steps', array( $this, 'setup_upgrade' ) );

		$this->textdomain = APP_TD;

		$this->args = array(
			'page_title'            => __( 'Vantage Setup', APP_TD ),
			'menu_title'            => __( 'Setup Guide', APP_TD ),
			'page_slug'             => 'app-setup',
			'parent'                => 'app-dashboard',
			'screen_icon'           => 'options-general',
			'admin_action_priority' => 40,
		);

	}

	/**
	 *
	 * @param APP_Dynamic_Checkout $checkout
	 */
	public function setup_upgrade( APP_Dynamic_Checkout $checkout ) {
		$checkout_type = $checkout->get_checkout_type();

		if ( ! in_array( $checkout_type, array( 'upgrade_theme', 'install_theme_samples' ) ) ) {
			return;
		}

		require_once ( dirname( __FILE__ ) . '/upgrade/install.php' );
		require_once ( dirname( __FILE__ ) . '/upgrade/upgrade.php' );

		$old_version = $checkout->get_data( 'old_version' );
		$since       = '';

		if ( $old_version ) {
			$since = '4.0.0';
		}

		switch ( $checkout_type ) {
			case 'upgrade_theme':

				// First theme installation or upgrade from legacy version.
				new VA_Install_Menus(         'install_menus',         array( 'register_to' => $checkout_type, 'since' => $since, 'title' => 'Setup Menus',         'icon' => 'dashicons-before dashicons-menu' ) );
				new VA_Install_Widgets(       'install_widgets',       array( 'register_to' => $checkout_type, 'since' => $since, 'title' => 'Setup Widgets',       'icon' => 'dashicons-before dashicons-welcome-widgets-menus' ) );
				new VA_Install_Pages(         'install_pages',         array( 'register_to' => $checkout_type, 'since' => $since, 'title' => 'Setup Pages',         'icon' => 'dashicons-before dashicons-welcome-add-page' ) );
				new VA_Install_Menu_Items(    'install_menu_items',    array( 'register_to' => $checkout_type, 'since' => $since, 'title' => 'Setup Menu Items',    'icon' => 'dashicons-before dashicons-editor-ul' ) );
				new VA_Install_Options(       'install_options',       array( 'register_to' => $checkout_type, 'since' => $since, 'title' => 'Setup Options',       'icon' => 'dashicons-before dashicons-admin-settings' ) );
				new VA_Install_Rewrite_Rules( 'install_rewrite_rules', array( 'register_to' => $checkout_type, 'since' => $since, 'title' => 'Flush Rewrite Rules', 'icon' => 'dashicons-before dashicons-update' ) );

				// Regular upgrades might look like following:
				new VA_Upgrade_Order_Item_Addons(       'upgrade_order_item_addons',   array( 'register_to' => $checkout_type, 'since' => '1.1',   'title' => 'Upgrade Order Items Addons', 'icon' => 'dashicons-at-payments' ) );
				new VA_Upgrade_Featured_Image_4_0_0(    'upgrade_featured_image_4',    array( 'register_to' => $checkout_type, 'since' => '4.0.0', 'title' => 'Upgrade Listing Featured Images', 'icon' => 'dashicons-before dashicons-format-image' ) );
				new VA_Upgrade_Theme_Options_4_0_0(     'upgrade_theme_options_4',     array( 'register_to' => $checkout_type, 'since' => '4.0.0', 'title' => 'Upgrade Theme Options', 'icon' => 'dashicons-before dashicons-admin-settings' ) );
				new VA_Upgrade_Options_4_0_0(           'upgrade_listing_options_4',   array( 'register_to' => $checkout_type, 'since' => '4.0.0', 'title' => 'Upgrade Listing Options', 'icon' => 'dashicons-before dashicons-admin-settings' ) );
				new VA_Upgrade_Geodata_4_0_0(           'upgrade_geodata_4',           array( 'register_to' => $checkout_type, 'since' => '4.0.0', 'title' => 'Upgrade Geo Data',         'icon' => 'dashicons-before dashicons-location' ) );
				new VA_Upgrade_Plans_Post_Type_4_0_0(   'upgrade_plans_post_type_4',   array( 'register_to' => $checkout_type, 'since' => '4.0.0', 'title' => 'Upgrade Plans Post Type', 'icon' => 'dashicons-before dashicons-at-payments' ) );
				new VA_Upgrade_Plans_Period_Type_1_3_1( 'upgrade_plans_period_type_1', array( 'register_to' => $checkout_type, 'since' => '1.3.1', 'title' => 'Upgrade Plans Period Type', 'icon' => 'dashicons-before dashicons-at-payments' ) );
				new VA_Upgrade_Post_Meta_Key(           'upgrade_plans_title1_4',      array( 'register_to' => $checkout_type, 'since' => '4.0.0', 'title' => 'Remove Redundant Plans "title" Meta', 'icon' => 'dashicons-before dashicons-at-payments', 'old_value' => 'title', 'post_type' => APPTHEMES_PRICE_PLAN_PTYPE ) );
				new VA_Upgrade_Post_Meta_Key(           'upgrade_plans_title2_4',      array( 'register_to' => $checkout_type, 'since' => '4.0.0', 'title' => 'Remove Redundant Plans "plan_title" Meta', 'icon' => 'dashicons-before dashicons-at-payments', 'old_value' => 'plan_title', 'post_type' => APPTHEMES_PRICE_PLAN_PTYPE ) );
				new VA_Upgrade_Plans_P2P_4_0_0(         'upgrade_plans_p2p_4',         array( 'register_to' => $checkout_type, 'since' => '4.0.0', 'title' => 'Upgrade Plans P2P Connections', 'icon' => 'dashicons-before dashicons-at-payments' ) );
				new VA_Upgrade_Post_Meta_Key(           'upgrade_duration_key_4',      array( 'register_to' => $checkout_type, 'since' => '4.0.0', 'title' => 'Change Listing Duration Meta Key', 'icon' => 'dashicons-before dashicons-at-payments', 'old_value' => 'listing_duration', 'new_value' => '_listing_duration' ) );
				new VA_Upgrade_Post_Meta_Key(           'remove_redundant_flag_4',     array( 'register_to' => $checkout_type, 'since' => '4.0.0', 'title' => 'Remove Redundant "featured" flag', 'icon' => 'dashicons-before dashicons-cloud', 'old_value' => 'featured' ) );

				// data to be replaced: ptype => old => new
				$data = array(
					VA_LISTING_PTYPE => array(
						'featured-cat'  => VA_ITEM_FEATURED_CAT,
						'featured-home' => VA_ITEM_FEATURED_HOME,
					),
					'event' => array(
						'featured-cat'  => 'event-featured-cat',
						'featured-home' => 'event-featured-home',
					),
				);

				foreach ( $data as $ptype => $keys ) {
					foreach ( $keys as $old => $new ) {

						new VA_Upgrade_P2P_Order_Meta( "upgrade_{$new}_p2p_4", array( 'old_value' => $old, 'new_value' => $new, 'post_type' => $ptype, 'title' => "Upgrade {$new} P2P Connection", 'register_to' => $checkout_type, 'since' => '4.0.0', 'icon' => 'dashicons-before dashicons-cloud' ) );
						new VA_Remove_Empty_Post_Meta( "remove_{$new}_meta_4", array( 'old_value' => $old, 'new_value' => $new, 'post_type' => $ptype, 'title' => "Remove {$new} Empty Meta", 'register_to' => $checkout_type, 'since' => '4.0.0', 'icon' => 'dashicons-before dashicons-cloud' ) );
						new VA_Upgrade_Post_Meta_Key( "upgrade_{$new}_flag_4", array( 'old_value' => $old, 'new_value' => "_$new", 'post_type' => $ptype, 'title' => "Upgrade {$new} Flag", 'register_to' => $checkout_type, 'since' => '4.0.0', 'icon' => 'dashicons-before dashicons-cloud' ) );

						if ( 'event' === $ptype ) {
							continue;
						}

						new VA_Upgrade_Post_Meta_Key( "upgrade_{$new}_duration_key_4", array( 'old_value' => "{$old}_duration", 'new_value' => "_{$new}_duration", 'post_type' => $ptype, 'title' => "Upgrade {$new} Duration Key", 'register_to' => $checkout_type, 'since' => '4.0.0', 'icon' => 'dashicons-before dashicons-cloud' ) );
						new VA_Upgrade_Post_Meta_Key( "upgrade_{$new}_start_date_key_4", array( 'old_value' => "{$old}_start_date", 'new_value' => "_{$new}_start_date", 'post_type' => $ptype, 'title' => "Upgrade {$new} Start Date Key", 'register_to' => $checkout_type, 'since' => '4.0.0', 'icon' => 'dashicons-before dashicons-cloud' ) );
						new VA_Upgrade_Post_Meta_Key( "upgrade_plan_{$new}_flag_4", array( 'old_value' => $old, 'new_value' => $new, 'post_type' => APPTHEMES_PRICE_PLAN_PTYPE, 'title' => "Upgrade Pricing Plan {$new} Flag", 'register_to' => $checkout_type, 'since' => '4.0.0', 'icon' => 'dashicons-before dashicons-cloud' ) );
						new VA_Upgrade_Post_Meta_Key( "upgrade_plan_{$new}_duration_key_4", array( 'old_value' => "{$old}_duration", 'new_value' => "{$new}_duration", 'post_type' => APPTHEMES_PRICE_PLAN_PTYPE, 'title' => "Upgrade Pricing Plan {$new} Duration Key", 'register_to' => $checkout_type, 'since' => '4.0.0', 'icon' => 'dashicons-before dashicons-cloud' ) );
						new VA_Upgrade_Post_Meta_Key( "upgrade_plan_{$new}_period_key_4", array( 'old_value' => "{$old}_period", 'new_value' => "{$new}_period", 'post_type' => APPTHEMES_PRICE_PLAN_PTYPE, 'title' => "Upgrade Pricing Plan {$new} Period Key", 'register_to' => $checkout_type, 'since' => '4.0.0', 'icon' => 'dashicons-before dashicons-cloud' ) );
						new VA_Upgrade_Post_Meta_Key( "upgrade_plan_{$new}_period_type_key_4", array( 'old_value' => "{$old}_period_type", 'new_value' => "{$new}_period_type", 'post_type' => APPTHEMES_PRICE_PLAN_PTYPE, 'title' => "Upgrade Pricing Plan {$new} Period Type Key", 'register_to' => $checkout_type, 'since' => '4.0.0', 'icon' => 'dashicons-before dashicons-cloud' ) );

					}
				}

				new VA_Upgrade_Checkout_Data( 'upgrade_checkout_data', array( 'register_to' => $checkout_type, 'since' => '4.0.0', 'title' => 'Upgrade Checkout Data', 'icon' => 'dashicons-before dashicons-cloud' ) );

				// Some regular upgrading procedures.
				new VA_Delete_Expired_Transients( 'delete_expired_transients', array( 'register_to' => $checkout_type, 'since' => VA_VERSION, 'title' => 'Delete Expired Transients', 'icon' => 'dashicons-before dashicons-cloud' ) );

				break;

			case 'install_theme_samples':
				new VA_Install_Sample_Widgets(    'sample_widgets',    array( 'register_to' => $checkout_type, 'since' => $since, 'title' => 'Widgets',       'icon' => 'dashicons-before dashicons-welcome-widgets-menus' ) );
				new VA_Install_Sample_Pages(      'sample_pages',      array( 'register_to' => $checkout_type, 'since' => $since, 'title' => 'Pages',         'icon' => 'dashicons-before dashicons-welcome-add-page' ) );
				new VA_Install_Sample_Menu_Items( 'sample_menu_items', array( 'register_to' => $checkout_type, 'since' => $since, 'title' => 'Menu Items',    'icon' => 'dashicons-before dashicons-editor-ul' ) );
				new VA_Install_Sample_Posts(      'sample_posts',      array( 'register_to' => $checkout_type, 'since' => $since, 'title' => 'Blog Posts',    'icon' => 'dashicons-before dashicons-welcome-write-blog' ) );
				new VA_Install_Sample_Plans(      'sample_plans',      array( 'register_to' => $checkout_type, 'since' => $since, 'title' => 'Pricing Plans', 'icon' => 'dashicons-before dashicons-at-payments' ) );
				new VA_Install_Sample_Listings(   'sample_listings',   array( 'register_to' => $checkout_type, 'since' => $since, 'title' => 'Listings',      'icon' => 'dashicons-before dashicons-list-view' ) );
				new VA_Install_Sample_Logo(       'sample_logo',       array( 'register_to' => $checkout_type, 'since' => $since, 'title' => 'Logo',          'icon' => 'dashicons-before dashicons-admin-customizer' ) );

				break;
		}

	}

	/**
	 * Get the theme name.
	 *
	 * @since 4.0.0
	 *
	 * @return string The theme name value.
	 */
	public function theme_name() {
		return get_option( 'current_theme' );
	}

	/**
	 * Load the inital tabs
	 *
	 * It's required so we leave it empty.
	 *
	 * @since 4.0.0
	 */
	protected function init_tabs() {
		$_SERVER['REQUEST_URI'] = esc_url_raw( remove_query_arg( array( 'firstrun' ), $_SERVER['REQUEST_URI'] ) );
		add_action( 'admin_enqueue_scripts', array( APP_Progress_View::get_instance( 'upgrade_theme' ), 'enqueue_scripts' ) );
	}

	/**
	 * Load the page content.
	 *
	 * @since 4.0.0
	 */
	public function page_content() {

		if ( isset( $_GET['firstrun'] ) ) {
			do_action( 'appthemes_first_run' );
		} ?>

	<div class="wrap about-wrap app-setup">

		<h1><?php printf( __( 'Welcome to %s&nbsp;%s' ), $this->theme_name(), VA_VERSION ); ?></h1>

		<p class="about-text"><?php echo sprintf( __( 'Thank you for updating to the latest version. %s %s is a huge change visually and under the hood&mdash;all which makes your overall experience even better!' ), $this->theme_name(), VA_VERSION ); ?></p>
		<div class="wp-badge"><?php printf( __( 'Version %s' ), VA_VERSION ); ?></div>

		<p class="getting-started-links">
			<a href="https://docs.appthemes.com" class="button button-primary" target="_blank"><?php _e( 'View Documentation &rarr;', APP_TD ); ?></a>
		</p>

		<!-- <h2 class="nav-tab-wrapper wp-clearfix">
			<a href="?page=app-setup" class="nav-tab nav-tab-active"><?php _e( 'What&#8217;s New', APP_TD ); ?></a>
		</h2>

		<div class="changelog point-releases">
			<h3><?php _e( 'Major Redesign and Code Overhaul' ); ?></h3>
			<p><?php printf( _n( '<strong>Version %1$s</strong> is a complete rebuild with and fixed %2$s bug.',
				'<strong>Version %1$s</strong> addressed some security issues and fixed %2$s issues.', 15 ), VA_VERSION, number_format_i18n( 15 ) ); ?>
				<?php printf( __( 'For more information, see <a href="%s">the release notes</a>.' ), 'https://docs.appthemes.com' ); ?>
			</p>
		</div> -->

		<?php if ( APP_Progress_View::get_instance( 'upgrade_theme' )->condition() ) { ?>
			<hr />

			<h3><?php _e( 'Summary' ); ?></h3>
			<p><?php _e( 'Please wait until the installation process is complete.', APP_TD ); ?></p>

			<?php APP_Progress_View::get_instance( 'upgrade_theme' )->display(); ?>

			<script type="text/javascript">
			jQuery( function($) {
				$('#app_progress_form_upgrade_theme' ).find( '.app-progress-button' ).hide().click();
			});
			</script>

		<?php } ?>

		<?php if ( APP_Progress_View::get_instance( 'install_theme_samples' )->condition() ) { ?>

			<hr />

			<h3><?php _e( 'Sample Data' ); ?></h3>
			<p><?php _e( "To help get you started, we've setup some initial pages, posts, options, and pricing plans. You can of course edit and/or delete whatever you like.", APP_TD ); ?></p>

			<?php APP_Progress_View::get_instance( 'install_theme_samples' )->display(); ?>
			<br />
		<?php } ?>

		<?php do_action( 'appthemes_upgrade_section' ); ?>

		<hr />

		<div class="va-setup-getting-started feature-section one-col">

				<h2><?php _e( 'Getting Started', APP_TD ); ?></h2>


				<div class="under-the-hood three-col">
					<div class="col">
						<h3><span class="dashicons dashicons-admin-generic"></span> <?php _e( 'General Settings', APP_TD ); ?></h3>
						<p><?php _e( 'Setup and configure the Vantage options and get your business ready to launch.', APP_TD ); ?></p>
						<p><a href="<?php echo esc_url( admin_url( 'admin.php?page=app-settings' ) ); ?>"><?php _e( 'Configure Theme Settings &rarr;', APP_TD ); ?></a></p>
					</div>
					<div class="col">
						<h3><span class="dashicons dashicons-admin-appearance"></span> <?php _e( 'Look and Feel', APP_TD ); ?></h3>
						<p><?php _e( 'Manage the front-end design of your website using the native WordPress live customizer. Content blocks are widgets for easy setup.', APP_TD ); ?></p>
						<p><a href="<?php echo esc_url( admin_url( 'customize.php' ) ); ?>"><?php _e( 'Launch Customizer &rarr;', APP_TD ); ?></a></p>
					</div>
					<div class="col">
						<h3><span class="dashicons dashicons-at-payments"></span> <?php _e( 'Payment Settings', APP_TD ); ?></h3>
						<p><?php _e( 'If you plan on monetizing your website, make sure you setup and configure the payment settings.', APP_TD ); ?></p>
						<p><a href="<?php echo esc_url( admin_url( 'admin.php?page=app-payments-settings' ) ); ?>"><?php _e( 'Configure Payment Settings &rarr;', APP_TD ); ?></a></p>
					</div>
				</div>

				<div class="under-the-hood three-col">
					<div class="col">
						<h3><span class="dashicons dashicons-update"></span> <?php _e( 'Automatic Updates', APP_TD ); ?></h3>
						<p><?php _e( "Make sure you've got the latest and greatest version of Vantage. Keeping up-to-date protects you from bugs and security issues.", APP_TD ); ?></p>
						<p><a href="<?php echo esc_url( 'https://my.appthemes.com/' ); ?>" target="_blank"><?php _e( 'Download Updater Plugin &rarr;', APP_TD ); ?></a></p>
					</div>
					<div class="col">
						<h3><span class="dashicons dashicons-admin-plugins"></span> <?php _e( 'Marketplace Add-ons', APP_TD ); ?></h3>
						<p><?php _e( "We've got a thriving 3rd-party Marketplace which sells child themes and plugins for your theme.", APP_TD ); ?></p>
						<p><a href="<?php echo esc_url( 'https://marketplace.appthemes.com/' ) ?>" target="_blank"><?php _e( 'View Add-ons &rarr;', APP_TD ); ?></a></p>
					</div>
					<div class="col">
						<h3><span class="dashicons dashicons-sos"></span> <?php _e( 'Get Support', APP_TD ); ?></h3>
						<p><?php _e( "If you've gone through the setup and documentation and still have questions, our support team is here to help.", APP_TD ); ?></p>
						<p><a href="http://forums.appthemes.com/" target="_blank"><?php _e( 'Visit Forums &rarr;', APP_TD ); ?></a></p>
					</div>
				</div>

		</div>

		<hr />

		<div class="feature-section two-col">

			<h2><?php _e( 'Get Involved', APP_TD ); ?></h2>
			<div class="col">
				<img src="//cdn.appthemes.com/wp-content/uploads/2016/11/appthemes-developers-splash-page.png" alt="">
				<h3><span class="dashicons dashicons-hammer"></span> <?php _e( 'Developers', APP_TD ); ?></h3>
				<p>
					<?php
						printf(
							__( 'Build plugins and child themes on top of our products. Check out our Developers Center for tutorials and documentation. We also accept <a href="%s">Github pull requests</a>. If you would like access, please <a href="%s">contact us</a>.', APP_TD ),
							'https://github.com/AppThemes', 'https://www.appthemes.com/about/contact-form/'
						);
					?>
				</p>
				<p><a href="https://docs.appthemes.com/developers/" target="_blank"><?php _e( 'Developers Center &rarr;', APP_TD ); ?></a></p>
			</div>
			<div class="col">
				<img src="//cdn.appthemes.com/wp-content/uploads/2015/03/translate-wordpress-illustration.png" alt="">
				<h3><span class="dashicons dashicons-location-alt"></span> <?php _e( 'Translators', APP_TD ); ?></h3>
				<p><?php _e( "English not your native language? We could use your help then! Become an official AppThemes translator and reap some nice benefits. All text strings can be translated using tools like poedit.", APP_TD ); ?></p>
				<p><a href="https://www.appthemes.com/support/languages/" target="_blank"><?php _e( 'Learn More &rarr;', APP_TD ); ?></a></p>
			</div>

		</div>

	</div> <!-- .wrap about-wrap -->
<?php
	}

}
