<?php
/**
 * Listing advanced form for inclusion in the administration panels.
 *
 * @package Vantage\Templates
 * @since 1.0.0
 */

/**
 * Filter the columns displayed in the listings list table.
 *
 * @todo Use different order and add claimee column with checkbox. Keep author column.
 *
 * @since 1.0.0
 *
 * @param array $columns An array of column names.
 * @return array The column array.
 */
function va_listing_manage_columns( $columns ) {

	$comments = $columns['comments'];
	$date     = $columns['date'];

	unset( $columns['date'], $columns['comments'] );

	if ( ! empty( $_GET['post_status'] ) && VA_LISTING_PTYPE == $_GET['post_type'] && 'pending-claimed' == $_GET['post_status'] ) {
		unset( $columns['author'] );
		$columns['claimee'] = __( 'Claimee', APP_TD );
	}

	$columns['expire']    = __( 'Expires', APP_TD );
	$columns['address']   = __( 'Location', APP_TD );
	$columns['thumbnail'] = '';
	$columns['claimable'] = '';
	$columns['comments']  = $comments;
	$columns['date']      = $date;

	return $columns;
}
add_filter( 'manage_' . VA_LISTING_PTYPE . '_posts_columns', 'va_listing_manage_columns' );


/**
 * Enable column sorting for new custom fields displayed in the listings list table.
 *
 * @since 1.0.0
 *
 * @param array  $columns An array of column names.
 * @return array $columns The column array.
 */
function va_listing_columns_sort( $columns ) {

	$columns['expire'] = 'expire';

	return $columns;
}
add_filter( 'manage_edit-' . VA_LISTING_PTYPE . '_sortable_columns', 'va_listing_columns_sort' );


/**
 * Fires for each custom column in the listings list table.
 *
 * @since 1.0.0
 *
 * @param string $column_name The name of the column to display.
 * @param int    $post_id     The current post ID.
 */
function va_listing_add_column_data( $column_name, $post_id ) {

	switch ( $column_name ) {

		case 'expire' :
			echo mysql2date( get_option( 'date_format' ), va_get_listing_exipration_date( $post_id ) );
			break;
		case 'thumbnail' :
			echo get_the_listing_thumbnail( $post_id );
			break;
		case 'claimee' :
			echo va_get_the_author_listings_link( get_post_meta( $post_id, 'claimee', true ) );
			break;
		case 'claimable' :
			echo '<input type="hidden" disabled="disabled" name="listing_claimable['.$post_id.']" value="'. ( 1 == get_post_meta( $post_id, 'listing_claimable', true ) ? 1 : '') .'" />';
			break;
		case 'address' :
			if ( $address = get_post_meta( $post_id, 'address', true ) ) {
				/**
				 * Filters the default address map link.
				 *
				 * @since 4.0.0
				 *
				 * @param string          The html for the map link.
				 * @param string $address The post meta address.
				 * @param int    $post_id The post ID.
				 */
				echo apply_filters( 'va_listing_column_map_link', '<a class="google_map_link" href="' . esc_url( 'https://www.google.com/maps?q=' . urlencode( strip_tags( $address ) ) ) . '" target="_blank">' . the_listing_address() . '</a>', $address, $post_id );
			} else {
				echo '&ndash;';
			}

			break;
	}
}
add_action( 'manage_' . VA_LISTING_PTYPE . '_posts_custom_column', 'va_listing_add_column_data', 10, 2 );


/**
 * Fires once for each column in Bulk Edit mode.
 *
 * @since 1.0.0
 *
 * @param string  $column_name Name of the column to edit.
 * @param WP_Post $post_type   The post type slug.
 */
function va_bulk_edit_claimee( $column_name, $post_type ) {

	switch ( $column_name ) {
		case 'claimable':
		?>
			<fieldset class="inline-edit-col-right inline-edit-<?php echo $column_name ?>">
				<div class="inline-edit-col inline-edit-<?php echo $column_name ?>">
					<div class="inline-edit-group">
						<label class="inline-edit-<?php echo $column_name; ?> alignleft">
							<span class="title"><?php _e( 'Claimable', APP_TD ); ?></span>
							<select name="listing_claimable[bulk]">
								<option value="-1"><?php _e( '&mdash; No Change &mdash;', APP_TD ); ?></option>
								<option value="1"><?php _e( 'Yes', APP_TD ); ?></option>
								<option value="0"><?php _e( 'No', APP_TD ); ?></option>
							</select>
						</label>
					</div>
				</div>
			</fieldset>
		<?php
			break;
	}
}
add_action( 'bulk_edit_custom_box', 'va_bulk_edit_claimee', 10, 2 );


/**
 * Fires once for each column in Quick Edit mode.
 *
 * @since 1.0.0
 *
 * @param string $column_name Name of the column to edit.
 * @param string $post_type   The post type slug.
 */
function va_quick_edit_claimee( $column_name, $post_type ) {

	switch ( $column_name ) {
		case 'claimable':
		?>
			<fieldset class="inline-edit-col-right inline-edit-<?php echo $column_name ?>">
				<div class="inline-edit-col inline-edit-<?php echo $column_name ?>">
					<div class="inline-edit-group">
						<label class="inline-edit-<?php echo $column_name; ?> alignleft">
							<input type="checkbox" name="listing_claimable" value="1" />
							<span class="checkbox-title"><?php _e( 'Claimable' , APP_TD ); ?></span>
						</label>
					</div>
				</div>
			</fieldset>
		<?php
		break;
	}
}
add_action( 'quick_edit_custom_box', 'va_quick_edit_claimee', 10, 2 );


/**
 * Fires once a listing has been saved.
 *
 * @since 1.0.0
 *
 * @param int $post_id Post ID.
 */
function va_listing_bulk_save_categories( $post_id ) {

	if ( empty( $_REQUEST['post_type'] ) || VA_LISTING_PTYPE !== $_REQUEST['post_type'] ) {
		return;
	}

	if ( ! current_user_can( 'edit_post', $post_id ) ) {
		return;
	}

	if ( ! isset( $_REQUEST['bulk_edit'] ) ) {
		return;
	}

	if ( ! empty( $_REQUEST['post'] ) && in_array( $post_id, $_REQUEST['post'] ) && ! empty( $_REQUEST['tax_input'][ VA_LISTING_CATEGORY ] ) ) {

		$categories = $_REQUEST['tax_input'][ VA_LISTING_CATEGORY ];

		foreach ( $categories as $k => $category ) {
			if ( empty( $category ) ) {
				unset( $categories[ $k ] );
			}
		}

		if ( empty( $categories ) || ! is_array( $categories ) ) {
			return;
		}

		$categories = array_map( 'intval', $categories );
		$categories = array_unique( $categories );

		wp_set_object_terms( $listing_id, $categories, VA_LISTING_CATEGORY );
	}
}
add_action( 'save_post', 'va_listing_bulk_save_categories' );


/**
 * Fires once a listing has been saved.
 *
 * @since 1.0.0
 *
 * @param int $post_id Post ID.
 */
function va_listing_bulk_save( $post_id ) {

	if ( empty( $_REQUEST['post_type'] ) || VA_LISTING_PTYPE !== $_REQUEST['post_type'] ) {
		return;
	}

	if ( ! current_user_can( 'edit_post', $post_id ) ) {
		return;
	}

	if ( isset( $_REQUEST['listing_claimable']['bulk'] ) ) {
		if ( 1 == $_REQUEST['listing_claimable']['bulk'] ) {
			update_post_meta( $post_id, 'listing_claimable', 1 );
		} elseif ( 0 == $_REQUEST['listing_claimable']['bulk'] ) {
			delete_post_meta( $post_id, 'listing_claimable', 1 );
		}
	} elseif ( isset( $_REQUEST['_inline_edit'] ) ) {
		if ( isset( $_REQUEST['listing_claimable'] ) ) {
			update_post_meta( $post_id, 'listing_claimable', 1 );
		} else {
			delete_post_meta( $post_id, 'listing_claimable' );
		}
	}
}
add_action( 'save_post', 'va_listing_bulk_save' );
