<?php
/**
 * The theme setup and install scripts.
 *
 * @package Vantage
 *
 * @since 4.0.0
 */

class VA_Install_Menus extends APP_Progress_Upgrade_Step {

	public function get_total() {
		return count( get_registered_nav_menus() );
	}

	/**
	 * Create the inital menus for the new site.
	 *
	 * @since  4.1.0
	 *
	 * @param APP_Dynamic_Checkout $checkout Checkout object.
	 *
	 * @return int The number of actually processed items.
	 */
	public function progress( APP_Dynamic_Checkout $checkout ) {
		// Get all registered menu locations so we can assign menus to them.
		$locations = get_theme_mod( 'nav_menu_locations' );

		// Get all registered theme menu items.
		$menus = get_registered_nav_menus();

		foreach ( $menus as $key => $value ) {

			// Create the menu and return menu ID.
			$menu_id = wp_create_nav_menu( ucwords( $key ) );

			// Menu name already exists so use existing menu ID.
			if ( is_wp_error( $menu_id ) ) {
				$menu_id = $locations[ $key ];
			}

			// Get the new term object so we can grab the term ID.
			$menu_id = wp_get_nav_menu_object( $menu_id );

			// Assign new menu ID to registered location.
			$locations[ $key ] = $menu_id->term_id;
		}

		// Save the menu locations.
		set_theme_mod( 'nav_menu_locations', $locations );

		return count( $menus );
	}

}

class VA_Install_Widgets extends APP_Progress_Upgrade_Step {

	protected function get_widgets() {
		return array(
			/**
			 * Home page widgets.
			 */
			'va-home-main-content-sidebar' => array(
				'va_widget_listing_featured' => array(
					'header'      => __( 'Featured Listings', APP_TD ),
					'description' => __( 'Check out our featured listings', APP_TD ),
					'limit'       => 8,
				),
				'va_widget_listing_latest' => array(
					'header'      => __( 'Latest Listings', APP_TD ),
					'description' => __( 'Check out our newest listings', APP_TD ),
					'limit'       => 6,
				),
				'va_widget_post_latest' => array(
					'header'      => __( 'From the Blog', APP_TD ),
					'description' => __( 'Read our latest articles', APP_TD ),
					'limit'       => 3,
				),
			),
			/**
			 * Single listing page widgets.
			 */
			'va-single-listing-main-content-sidebar' => array(
				'va_widget_listing_content' => array(
					'title'  => '',
				),
				'va_widget_listing_reveal_gallery' => array(
					'title'  => __( 'Photo Gallery', APP_TD ),
				),
				'va_widget_listing_custom_fields' => array(
					'title'  => __( 'Additional Info', APP_TD ),
				),
				'va_widget_listing_comments' => array(
					'title'  => __( 'Comments', APP_TD ),
				),
			),
			/**
			 * Single listing sidebar widgets.
			 */
			'va-single-listing-sidebar' => array(
				'va_widget_listing_map' => array(
					'title'      => '',
					'address'    => true,
					'phone'      => true,
					'website'    => true,
					'email'      => true,
					'directions' => true,
					'social'     => true,
				),
				'va_widget_listing_author' => array(
					'title' => __( 'Listing Owner', APP_TD ),
				),
			),
			/**
			 * User pages sidebar widgets.
			 */
			'va-user-sidebar' => array(
				'va_widget_listing_author_stats' => array(
					'title' => __( 'Account Stats', APP_TD ),
				),
			),
			/**
			 * Search listings pages sidebar widgets.
			 */
			'va-archive-listing-sidebar' => array(
				'va_widget_listing_refine_search' => array(
					'title' => __( 'Refine Results', APP_TD ),
				),
			),
			/**
			 * Blog sidebar widgets.
			 */
			'va-blog-sidebar' => array(
				'search' => array(
					'title' => '',
				),
				'recent-posts' => array(
					'title'     => __( 'Recent Posts', APP_TD ),
					'number'    => 5,
					'show_date' => true,
				),
				'meta' => array(
					'title' => __( 'Meta', APP_TD ),
				),
			),
		);
	}

	/**
	 * Retrieves total number of items to be processed withing current step.
	 *
	 * @return int
	 */
	public function get_total() {
		$count   = 0;
		$widgets = $this->get_widgets();

		foreach ( $widgets as $group ) {
			$count += count( $group );
		}

		return $count;
	}

	/**
	 * Create the inital menus for the new site.
	 *
	 * @since  4.1.0
	 *
	 * @param APP_Dynamic_Checkout $checkout Checkout object.
	 *
	 * @return int The number of actually processed items.
	 */
	public function progress( APP_Dynamic_Checkout $checkout ) {
		$sidebars_widgets = $this->get_widgets();
		appthemes_install_widgets( $sidebars_widgets );

		return $this->get_total();
	}

}

class VA_Install_Sample_Widgets extends VA_Install_Widgets {

	protected function get_widgets() {
		return array(
			/**
			 * Footer widgets.
			 */
			'va-footer-sidebar-1' => array(
				'text' => array(
					'title' => __( 'About Us', APP_TD ),
					'text'  => __( 'We provide a platform to showcase your business and connect with your customers.', APP_TD ),
				),
			),
			'va-footer-sidebar-2' => array(
				'recent-posts' => array(
					'title'  => __( 'Latest News', APP_TD ),
					'number' => 5,
				),
			),
			'va-footer-sidebar-3' => array(
				'recent-comments' => array(
					'title'  => __( 'Recent Comments', APP_TD ),
					'number' => 5,
				),
			),
			'va-footer-sidebar-4' => array(
				'meta' => array(
					'title'  => __( 'Meta', APP_TD ),
					'number' => 5,
				),
			),
			/**
			 * Home page widgets.
			 */
			'va-home-main-content-sidebar' => array(
				'va_widget_listing_featured' => array(
					'header'      => __( 'Featured Listings', APP_TD ),
					'description' => __( 'Check out our featured listings', APP_TD ),
					'limit'       => 8,
				),
				'va_widget_listing_latest' => array(
					'header'      => __( 'Latest Listings', APP_TD ),
					'description' => __( 'Check out our newest listings', APP_TD ),
					'limit'       => 6,
				),
				'va_widget_callout_box' => array(
					'header'           => __( 'Download our App', APP_TD ),
					'content'          => '<ul class="apps-list list-inline">
	<li><a class="button hollow download-app apple-download" href="#"><i class="fa fa-apple" aria-hidden="true"></i> <span class="intro-text">' . _x( 'Download on the', 'App Store', APP_TD ) . '</span><span class="main-text">App Store</span></a></li>
	<li><a class="button hollow download-app android-download" href="#"><i class="fa fa-android" aria-hidden="true"></i> <span class="intro-text"> ' . _x( 'Get it on', 'Google Play', APP_TD ) . '</span><span class="main-text">Google Play</span></a></li>
	<li><a class="button hollow download-app windows-download" href="#"><i class="fa fa-windows" aria-hidden="true"></i> <span class="intro-text">' . _x( 'Download from', 'Windows Phone Store', APP_TD ) . '</span><span class="main-text">Windows Phone Store</span></a></li>
</ul>',
					'text_align'       => 'center',
					'text_color'       => '#ffffff',
					'text_padding'     => 6,
					'background'       => 'cover',
					'background_color' => '#1AB394',
				),
				'va_widget_post_latest' => array(
					'header'      => __( 'From the Blog', APP_TD ),
					'description' => __( 'Read our latest articles', APP_TD ),
					'limit'       => 3,
				),
				'va_widget_callout_box2' => array(
					'widget_name'      => 'va_widget_callout_box',
					'header'           => __( 'Ready to Get Started?', APP_TD ),
					'content'          => __( 'Sign up to try us FREE for 30 days! No credit card needed.', APP_TD ) . '
<form action="#">
<div class="small-12 medium-8 small-centered columns">
	<div class="input-group">
		<input class="input-group-field" type="email" placeholder="email@domain.com">
		<div class="input-group-button">
			<input type="submit" class="button" value="' . __( 'Sign Up!', APP_TD ) . '">
		</div>
	</div>
</div>
</form>',
					'text_align'       => 'center',
					'text_padding'     => 5,
					'background'       => 'cover',
					'background_color' => '#ffffff',
				),
			),
			/**
			 * Blog sidebar widgets.
			 */
			'va-blog-sidebar' => array(
				'search' => array(
					'title' => '',
				),
				'recent-posts' => array(
					'title'     => __( 'Recent Posts', APP_TD ),
					'number'    => 5,
					'show_date' => true,
				),
				'rss' => array(
					'title'     => __( 'Reuters World News', APP_TD ),
					'url'       => 'http://feeds.reuters.com/reuters/topNews',
					'items'     => 5,
					'show_date' => true,
				),
				'meta' => array(
					'title' => __( 'Meta', APP_TD ),
				),
			),
		);
	}
}

class VA_Install_Sample_Posts extends APP_Progress_Upgrade_Step {

	protected function _get_items() {
		return array(
			'blog_post' => array(
				'postarr' => array(
					'post_status'  => 'publish',
					'post_title'   => 'Top Spring Breakfast Spots',
					'post_content' => 'The this jeez with when some rabidly far nobly excepting histrionically onto this hen exited one interminably until within flamingo yikes sardonically far sweeping since juicy abominably however followed dog fitting swung.

Far jeepers glanced hello prior savage fondly far plankton much examined matter-of-factly unimaginatively naturally wow inside gratefully sheared some smelled.

Strode regarding more happy where wolf gorilla that forward more dear leered ecstatic hopefully dipped or creepily untruthful oh maliciously uselessly mawkish that placid disbanded ouch gosh.

Abiding broke jeepers because romantic when jeez far much next and seal before hawk crud overdrew prosperously laudable creepy loaded because apart fatal misunderstood less unlike.

Goodness far disgraceful much caterpillar hedgehog froze significant hello far so where dubious some as wittily black armadillo hey iguanodon raffishly and hawk.',
				),
				'image'   => 'breakfast-coffee.jpeg',
			),
		);
	}

	public function get_total() {
		return count( $this->_get_items() );
	}

	/**
	 * Create the inital post content for the new site.
	 *
	 * @since  4.1.0
	 *
	 * @param APP_Dynamic_Checkout $checkout Checkout object.
	 *
	 * @return int The number of actually processed items.
	 */
	public function progress( APP_Dynamic_Checkout $checkout ) {

		$items = $this->_get_items();

		foreach ( $items as $name => $args ) {
			$id = wp_insert_post( $args['postarr'] );

			if ( $id ) {
				$checkout->add_data( $name . '_page_id', $id );
				if ( isset( $args['meta'] ) ) {
					foreach ( (array) $args['meta'] as $metakey => $metavalue ) {
						update_post_meta( $id, $metakey, $metavalue );
					}
				}
				if ( isset( $args['image'] ) ) {
					$img_url = get_template_directory_uri() . '/assets/images/admin/install/' . $args['image'];
					VA_Install::upload_image( $id, $img_url, null, true );
				}
			}
		}

		return $this->get_total();
	}

}

class VA_Install_Pages extends VA_Install_Sample_Posts {

	protected function _get_items() {
		global $vantage;

		$home_page_id = get_option( 'page_on_front', 0 );
		$blog_page_id = get_option( 'page_for_posts', 0 );
		$cat_page_id  = 0;
		$create_page_id = 0;
		$new_create_page_id = $vantage->{VA_LISTING_PTYPE}->view_process_new->get_page_id();

		// In case that legacy pages exist.
		$page_q = new WP_Query( array(
			'post_type'        => 'page',
			'meta_key'         => '_wp_page_template',
			'meta_value'       => array( 'categories-list.php', 'categories-list-listing.php' ),
			'posts_per_page'   => 1,
			'suppress_filters' => true,
		) );

		if ( ! empty( $page_q->posts ) ) {
			$cat_page_id = $page_q->posts[0]->ID;
		}

		$page_q = new WP_Query( array(
			'post_type'        => 'page',
			'meta_key'         => '_wp_page_template',
			'meta_value'       => 'create-listing.php',
			'posts_per_page'   => 1,
			'suppress_filters' => true,
		) );

		if ( ! empty( $page_q->posts ) ) {
			$create_page_id = $page_q->posts[0]->ID;

			if ( $new_create_page_id ) {
				wp_delete_post( $new_create_page_id, true );
			}

		} else {
			$create_page_id = $new_create_page_id;
		}

		return array(
			'home' => array(
				'postarr' => array(
					'ID'           => $home_page_id,
					'post_type'    => 'page',
					'post_status'  => 'publish',
					'post_title'   => __( 'Home', APP_TD ),
				),
				'meta' => array(
					'_wp_page_template' => 'page-templates/template-home.php',
				),
			),
			'blog' => array(
				'postarr' => array(
					'ID'           => $blog_page_id,
					'post_type'    => 'page',
					'post_status'  => 'publish',
					'post_title'   => __( 'Blog', APP_TD ),
				),
				'image'   => 'vintage-technology-keyboard-old.jpg',
			),
			'cat' => array(
				'postarr' => array(
					'ID'           => $cat_page_id,
					'post_type'    => 'page',
					'post_status'  => 'publish',
					'post_title'   => __( 'Categories', APP_TD ),
					'post_content' => '[vantage_listing_categories]', // Shortcode.
				),
				'meta' => array(
					'_wp_page_template' => 'page-templates/template-full-width.php',
				),
			),
			'create' => array(
				'postarr' => array(
					'ID'           => $create_page_id,
					'post_type'    => 'page',
					'post_status'  => 'publish',
					'post_title'   => __( 'Create Listing', APP_TD ),
				),
				'meta' => array(
					'_wp_page_template' => 'process-listing-new.php',
				),
			),
		);
	}

	public function get_total() {
		$count = parent::get_total();
		$count  += count( APP_View_Page::_get_templates() );
		return $count;
	}
}

class VA_Install_Sample_Pages extends VA_Install_Sample_Posts {

	protected function _get_items() {

		$home_page_id = get_option( 'page_on_front', 0 );

		return array(
			'home'   => array(
				'postarr' => array(
					'ID'           => $home_page_id,
					'post_type'    => 'page',
					'post_status'  => 'publish',
					'post_title'   => __( 'Search for....', APP_TD ),
					'post_content' => '[vantage_typed_elements text="' . __( 'tacos in San Francisco, coffee in Tokyo, pet food in London, office space in Paris, anything with Vantage!', APP_TD ) . '"]
' . __( 'People use Vantage to discover great local businesses. What will you find in your neighborhood?', APP_TD ) . '
<br>
<br>
<a class="button large" href="listings/?ls=">' . __( 'BROWSE LISTINGS', APP_TD ) . ' &nbsp;&nbsp;<i class="fa fa-chevron-circle-right" aria-hidden="true"></i></a>',
				),
			),
			'sample' => array(
				'postarr' => array(
					'post_type'    => 'page',
					'post_status'  => 'publish',
					'post_title'   => __( 'Why Us', APP_TD ),
					'post_content' => 'Underwrote salamander more far quit hello and unheedfully until camel thus however tragically upheld sound oh some more crud brusque gosh crud jeepers.

Then stolidly snugly less more yellow forgot more and some less far yet much flawlessly more less jeez spurious much far thus and as one crab far some komodo wiped wildly.

Minimally until inaudible sadistic zebra tremendously stole jolly yet by smiled to beseeching much forgetful joyful alas oh overheard amid apologetic rueful across according this thought urchin dear browbeat between rewrote.

Much some the yet sensitive manatee unsaddled porcupine that the positively after more crass goldfish fleet fox removed more darn black considering far.

Inflexibly thanks complacently snuffed activated catty desirably candid up after oh far reined caught over much oh far unobtrusively that untiringly hence.',
				),
				'meta' => array(
					'_wp_page_template' => 'page-templates/template-full-width.php',
				),
			),
		);
	}
}

class VA_Install_Menu_Items extends APP_Progress_Upgrade_Step {

	protected function _get_items() {
		global $vantage;

		// Get all registered menu locations so we can add page/posts to them.
		$locations = get_theme_mod( 'nav_menu_locations' );
		$checkout  = appthemes_get_checkout();

		return array(
			array(
				'post_id' => $checkout->get_data( 'blog_page_id' ),
				'menu_id' => $locations['secondary'],
			),
			array(
				'post_id' => $checkout->get_data( 'cat_page_id' ),
				'menu_id' => $locations['secondary'],
			),
			array(
				'post_id' => $vantage->{VA_LISTING_PTYPE}->view_process_new->get_page_id(),
				'menu_id' => $locations['primary'],
				'data'    => array( 'menu-item-title' => '<i class="fa fa-plus"></i> ' . __( 'Create Listing', APP_TD ) ),
			),
		);
	}

	/**
	 * Retrieves total number of items to be processed withing current step.
	 *
	 * @return int
	 */
	public function get_total() {
		return count( $this->_get_items() );
	}

	/**
	 * Add initial menu items.
	 *
	 * @param APP_Dynamic_Checkout $checkout Checkout object.
	 *
	 * @return int The number of actually processed items.
	 */
	public function progress( APP_Dynamic_Checkout $checkout ) {

		foreach ( $this->_get_items() as $item ) {

			wp_parse_args( $item, array(
				'post_id' => '',
				'menu_id' => '',
				'data'    => array(),
			) );

			VA_Install::add_item_to_menu( $item['post_id'], $item['menu_id'], $item['data'] );
		}

		return $this->get_total();
	}

}

class VA_Install_Sample_Menu_Items extends VA_Install_Menu_Items {

	protected function _get_items() {
		global $vantage;

		// Get all registered menu locations so we can add page/posts to them.
		$locations = get_theme_mod( 'nav_menu_locations' );
		$checkout  = appthemes_get_checkout();

		return array(
			array(
				'post_id' => $checkout->get_data( 'sample_page_id' ),
				'menu_id' => $locations['secondary'],
			),
			array(
				'menu_id' => $locations['footer'],
				'data'    => array(
					'menu-item-type'  => 'custom',
					'menu-item-title' => '<i class="fa fa-twitter" aria-hidden="true"></i>',
					'menu-item-url'   => 'https://twitter.com/',
				),
			),
			array(
				'menu_id' => $locations['footer'],
				'data'    => array(
					'menu-item-type'  => 'custom',
					'menu-item-title' => '<i class="fa fa-facebook" aria-hidden="true"></i>',
					'menu-item-url'   => 'https://www.facebook.com/',
				),
			),
			array(
				'menu_id' => $locations['footer'],
				'data'    => array(
					'menu-item-type'  => 'custom',
					'menu-item-title' => '<i class="fa fa-google-plus" aria-hidden="true"></i>',
					'menu-item-url'   => 'https://plus.google.com/',
				),
			),
			array(
				'menu_id' => $locations['footer'],
				'data'    => array(
					'menu-item-type'  => 'custom',
					'menu-item-title' => '<i class="fa fa-instagram" aria-hidden="true"></i>',
					'menu-item-url'   => 'https://www.instagram.com/',
				),
			),
			array(
				'menu_id' => $locations['footer'],
				'data'    => array(
					'menu-item-type'  => 'custom',
					'menu-item-title' => '<i class="fa fa-linkedin" aria-hidden="true"></i>',
					'menu-item-url'   => 'https://www.linkedin.com/',
				),
			),
		);
	}
}

class VA_Install_Sample_Plans extends VA_Install_Sample_Posts {

	protected function _get_items() {
		return array(
			'free_plan' => array(
				'postarr' => array(
					'post_type'    => APPTHEMES_PRICE_PLAN_PTYPE,
					'post_status'  => 'publish',
					'post_title'   => __( 'Free Trial', APP_TD ),
				),
				'meta'    => array(
					'description'                       => __( 'Take a few days to test the waters. See if listing on our site works for your business.', APP_TD ),
					'price'                             => '0.00',
					'included_categories'               => 1,
					'recurring'                         => 'non_recurring',
					'period'                            => 7,
					'duration'                          => 7,
					'period_type'                       => 'D',
					'listing-featured-cat'              => '',
					'listing-featured-cat_period'       => 0,
					'listing-featured-cat_period_type'  => 'D',
					'listing-featured-cat_duration'     => 0,
					'listing-featured-home'             => '',
					'listing-featured-home_period'      => 0,
					'listing-featured-home_period_type' => 'D',
					'listing-featured-home_duration'    => 0,
				),
			),
			'standard_plan' => array(
				'postarr' => array(
					'post_type'    => APPTHEMES_PRICE_PLAN_PTYPE,
					'post_status'  => 'publish',
					'post_title'   => __( 'Standard Listing', APP_TD ),
				),
				'meta'    => array(
					'description'                       => __( 'A no-frills, simple, month-to-month plan. Great for most businesses.', APP_TD ),
					'price'                             => '5.00',
					'included_categories'               => 3,
					'recurring'                         => 'non_recurring',
					'period'                            => 30,
					'duration'                          => 30,
					'period_type'                       => 'D',
					'listing-featured-cat'              => '',
					'listing-featured-cat_period'       => 0,
					'listing-featured-cat_period_type'  => 'D',
					'listing-featured-cat_duration'     => 0,
					'listing-featured-home'             => '',
					'listing-featured-home_period'      => 0,
					'listing-featured-home_period_type' => 'D',
					'listing-featured-home_duration'    => 0,
				),
			),
			'power_plan' => array(
				'postarr' => array(
					'post_type'    => APPTHEMES_PRICE_PLAN_PTYPE,
					'post_status'  => 'publish',
					'post_title'   => __( 'Power Listing', APP_TD ),
				),
				'meta'    => array(
					'description'                       => __( 'Reap extra benefits with our annual plan. Saves your business money. (Two months free!)', APP_TD ),
					'price'                             => '50.00',
					'included_categories'               => 3,
					'recurring'                         => 'non_recurring',
					'period'                            => 1,
					'duration'                          => 365,
					'period_type'                       => 'Y',
					'listing-featured-cat'              => 1,
					'listing-featured-cat_period'       => 1,
					'listing-featured-cat_period_type'  => 'M',
					'listing-featured-cat_duration'     => 30,
					'listing-featured-home'             => 1,
					'listing-featured-home_period'      => 1,
					'listing-featured-home_period_type' => 'M',
					'listing-featured-home_duration'    => 30,
				),
			),
		);
	}
}

class VA_Install_Sample_Listings extends APP_Progress_Upgrade_Step {

	/**
	 * Retrieves total number of items to be processed withing current step.
	 *
	 * @return int
	 */
	public function get_total() {
		return 1;
	}

	/**
	 * Create the inital listings content.
	 *
	 * @param APP_Dynamic_Checkout $checkout Checkout object.
	 *
	 * @return int The number of actually processed items.
	 */
	public function progress( APP_Dynamic_Checkout $checkout ) {
		global $vantage;

		$listing_mod = $vantage->{VA_LISTING_PTYPE};
		/* @var $plan APP_Listing_Plan_I */
		$plans = $listing_mod->plans->get_plans();
		$plan = $plans[0];

		// Insert terms or return existing term id.
		$parent_term_id = appthemes_maybe_insert_term( __( 'Food', APP_TD ), VA_LISTING_CATEGORY );

		// Create a child category to put listing into.
		appthemes_maybe_insert_term( __( 'Dessert', APP_TD ), VA_LISTING_CATEGORY, array( 'parent' => $parent_term_id['term_id'] ) );

		/* @var $importer VA_Admin_Importer */
		$importer = appthemes_get_instance( 'VA_Admin_Importer' );
		$sample   = $importer->get_sample_data();

		// Import listing from the generated sample.
		$listing_id = $importer->import_listing( $sample );

		// Set feature addons.
		appthemes_add_addon( $listing_id, VA_ITEM_FEATURED_HOME, 30 );
		appthemes_add_addon( $listing_id, VA_ITEM_FEATURED_CAT, 30 );

		// Create a transaction record.
		$order = appthemes_new_order();
		$order->add_item( $plan->get_type(), 5, $listing_id );
		$order->set_gateway( 'paypal' );
		$order->complete();
		$order->activate();

		// Create a comment on this listing.
		$commentdata = array(
			'comment_author'       => 'AppThemes Team',
			'comment_author_email' => 'general@appthemes.com',
			'comment_author_url'   => 'https://www.appthemes.com',
			'comment_author_IP'    => '',
			'comment_approved'     => 1,
			'comment_parent'       => 0,
			'user_id'              => 0,
			'comment_post_ID'      => $listing_id,
			'comment_content'      => "Sprinkles is the BEST cupcake shop on this planet! I've been to this location multiple times and my favorite is the Red Velvet cupcake.

			Cream cheese frosting and moist Callebaut cocoa cake. Yummy! :-)",
		);

		wp_insert_comment( $commentdata );

		return $this->get_total();
	}

}

class VA_Install_Sample_Logo extends APP_Progress_Upgrade_Step {

	/**
	 * Retrieves total number of items to be processed withing current step.
	 *
	 * @return int
	 */
	public function get_total() {
		return 1;
	}

	/**
	 * Set the sample logo.
	 *
	 * @param APP_Dynamic_Checkout $checkout Checkout object.
	 *
	 * @return int The number of actually processed items.
	 */
	public function progress( APP_Dynamic_Checkout $checkout ) {

		$path = get_template_directory() . '/assets/images/admin/install/';

		// Set the header logo image.
		$custom_logo_id = VA_Install::upload_image( 0, $path . 'vantage-logo.png', __( 'Vantage Logo', APP_TD ), false );
		set_theme_mod( 'custom_logo', $custom_logo_id );

		return $this->get_total();
	}

}

class VA_Install_Options extends APP_Progress_Upgrade_Step {

	private function _get_items() {

		$checkout = appthemes_get_checkout();

		$options = array(
			'show_on_front'  => 'page',
			'page_on_front'  => $checkout->get_data( 'home_page_id' ),
			'page_for_posts' => $checkout->get_data( 'blog_page_id' ),
		);

		// Setup pretty permalinks for the blog if something isn't already set.
		// Default core is now /%year%/%monthnum%/%day%/%postname%/
		if ( ! get_option( 'permalink_structure' ) ) {
			$options['permalink_structure'] = '/%postname%/';
		}

		// Set the default user role.
		if ( get_option( 'default_role' ) == 'subscriber' ) {
			$options['default_role'] = 'contributor';
		}

		return $options;
	}

	/**
	 * Retrieves total number of items to be processed withing current step.
	 *
	 * @return int
	 */
	public function get_total() {
		return count( $this->_get_items() );
	}

	/**
	 * Set the inital WordPress options.
	 *
	 * @param APP_Dynamic_Checkout $checkout Checkout object.
	 *
	 * @return int The number of actually processed items.
	 */
	public function progress( APP_Dynamic_Checkout $checkout ) {

		$items = $this->_get_items();

		foreach ( $items as $key => $value ) {
			update_option( $key, $value );
		}

		return count( $items );
	}

}

class VA_Install_Rewrite_Rules extends APP_Progress_Upgrade_Step {

	/**
	 * Retrieves total number of items to be processed withing current step.
	 *
	 * @return int
	 */
	public function get_total() {
		return 1;
	}

	/**
	 * Set the sample logo.
	 *
	 * @param APP_Dynamic_Checkout $checkout Checkout object.
	 *
	 * @return int The number of actually processed items.
	 */
	public function progress( APP_Dynamic_Checkout $checkout ) {
		flush_rewrite_rules();
		return $this->get_total();
	}

}

/**
 * Install/Upgrade helper utils.
 *
 * @since 4.0.0
 */
final class VA_Install {

	/**
	 * Adds the page/post to an existing menu.
	 *
	 * @since 4.0.0
	 *
	 * @param int    $post_id         The post ID to add.
	 * @param string $menu_id         The menu ID to add to.
	 * @param array  $menu_item_data  The menu item's data.
	 * @return int|WP_Error Menu ID on success, WP_Error object on failure.
	 */
	public static function add_item_to_menu( $post_id, $menu_id, $menu_item_data = array() ) {

		$defaults = array(
			'menu-item-object-id'   => $post_id,
			'menu-item-object'      => 'page',
			'menu-item-parent-id'   => 0,
			'menu-item-position'    => 0,
			'menu-item-type'        => 'post_type',
			'menu-item-title'       => '', // The post_title.
			'menu-item-url'         => '', // The url to go to if custom page.
			'menu-item-description' => '', // The post_content.
			'menu-item-target'      => '', // When clicked on. Options: _blank or empty.
			'menu-item-classes'     => '', // CSS classes separated by spaces.
			'menu-item-xfn'         => '',
			'menu-item-status'      => 'publish', // The post status.
		);

		$args = wp_parse_args( $menu_item_data, $defaults );

		return wp_update_nav_menu_item( $menu_id, 0, $args );
	}

	/**
	 * Upload an image to the media library.
	 *
	 * @since 4.0.0
	 *
	 * @param int    $post_id   The ID of the post to which the image is attached.
	 * @param string $file      The full path of the image (http url or local absolute path).
	 * @param string $desc      The image description (optional).
	 * @param bool   $featured  Set the featured image. Default false.
	 * @param array  $post_data Optional. Post data to override. Default empty array.
	 * @return (int|false)      The image post ID on success.
	 */
	public static function upload_image( $post_id, $file, $desc = null, $featured = false, $post_data = array() ) {

		// WordPress API for image uploads.
		require_once( ABSPATH . 'wp-admin/includes/admin.php' );

		// Get the actual file name (xyz.jpg).
		$filename = basename( $file );

		// Handle locally stored files differently.
		if ( ! preg_match( '!^(http|https)://!i', $file ) ) {

			// Grab the upload dir values.
			$r = wp_upload_dir();

			// Copy it to the uploads dir.
			@copy( $file, trailingslashit( $r['path'] ) . $filename );

			// Get the new media url.
			$file = trailingslashit( $r['url'] ) . $filename;
		}

		// Download the file to a temp location.
		$url = download_url( $file );

		$file_array = array(
			'name'     => $filename,
			'tmp_name' => $url,
		);

		if ( is_wp_error( $file_array['tmp_name'] ) ) {
			error_log( 'Error trying to store the file temporarily.' );
			return;
		}

		// Do the validation and put it in the media library.
		$id = media_handle_sideload( $file_array, $post_id, $desc, $post_data );

		// If error storing permanently, unlink.
		if ( is_wp_error( $id ) ) {
			@unlink( $file_array['tmp_name'] );
			return $id;
		}

		// Set as featured image if param passed.
		if ( true === $featured ) {
			set_post_thumbnail( $post_id, $id );
		}

		return $id;
	}

}
