<?php
/**
 * Upgrade procedures.
 *
 * @package Vanatge\Admin\Upgrade
 * @author  AppThemes
 * @since   4.0.0
 */

class VA_Upgrade_Post_Meta_Key extends APP_Progress_Upgrade_Step {

	/**
	 * Creates new Checkout Step instance
	 *
	 * @param string $step_id Step ID.
	 * @param array  $args    Step arguments.
	 */
	public function __construct( $step_id, $args = array() ) {

		$args = wp_parse_args( $args, array(
			'old_value' => '',
			'new_value' => '',
			'post_type' => '',
			'limit'     => 1000,
		) );

		parent::__construct( $step_id, $args );
	}

	/**
	 * Retrieves total number of items to be processed withing current step.
	 *
	 * @return int
	 */
	public function get_total() {
		global $wpdb;

		$sql = "";
		$sql .= "SELECT COUNT(meta_id) pm ";
		$sql .= "FROM {$wpdb->postmeta} pm ";
		$sql .= ( $this->args['post_type'] ) ? "INNER JOIN {$wpdb->posts} ps ON ( pm.post_id = ps.ID ) " : "";
		$sql .= "WHERE ";
			$sql .= "pm.meta_key = '%s' ";
			$sql .= ( $this->args['post_type'] ) ? "AND ps.post_type = '%s'" : "";

		if ( $this->args['post_type'] ) {
			$sql = $wpdb->prepare( $sql, $this->args['old_value'], $this->args['post_type'] );
		} else {
			$sql = $wpdb->prepare( $sql, $this->args['old_value'] );
		}

		return intval( $wpdb->get_var( $sql ) );
	}

	/**
	 * Processes items.
	 *
	 * @param APP_Dynamic_Checkout $checkout Checkout object.
	 *
	 * @return int The number of actually processed items.
	 */
	public function progress( APP_Dynamic_Checkout $checkout ) {
		global $wpdb;

		$limit = $this->args['limit'];

		if ( ! $this->args['post_type'] ) {

			if ( ! $this->args['new_value'] ) {
				$sql   = "DELETE FROM {$wpdb->postmeta} WHERE meta_key = '%s' LIMIT %d";
				$count = $wpdb->query( $wpdb->prepare( $sql, $this->args['old_value'], $limit ) );
			} else {
				$sql   = "UPDATE {$wpdb->postmeta} SET meta_key = '%s' WHERE meta_key = '%s' LIMIT %d";
				$count = $wpdb->query( $wpdb->prepare( $sql, $this->args['new_value'], $this->args['old_value'], $limit ) );
			}

			return intval( $count );
		}

		$sql = "";
		$sql .= "SELECT meta_id ";
		$sql .= "FROM {$wpdb->postmeta} pm ";
		$sql .= "INNER JOIN {$wpdb->posts} ps ON ( pm.post_id = ps.ID ) ";
		$sql .= "WHERE ";
			$sql .= "pm.meta_key = '%s' AND ";
			$sql .= "ps.post_type = '%s'";
		$sql .= "LIMIT %d";

		$ids = $wpdb->get_results( $wpdb->prepare( $sql, $this->args['old_value'], $this->args['post_type'], $limit ) );
		$ids = implode( ', ', wp_list_pluck( $ids, 'meta_id' ) );

		if ( ! $ids ) {
			return 0;
		}

		if ( ! $this->args['new_value'] ) {
			$sql   = "DELETE FROM {$wpdb->postmeta} WHERE meta_id IN ( {$ids} ) ";
			$count = intval( $wpdb->query( $sql ) );
		} else {
			$sql   = "UPDATE {$wpdb->postmeta} SET meta_key = '%s' WHERE meta_id IN ( {$ids} ) ";
			$count = intval( $wpdb->query( $wpdb->prepare( $sql, $this->args['new_value'] ) ) );
		}

		return intval( $count );
	}
}

class VA_Upgrade_Theme_Options_4_0_0 extends APP_Progress_Upgrade_Step {

	/**
	 * Retrieves the items array to be processed.
	 *
	 * @global scbOptions $va_options
	 *
	 * @return array
	 */
	protected function _get_items() {
		global $va_options;

		return array(
			'google_maps_region'   => $va_options->map_provider_settings['google']['geo_region'],
			'google_maps_language' => $va_options->map_provider_settings['google']['geo_language'],
			'google_maps_unit'     => $va_options->map_provider_settings['google']['geo_unit'],
			'google_maps_api_key'  => $va_options->map_provider_settings['google']['api_key'],
			'google_color_scheme'  => isset( $va_options->map_provider_settings['google']['color_scheme'] ) ? $va_options->map_provider_settings['google']['color_scheme'] : 'cream',
		);
	}

	/**
	 * Retrieves total number of items to be processed withing current step.
	 *
	 * @return int
	 */
	public function get_total() {
		return count( $this->_get_items() );
	}

	/**
	 * Processes items.
	 *
	 * @param APP_Dynamic_Checkout $checkout Checkout object.
	 *
	 * @return int The number of actually processed items.
	 */
	public function progress( APP_Dynamic_Checkout $checkout ) {
		global $va_options;
		$items = $this->_get_items();
		$va_options->update( $items );
		return count( $items );
	}

}

class VA_Upgrade_Options_4_0_0 extends APP_Progress_Upgrade_Step {

	/**
	 * Retrieves the items array to be processed.
	 *
	 * @global scbOptions $va_options
	 *
	 * @return array
	 */
	protected function _get_items() {
		global $va_options;

		// Already cleaned, nothing to do.
		if ( ! $va_options->addons ) {
			return array();
		}

		$tax = VA_LISTING_CATEGORY;

		return array(
			'price'                     => $va_options->listing_price,
			'charge'                    => $va_options->listing_charge,
			'duration'                  => $va_options->listing_duration,
			'moderate'                  => $va_options->moderate_listings,
			'moderate_claimed_listings' => $va_options->moderate_claimed_listings,
			"included_{$tax}"           => $va_options->included_categories,
			"{$tax}_surcharges"         => $va_options->category_surcharges,
			'features'                  => array( 'custom_form' ),

			'addons' => array(
				VA_LISTING_PTYPE . '-featured-home' => array(
					'title'       => __( 'Feature on Homepage', APP_TD ),
					'enabled'     => $va_options->addons['featured-home']['enabled'],
					'price'       => $va_options->addons['featured-home']['price'],
					'duration'    => $va_options->addons['featured-home']['duration'],
					'period'      => $va_options->addons['featured-home']['period'],
					'period_type' => $va_options->addons['featured-home']['period_type'],
				),
				VA_LISTING_PTYPE . '-featured-cat'  => array(
					'title'       => __( 'Feature on Category', APP_TD ),
					'enabled'     => $va_options->addons['featured-home']['enabled'],
					'price'       => $va_options->addons['featured-home']['price'],
					'duration'    => $va_options->addons['featured-home']['duration'],
					'period'      => $va_options->addons['featured-home']['period'],
					'period_type' => $va_options->addons['featured-home']['period_type'],
				),
			),
		);
	}

	/**
	 * Retrieves total number of items to be processed withing current step.
	 *
	 * @return int
	 */
	public function get_total() {
		return count( $this->_get_items() );
	}

	/**
	 * Processes items.
	 *
	 * @param APP_Dynamic_Checkout $checkout Checkout object.
	 *
	 * @return int The number of actually processed items.
	 */
	public function progress( APP_Dynamic_Checkout $checkout ) {
		global $va_options, $vantage;

		$items = $this->_get_items();

		if ( ! empty( $items ) ) {
			/* @var $listings APP_Listing */
			$listings = $vantage->{VA_LISTING_PTYPE};
			$listings->options->update( $items );
			// cleanup migrated options.
			$va_options->cleanup();
		}

		return count( $items );
	}

}

class VA_Upgrade_Plans_Post_Type_4_0_0 extends APP_Progress_Upgrade_Step {

	/**
	 * Retrieves total number of items to be processed withing current step.
	 *
	 * @return int
	 */
	public function get_total() {
		global $wpdb;
		$totalposts = intval( $wpdb->get_var( "SELECT COUNT(ID) FROM $wpdb->posts WHERE post_type = 'pricing-plan'" ) );
		return $totalposts;
	}

	/**
	 * Processes items.
	 *
	 * @param APP_Dynamic_Checkout $checkout Checkout object.
	 *
	 * @return int The number of actually processed items.
	 */
	public function progress( APP_Dynamic_Checkout $checkout ) {
		global $wpdb;

		$sql   = "UPDATE {$wpdb->posts} SET post_type = '%s' WHERE post_type = '%s' LIMIT %d";
		$count = $wpdb->query( $wpdb->prepare( $sql, 'listing-pricing-plan', 'pricing-plan', 1000 ) );

		return intval( $count );
	}
}

class VA_Upgrade_Plans_P2P_4_0_0 extends APP_Progress_Upgrade_Step {

	/**
	 * Retrieves total number of items to be processed withing current step.
	 *
	 * @return int
	 */
	public function get_total() {
		global $wpdb;
		$totalposts = intval( $wpdb->get_var( "SELECT COUNT(ID) FROM $wpdb->posts WHERE post_type = 'listing-pricing-plan'" ) );
		return $totalposts;
	}

	/**
	 * Processes items.
	 *
	 * @param APP_Dynamic_Checkout $checkout Checkout object.
	 *
	 * @return int The number of actually processed items.
	 */
	public function progress( APP_Dynamic_Checkout $checkout ) {
		global $wpdb;

		$progress_data  = (array) $this->checkout->get_data( 'progress_data' );

		$plans = new WP_Query( array(
			'post_type'      => 'listing-pricing-plan',
			'posts_per_page' => 50,
			'offset'         => $progress_data[ $this->step_id ]['done'],
			'orderby'        => 'ID',
			'order'          => 'ASC',
		) );

		foreach ( $plans->posts as $plan ) {
			$old = $plan->post_name;
			$new = "listing-{$plan->ID}";

			$sql = "";
			$sql .= "UPDATE {$wpdb->p2pmeta} p2pm ";
			$sql .= "INNER JOIN {$wpdb->p2p} p2p ON ( p2p.p2p_id = p2pm.p2p_id ) ";
			$sql .= "INNER JOIN {$wpdb->posts} ps ON ( p2p.p2p_to = ps.ID ) ";
			$sql .= "SET p2pm.meta_value = '%s' ";
			$sql .= "WHERE ";
				$sql .= "p2pm.meta_value = '%s' AND ";
				$sql .= "ps.post_type = '%s' AND ";
				$sql .= "p2p.p2p_type = '%s'";

			$wpdb->query( $wpdb->prepare( $sql, $new, $old, VA_LISTING_PTYPE, APPTHEMES_ORDER_CONNECTION ) );
		}

		return count( $plans->posts );
	}
}

class VA_Upgrade_P2P_Order_Meta extends VA_Upgrade_Post_Meta_Key {

	/**
	 * Retrieves total number of items to be processed withing current step.
	 *
	 * @return int
	 */
	public function get_total() {
		global $wpdb;

		$sql = "";
		$sql .= "SELECT COUNT(meta_id) p2pm ";
		$sql .= "FROM {$wpdb->p2pmeta} p2pm ";
		$sql .= "INNER JOIN {$wpdb->p2p} p2p ON ( p2p.p2p_id = p2pm.p2p_id ) ";
		$sql .= "INNER JOIN {$wpdb->posts} ps ON ( p2p.p2p_to = ps.ID ) ";
		$sql .= "WHERE ";
			$sql .= "p2pm.meta_value = '%s' AND ";
			$sql .= "ps.post_type = '%s' AND ";
			$sql .= "p2p.p2p_type = '%s'";

		$total = intval( $wpdb->get_var( $wpdb->prepare( $sql, $this->args['old_value'], $this->args['post_type'], APPTHEMES_ORDER_CONNECTION ) ) );
		return $total;
	}

	/**
	 * Processes items.
	 *
	 * @param APP_Dynamic_Checkout $checkout Checkout object.
	 *
	 * @return int The number of actually processed items.
	 */
	public function progress( APP_Dynamic_Checkout $checkout ) {
		global $wpdb;

		$limit = $this->args['limit'];

		$sql = "";
		$sql .= "SELECT meta_id FROM {$wpdb->p2pmeta} p2pm ";
		$sql .= "INNER JOIN {$wpdb->p2p} p2p ON ( p2p.p2p_id = p2pm.p2p_id ) ";
		$sql .= "INNER JOIN {$wpdb->posts} ps ON ( p2p.p2p_to = ps.ID ) ";
		$sql .= "WHERE ";
			$sql .= "p2pm.meta_value = '%s' AND ";
			$sql .= "ps.post_type = '%s' AND ";
			$sql .= "p2p.p2p_type = '%s' ";
		$sql .= "LIMIT %d";

		$ids = $wpdb->get_results( $wpdb->prepare( $sql, $this->args['old_value'], $this->args['post_type'], APPTHEMES_ORDER_CONNECTION, $limit ) );
		$ids = implode( ', ', wp_list_pluck( $ids, 'meta_id' ) );

		if ( ! $ids ) {
			return 0;
		}

		$sql = "";
		$sql .= "UPDATE {$wpdb->p2pmeta} ";
		$sql .= "SET meta_value = '%s' ";
		$sql .= "WHERE meta_id IN ( {$ids} ) ";

		$count = intval( $wpdb->query( $wpdb->prepare( $sql, $this->args['new_value'] ) ) );

		return $count;
	}
}

class VA_Remove_Empty_Post_Meta extends VA_Upgrade_Post_Meta_Key {

	/**
	 * Retrieves total number of items to be processed withing current step.
	 *
	 * @return int
	 */
	public function get_total() {
		global $wpdb;

		$sql = "";
		$sql .= "SELECT COUNT(meta_id) pm ";
		$sql .= "FROM {$wpdb->postmeta} pm ";
		$sql .= "INNER JOIN {$wpdb->posts} ps ON ( pm.post_id = ps.ID ) ";
		$sql .= "WHERE ";
			$sql .= "pm.meta_key = '%s' AND ";
			$sql .= "pm.meta_value = 0 AND ";
			$sql .= "ps.post_type = '%s'";

		$total = intval( $wpdb->get_var( $wpdb->prepare( $sql, $this->args['old_value'], $this->args['post_type'] ) ) );
		return $total;
	}

	/**
	 * Processes items.
	 *
	 * @param APP_Dynamic_Checkout $checkout Checkout object.
	 *
	 * @return int The number of actually processed items.
	 */
	public function progress( APP_Dynamic_Checkout $checkout ) {
		global $wpdb;

		$limit = $this->args['limit'];

		$sql = "";
		$sql .= "SELECT meta_id ";
		$sql .= "FROM {$wpdb->postmeta} pm ";
		$sql .= "INNER JOIN {$wpdb->posts} ps ON ( pm.post_id = ps.ID ) ";
		$sql .= "WHERE ";
			$sql .= "pm.meta_key = '%s' AND ";
			$sql .= "pm.meta_value = 0 AND ";
			$sql .= "ps.post_type = '%s'";
		$sql .= "LIMIT %d";

		$ids = $wpdb->get_results( $wpdb->prepare( $sql, $this->args['old_value'], $this->args['post_type'], $limit ) );
		$ids = implode( ', ', wp_list_pluck( $ids, 'meta_id' ) );

		if ( ! $ids ) {
			return 0;
		}

		$sql = "DELETE FROM {$wpdb->postmeta} WHERE meta_id IN ( {$ids} ) ";

		$count = intval( $wpdb->query( $sql ) );

		return $count;
	}
}

class VA_Upgrade_Plans_Period_Type_1_3_1 extends APP_Progress_Upgrade_Step {

	/**
	 * Retrieves total number of items to be processed withing current step.
	 *
	 * @return int
	 */
	public function get_total() {
		global $wpdb;

		$sql = "";
		$sql .= "SELECT COUNT(ID) ps ";
		$sql .= "FROM {$wpdb->posts} ps ";
		$sql .= "LEFT JOIN $wpdb->postmeta pm ON (ps.ID = pm.post_id AND pm.meta_key = 'period') ";
		$sql .= "WHERE ";
			$sql .= "ps.post_type = '%s' AND ";
			$sql .= "( pm.post_id IS NULL )";

		$totalposts = intval( $wpdb->get_var( $wpdb->prepare( $sql, APPTHEMES_PRICE_PLAN_PTYPE ) ) );
		return $totalposts;
	}

	/**
	 * Processes items.
	 *
	 * @param APP_Dynamic_Checkout $checkout Checkout object.
	 *
	 * @return int The number of actually processed items.
	 */
	public function progress( APP_Dynamic_Checkout $checkout ) {

		$query = new WP_Query( array(
			'post_type'      => APPTHEMES_PRICE_PLAN_PTYPE,
			'posts_per_page' => 50,
			'fields'        => 'ids',
			'meta_query'    => array(
				array(
					'key'     => 'period',
					'compare' => 'NOT EXISTS',
				),
			),
		) );

		if ( $query->post_count > 0 ) {
			foreach ( $query->posts as $k => $post_id ) {

				$duration = get_post_meta( $post_id, 'duration', true );

				if ( $duration > 90 ) {
					$period = min( 12, ceil( $duration / 30 ) );
					$period_type = APP_Order::RECUR_PERIOD_TYPE_MONTHS;
					$duration = $period * 30;
				} else {
					$period = $duration;
					$period_type = APP_Order::RECUR_PERIOD_TYPE_DAYS;
				}

				update_post_meta( $post_id, 'duration', $duration );
				update_post_meta( $post_id, 'period', $period );
				update_post_meta( $post_id, 'period_type', $period_type );
			}
		}

		return $query->post_count;
	}
}

class VA_Upgrade_Featured_Image_4_0_0 extends APP_Progress_Upgrade_Step {

	/**
	 * Retrieves total number of items to be processed withing current step.
	 *
	 * @return int
	 */
	public function get_total() {
		global $wpdb;

		$sql = "";
		$sql .= "SELECT COUNT(ID) ps ";
		$sql .= "FROM {$wpdb->posts} ps ";
		$sql .= "LEFT JOIN $wpdb->postmeta pm ON (ps.ID = pm.post_id AND pm.meta_key = '_thumbnail_id') ";
		$sql .= "WHERE ";
			$sql .= "ps.post_type = '%s' AND ";
			$sql .= "( pm.post_id IS NULL )";

		$totalposts = intval( $wpdb->get_var( $wpdb->prepare( $sql, VA_LISTING_PTYPE ) ) );
		return $totalposts;
	}

	/**
	 * Processes items.
	 *
	 * @param APP_Dynamic_Checkout $checkout Checkout object.
	 *
	 * @return int The number of actually processed items.
	 */
	public function progress( APP_Dynamic_Checkout $checkout ) {

		$offset = (int) $checkout->get_data( $this->step_id . '_offset' );

		$query = new WP_Query( array(
			'post_type'      => VA_LISTING_PTYPE,
			'posts_per_page' => 50,
			'fields'         => 'ids',
			'offset'         => $offset,
			'orderby'        => 'ID',
			'meta_query'     => array(
				array(
					'key'     => '_thumbnail_id',
					'compare' => 'NOT EXISTS',
				),
			),
		) );

		$no_thumb = 0;

		if ( $query->post_count > 0 ) {
			foreach ( $query->posts as $k => $post_id ) {
				$attachments = va_get_post_attachments( $post_id, -1, VA_ATTACHMENT_GALLERY, 'ids' );
				if ( ! empty( $attachments ) ) {
					set_post_thumbnail( $post_id, $attachments[0] );
				} else {
					$no_thumb++;
				}
			}
		}

		$offset += $no_thumb;
		$checkout->add_data( $this->step_id . '_offset', $offset );

		return count( $query->posts );
	}
}

class VA_Upgrade_Geodata_4_0_0 extends APP_Progress_Upgrade_Step {

	/**
	 * Retrieves total number of items to be processed withing current step.
	 *
	 * @return int
	 */
	public function get_total() {
		global $wpdb;

		scb_register_table( 'app_geodata' );

		$sql = "";
		$sql .= "SELECT COUNT(gd.post_id) ";
		$sql .= "FROM {$wpdb->app_geodata} gd ";
		$sql .= "LEFT JOIN $wpdb->postmeta pm ON (gd.post_id = pm.post_id AND pm.meta_key = 'geo_lat') ";
		$sql .= "WHERE pm.post_id IS NULL AND gd.lat != 0";

		$totalposts = intval( $wpdb->get_var( $sql ) );
		return $totalposts;
	}

	/**
	 * Processes items.
	 *
	 * @param APP_Dynamic_Checkout $checkout Checkout object.
	 *
	 * @global wpdb $wpdb
	 *
	 * @return int The number of actually processed items.
	 */
	public function progress( APP_Dynamic_Checkout $checkout ) {
		global $wpdb;

		$limit = 1000;
		$count = 0;

		scb_register_table( 'app_geodata' );

		$sql = "";
		$sql .= "SELECT gd.* ";
		$sql .= "FROM {$wpdb->app_geodata} gd ";
		$sql .= "LEFT JOIN {$wpdb->postmeta} pm ON (gd.post_id = pm.post_id AND pm.meta_key = 'geo_lat') ";
		$sql .= "WHERE pm.post_id IS NULL AND gd.lat != 0 ";
		$sql .= "LIMIT {$limit}";

		$geodata = $wpdb->get_results( $sql );

		foreach ( $geodata as $row ) {
			foreach ( array( 'lat', 'lng' ) as $key ) {
				$count += $wpdb->insert( $wpdb->postmeta, array(
					'post_id'    => $row->post_id,
					'meta_key'   => "geo_{$key}",
					'meta_value' => $row->{$key},
				) );
			}
		}

		return $count/2;
	}

	/**
	 * Finish Checkout Step
	 */
	public function finish_step() {
		parent::finish_step();
		scb_uninstall_table( 'app_geodata' );
	}
}

class VA_Upgrade_Checkout_Data extends APP_Progress_Upgrade_Step {

	/**
	 * Retrieves total number of items to be processed withing current step.
	 *
	 * @return int
	 */
	public function get_total() {
		global $wpdb;

		$sql = "";
		$sql .= "SELECT COUNT(ID) ps ";
		$sql .= "FROM {$wpdb->posts} ps ";
		$sql .= "INNER JOIN {$wpdb->postmeta} pm ON ( pm.post_id = ps.ID ) ";
		$sql .= "WHERE ";
			$sql .= "pm.meta_key = 'checkout_type' AND ";
			$sql .= "pm.meta_value IN ('create-listing', 'renew-listing', 'upgrade-listing', 'claim-listing') AND ";
			$sql .= "ps.post_type = 'transaction' AND ";
			$sql .= "ps.post_status IN ('tr_pending', 'tr_completed')";

		$total = intval( $wpdb->get_var( $sql ) );
		return $total;
	}

	/**
	 * Processes items.
	 *
	 * @param APP_Dynamic_Checkout $checkout Checkout object.
	 *
	 * @global wpdb $wpdb
	 *
	 * @return int The number of actually processed items.
	 */
	public function progress( APP_Dynamic_Checkout $checkout ) {
		global $wpdb, $vantage;

		$limit = 50;
		/* @var $types_map APP_View_Process[] */
		$types_map = array(
			'create-listing'  => $vantage->listing->view_process_new,
			'renew-listing'   => $vantage->listing->view_process_renew,
			'upgrade-listing' => $vantage->listing->view_process_upgrade,
			'claim-listing'   => APP_View_Process::get_process( VA_LISTING_PTYPE, 'claim' ),
		);

		$sql = "";
		$sql .= "SELECT post_id, meta_value ";
		$sql .= "FROM {$wpdb->postmeta} pm ";
		$sql .= "INNER JOIN {$wpdb->posts} ps ON ( pm.post_id = ps.ID ) ";
		$sql .= "WHERE ";
			$sql .= "pm.meta_key = 'checkout_type' AND ";
			$sql .= "pm.meta_value IN ('create-listing', 'renew-listing', 'upgrade-listing', 'claim-listing') AND ";
			$sql .= "ps.post_type = 'transaction' AND ";
			$sql .= "ps.post_status IN ('tr_pending', 'tr_completed') ";
		$sql .= "LIMIT %d";

		$orders = $wpdb->get_results( $wpdb->prepare( $sql, $limit ) );

		$multi_plans = $vantage->listing->multi_plans;
		if ( ! $multi_plans ) {
			$multi_plans = new APP_Listing_Plans( $vantage->listing );
		}
		$multi_plans->init();

		foreach ( $vantage->listing->plans->get_plans() as $plan ) {
			$plans[] = $plan->get_type();
		}

		foreach ( $orders as $order_info ) {
			$type  = $order_info->meta_value;
			$order = appthemes_get_order( $order_info->post_id );
			$hash  = get_post_meta( $order->get_id(), 'checkout_hash', true );
			$item  = $this->_get_order_listing_item( $order );
			$plan  = $item->post_type;
			$proc  = $types_map[ $type ];

			$order_item_types = wp_list_pluck( $order->get_items(), 'type' );
			$valid_plans = array_intersect( $plans, $order_item_types );

			if ( ! empty( $valid_plans ) ) {
				$plan = array_shift( $valid_plans );

				if ( 'upgrade-listing' !== $type ) {
					$plan_obj = $vantage->listing->plans->get_plan( $plan );
					foreach ( array( VA_ITEM_FEATURED_HOME, VA_ITEM_FEATURED_CAT ) as $addon ) {
						if ( $plan_obj->{$addon} ) {
							$order->add_item( $addon, 0, $item->ID );
						}
					}
				}
			}

			$checkout = new APP_Dynamic_Checkout( $proc->get_checkout_type(), $hash );

			update_post_meta( $order->get_id(), 'checkout_type', $proc->get_checkout_type() );

			if ( 'tr_pending' === $order->get_status() ) {
				$expire = 14 * DAY_IN_SECONDS;
				$steps_completed = array( 'create-order' );

				$query_args = array(
					'step' => 'gateway-process',
					'hash' => $hash,
				);

				$url = add_query_arg( $query_args, $proc->get_process_url( $item->ID ) );
				update_post_meta( $order->get_id(), 'complete_url', $url );

				$query_args = array(
					'step' => 'gateway-select',
					'hash' => $hash,
				);

				$url = add_query_arg( $query_args, $proc->get_process_url( $item->ID ) );
				update_post_meta( $order->get_id(), 'cancel_url', $url );
			} else {
				$expire = 0;
				$steps_completed = array( 'gateway-process' );

				$query_args = array(
					'step' => 'activate-order',
					'hash' => $hash,
				);

				$url = add_query_arg( $query_args, $proc->get_process_url( $item->ID ) );
				update_post_meta( $order->get_id(), 'activate_url', $url );
			}

			$checkout->set_expiration( $expire );
			$checkout->add_data( 'checkout_type', $proc->get_checkout_type() );
			$checkout->add_data( 'listing_id', $item->ID );
			$checkout->add_data( 'order_id', $order->get_id() );
			$checkout->add_data( 'plan', $plan );
			$checkout->add_data( 'step-completed', $steps_completed );

			if ( $order->is_recurring() ) {
				$checkout->add_data( 'recurring', true );
			}

			if ( 'claim-listing' === $type ) {
				$connection = "_in_process_{$proc->get_checkout_type()}_by_{$order->get_author()}";
				$claim_cats = get_post_meta( $order->get_id(), 'claim_categories', true );
				if ( $claim_cats ) {
					$checkout->add_data( 'optional_data', array( 'tax_input' => array( VA_LISTING_CATEGORY => $claim_cats ) ) );
				}
				$checkout->add_data( 'initiator', $order->get_author() );
			} else {
				$connection = $proc->get_connection_type();
			}

			update_post_meta( $item->ID, $connection, $hash );
		}

		return count( $orders );
	}

	/**
	 * Retrieves a listing item connected to given order.
	 *
	 * @param APP_Order $order
	 * @return WP_Post
	 */
	private function _get_order_listing_item( $order ) {
		foreach ( $order->get_items() as $item ) {
			if ( isset( $item['post'] ) && in_array( $item['post']->post_type, array( 'listing', 'event' ) ) ) {
				return $item['post'];
			}
		}
	}
}

class VA_Delete_Expired_Transients extends APP_Progress_Upgrade_Step {

	/**
	 * Retrieves total number of items to be processed withing current step.
	 *
	 * @return int
	 */
	public function get_total() {
		global $wpdb;
		$time = time();
		$sql = "SELECT COUNT(*) FROM {$wpdb->options} WHERE option_name LIKE '\_transient\_timeout\_%' and option_value < '{$time}'";

		$totalposts = intval( $wpdb->get_var( $sql ) );
		return $totalposts;
	}

	/**
	 * Processes items.
	 *
	 * @param APP_Dynamic_Checkout $checkout Checkout object.
	 *
	 * @global wpdb $wpdb
	 *
	 * @return int The number of actually processed items.
	 */
	public function progress( APP_Dynamic_Checkout $checkout ) {
		global $wpdb;

		$limit = 1000;
		$time  = time();

		$sql = "";
		$sql .= "SELECT option_id ";
		$sql .= "FROM {$wpdb->options} ";
		$sql .= "WHERE ";
			$sql .= "option_name LIKE '\_transient\_timeout\_%' AND ";
			$sql .= "option_value < '{$time}' ";
		$sql .= "LIMIT {$limit}";

		$results = $wpdb->get_results( $sql );
		$ids     = implode( ', ', wp_list_pluck( $results, 'option_id' ) );
		if ( ! $ids ) {
			return 0;
		}

		$sql = "";
		$sql .= "DELETE FROM t1, t2 ";
		$sql .= "USING {$wpdb->options} t1 ";
		$sql .= "LEFT JOIN {$wpdb->options} t2 ON t2.option_name = REPLACE(t1.option_name, '_timeout', '') ";
		$sql .= "WHERE t1.option_id IN ( {$ids} ) ";

		$wpdb->query( $sql );

		return count( $results );
	}
}

class VA_Upgrade_Order_Item_Addons extends APP_Progress_Upgrade_Step {

	private $query_count = 0;

	/**
	 * Retrieves total number of items to be processed withing current step.
	 *
	 * @return int
	 */
	public function get_total() {
		global $wpdb;

		$sql = "SELECT COUNT(ID) FROM {$wpdb->posts} WHERE post_type = '" . APPTHEMES_ORDER_PTYPE . "'";

		$totalposts = intval( $wpdb->get_var( $sql ) );
		return $totalposts;
	}

	/**
	 * Processes items.
	 *
	 * @param APP_Dynamic_Checkout $checkout Checkout object.
	 *
	 * @global wpdb $wpdb
	 *
	 * @return int The number of actually processed items.
	 */
	public function progress( APP_Dynamic_Checkout $checkout ) {
		add_filter( 'parse_query', array( $this, 'parse_query' ) );
		add_filter( 'the_posts', array( $this, 'the_posts' ), 10, 2 );
		appthemes_upgrade_item_addons();
		remove_filter( 'parse_query', array( $this, 'parse_query' ) );

		return $this->query_count;
	}

	public function parse_query( $wp_query ) {
		if ( APPTHEMES_ORDER_PTYPE !== $wp_query->get( 'post_type' ) ) {
			return;
		}
		remove_filter( 'parse_query', array( $this, 'parse_query' ) );

		$checkout = appthemes_get_checkout();
		$progress_data = $checkout->get_data( 'progress_data' );

		$limit = 3;
		$wp_query->set( 'upgrade_order_item_addons', 1 );
		$wp_query->set( 'nopaging', false );
		$wp_query->set( 'posts_per_page', $limit );
		$wp_query->set( 'offset', $progress_data[ $this->step_id ]['done'] );
	}

	public function the_posts( $posts, $wp_query ) {
		if ( $wp_query->get( 'upgrade_order_item_addons' ) ) {
			$this->query_count = count( $posts );
			remove_filter( 'the_posts', array( $this, 'the_posts' ), 10, 2 );
		}
		return $posts;
	}
}