<?php
/**
 * User page in the administration panels.
 *
 * @package Vantage\Templates
 * @author AppThemes
 * @since 4.0.0
 */

 /**
	* Filters the header and footer output of custom columns in the Users list table.
	*
	* @since 4.0.0
	*
	* @param array $column Column array output.
	*/
function va_add_user_columns( $column ) {
	$column['listings'] = _x( 'Listings', 'user page column name', APP_TD );
	return $column;
}
add_filter( 'manage_users_columns', 'va_add_user_columns' );

/**
 * Filters the display output of custom columns in the Users list table.
 *
 * @since 4.0.0
 *
 * @param string $output      Custom column output. Default empty.
 * @param string $column_name Column name.
 * @param int    $user_id     ID of the currently-listed user.
 */
function va_add_user_column_values( $output, $column_name, $user_id ) {

	$r         = '';
	$post_type = VA_LISTING_PTYPE;

	switch ( $column_name ) {
		case 'listings' :
			$numposts = count_user_posts( $user_id, $post_type );
			if ( $numposts > 0 ) {
				$r .= "<a href='edit.php?post_type=$post_type&author=$user_id' class='edit'>";
				$r .= '<span aria-hidden="true">' . $numposts . '</span>';
				$r .= '<span class="screen-reader-text">' . sprintf( _n( '%s listing by this author', '%s listings by this author', $numposts, APP_TD ), number_format_i18n( $numposts ) ) . '</span>';
				$r .= '</a>';
			} else {
				$r .= 0;
			}
			return $r;
			break;
		default:
	}

	return $output;
}
add_filter( 'manage_users_custom_column', 'va_add_user_column_values', 10, 3 );
