<?php
/**
 * Ajax process execution class
 *
 * @todo Eventually move this into framework. Then use the filter for non-shared actions.
 *
 * @package Vantage\Ajax
 * @since 4.0.0
 */

/**
 * Handle the ajax processing.
 *
 * @since 4.0.0
 */
class APP_Ajax {

	/**
	 * Constructor.
	 */
	public function __construct() {
		add_action( 'init', array( $this, 'register_ajax_calls' ) );
	}

	/**
	 * Dynamically register all ajax actions based on handle name.
	 *
	 * @since 4.0.0
	 */
	public function register_ajax_calls() {

		// Script for sending ajax requests with JSON responses. Only need in admin?
		wp_enqueue_script( 'wp-util' );

		// Whitelist of all post action handles allowed.
		$core_actions_post = array(
			'updater-plugin-notice',
		);

		/**
		 * Filter the ajax post actions.
		 *
		 * @since 4.0.0
		 *
		 * @param array $core_actions_post An array of ajax post action handles.
		 */
		$core_actions_post = apply_filters( 'appthemes_register_ajax_post_action', $core_actions_post );

		// Register core ajax calls.
		if ( ! empty( $_POST['action'] ) && in_array( $_POST['action'], $core_actions_post ) ) {

			add_action( 'wp_ajax_' . $_POST['action'], 'appthemes_ajax_' . str_replace( '-', '_', $_POST['action'] ), 1 );

			// Allow not logged in users to run ajax requests. Front-end only.
			if ( ! is_user_logged_in() ) {
				add_action( 'wp_ajax_nopriv_' . $_POST['action'], 'appthemes_ajax_' . str_replace( '-', '_', $_POST['action'] ), 1 );
			}
		}
	}

}

new APP_Ajax();
