<?php
/**
 * Autoloader
 *
 * @package Vantage
 *
 * @since 4.0.0
 */

/**
 * Autoloader class.
 *
 * Allows to use file prefix 'class-'.
 */
class VA_Autoload extends P2P_Autoload {

	/**
	 * Registers autoloader in the system.
	 *
	 * @param string $prefix  Class prefix (i.e. APP_ or VA_).
	 * @param string $basedir Class file base directory.
	 */
	static function register( $prefix, $basedir ) {
		$loader = new self( $prefix, $basedir );

		spl_autoload_register( array( $loader, 'autoload' ) );
	}

	/**
	 * Autoload callback.
	 *
	 * @param string $class Class name.
	 */
	function autoload( $class ) {
		if ( '\\' === $class[0] ) {
			$class = substr( $class, 1 );
		}

		if ( strpos( $class, $this->prefix ) !== 0 ) {
			return;
		}

		$path = str_replace( $this->prefix, '', $class );
		$path = str_replace( '_', '-', strtolower( $path ) );

		$file = sprintf( '%s/class-%s.php', $this->basedir, $path );

		if ( is_file( $file ) ) {
			require $file;
		}
	}
}

