<?php
/**
 * Refine listing search class.
 *
 * @package Vantage\Search
 * @author AppThemes
 * @since 4.0.0
 */

/**
 * The refine search listing class.
 *
 * @since 4.0.0
 */
class VA_Refine_Search {

	/**
	 * Constructor
	 */
	public function __construct() {
		add_action( 'va_listing_refine_search_fields_after', array( $this, 'radius_field' ) );
		add_action( 'va_listing_header_search_fields_after', array( $this, 'radius_field' ) );
		add_action( 'va_listing_refine_search_fields_after', array( $this, 'orderby_field' ) );
	}

	/**
	 * Add the radius slider and hidden fields.
	 *
	 * @since 4.0.0
	 *
	 * @return void
	 */
	public function radius_field() {
		global $va_options;

		// Only show the radius slider if we've got a point to work from.
		if ( ! empty( $_GET['lat'] ) && ! empty( $_GET['lng'] ) ) :
	?>
		<div class="refine-search-field-wrap search-radius">
			<label for="radius"><?php _e( 'Radius', APP_TD ); ?></label>
			<div class="slider" data-slider data-start="1" data-initial-start="<?php echo ! empty( $_GET[ 'radius' ] ) ? absint( $_GET[ 'radius' ] ) : 50; ?>" data-step="1">
				<span class="slider-handle" data-slider-handle role="slider" tabindex="1" aria-controls="sliderRadius"></span>
				<span class="slider-fill" data-slider-fill></span>
				<input type="text" name="radius" id="sliderRadius"> <em><?php 'km' == $va_options->google_maps_unit ? _e( 'km', APP_TD ) : _e( 'mi', APP_TD ); ?></em>
			</div>
		</div><!-- .refine-search-field-wrap -->
	<?php endif; ?>
	<input type="hidden" name="st" value="<?php echo esc_attr( VA_LISTING_PTYPE ); ?>">
	<input type="hidden" name="lat" value="<?php echo ! empty( $_GET[ 'lat' ] ) ? esc_attr( $_GET[ 'lat' ] ) : 0; ?>">
	<input type="hidden" name="lng" value="<?php echo ! empty( $_GET[ 'lng' ] ) ? esc_attr( $_GET[ 'lng' ] ) : 0; ?>">
	<?php
	}

	/**
	 * Add the order by dropdown.
	 *
	 * @since 4.0.0
	 *
	 * @return void
	 */
	public function orderby_field() {
		$current_orderby = get_query_var( 'orderby' );

		if ( is_array( $current_orderby ) ) {
			$current_orderby = array_keys( $current_orderby );
		} else {
			$current_orderby = (array) $current_orderby;
		}
?>
		<label for="orderby"><?php _e( 'Order By', APP_TD ); ?>
			<select id="orderby" name="orderby">
				<option value=""><?php _e( 'Relevance' ); ?></option>
				<?php
				/**
				 * Filters the listing order by values dropdown menu.
				 *
				 * @since 4.0.0
				 *
				 * @param array $orderby_values An array of order by values.
				 */
				$orderby_values = apply_filters( 'va_orderby_values_dropdown', array(
					'title'    => __( 'Alphabetical', APP_TD ),
					'newest'   => __( 'Newest', APP_TD ),
					//'distance' => __( 'Distance', APP_TD ),
				) );

				$selected = '';
				foreach ( $orderby_values as $value => $label ) {
					$_selected = '';
					if ( in_array( $value, $current_orderby, true ) && ! $selected ) {
						$_selected = selected( $value, $value, false );
						$selected  = $_selected;
					}

					echo "\t" . '<option value="' . esc_attr( $value ) . '"' . $_selected . ">$label</option>\n";
				}
			?>
			</select>
		</label>
<?php
	}

}

new VA_Refine_Search();
