<?php
/**
 * Shortcode classes.
 *
 * @package Vantage\Shortcodes
 * @author AppThemes
 * @since 4.0.0
 */

/**
 * Vantage Shortcodes.
 *
 * @since 4.0.0
 */
class VA_Shortcodes {

	/**
	 * Constructor
	 */
	public function __construct() {

		add_shortcode( 'vantage_listing_categories',  array( $this, 'output_listing_categories' ) );
		add_shortcode( 'vantage_typed_elements', array( $this, 'typed_elements' ) );
	}

	/**
	 * Listing categories shortcode
	 *
	 * Displays a hierarchical list of all listing categories.
	 *
	 * @since 4.0.0
	 *
	 * @access public
	 * @param array $args
	 * @return string
	 */
	public function output_listing_categories( $atts ) {

		extract( shortcode_atts( array(
				'id' => '',
			), $atts
		) );

		ob_start();
		?>
			<div class="listing-cats listing-cats-page row">
				<?php echo va_cat_menu_drop_down( 'dir' ); ?>
			</div>
		<?php
		return ob_get_clean();
	}

	/**
	 * Get the typed elements shortcode.
	 *
	 * Usage: [vantage_typed_elements text="hello dolly, wasssup fool??, and more stuff"]
	 *
	 * @since 4.0.0
	 *
	 * @param array $atts The shortcode arguments.
	 */
	static function typed_elements( $atts ) {

		extract( shortcode_atts( array(
				'text' => '',
			), $atts
		) );

		if ( ! $text ) {
			return;
		}

		$text_array = array_map( 'trim', explode( ',', strip_tags( $text ) ) );

		return '<script>/* <![CDATA[ */var typedStrings = ' . json_encode( $text_array ) . '/* ]]> */</script>';
	}
}

new VA_Shortcodes();
