<?php
/**
 * Contains custom widget class info.
 *
 * @package Vantage\Widgets
 * @author AppThemes
 * @since 4.0.0
 */

/**
 * Vantage Widget base class.
 */
class VA_Widget extends APP_Widget {

	/**
	 * Echo the widget content.
	 *
	 * @param array $args     Display arguments including before_title,
	 *                        after_title, before_widget, and after_widget.
	 * @param array $instance The settings for the particular instance of the
	 *                        widget.
	 */
	public function widget( $args, $instance ) {
		global $wp_query;

		$_instance = null;

		// Preserve query var if it was set somewhere else.
		if ( $wp_query->get( 'instance' ) ) {
			$_instance = $wp_query->get( 'instance' );
		}

		ob_start();

		parent::widget( $args, $instance );

		$content = ob_get_clean();

		// Restore query var.
		if ( $_instance ) {
			$wp_query->set( 'instance', $_instance );
		}

		/**
		 * Filter the widget content.
		 *
		 * @since 4.0.0
		 *
		 * @param string $id The widget ID.
		 * @param string $content   The widget content.
		 * @param array $instance   The widget options.
		 */
		echo apply_filters( $this->id_base, $content, $instance );
	}

	/**
	 * Retrieves form fields in scbForm format.
	 *
	 * Examples of definition some specific fields:
	 * 1. Number field
	 *
	 *		array(
	 *			'type'  => 'number',
	 *			'name'  => 'mynumber',
	 *			'desc'  => __( 'Number to show:', APP_TD ),
	 *			'extra' => array(
	 *				'class' => 'widefat',
	 *				'min'   => 1,
	 *				'max'   => 100,
	 *				'step'  => 1,
	 *			),
	 *		),
	 *
	 * 2. Color Picker
	 *		array(
	 *			'type' => 'colorpicker',
	 *			'name' => 'mycolorpicker',
	 *			'desc' => __( 'My Color:', APP_TD ),
	 *			'extra' => array(
	 *				'data-default-color' => '#f1ff1f',
	 *				'class'              => 'color-picker-hex',
	 *			),
	 *		),
	 *
	 * @return array Form fields array.
	 */
	protected function form_fields() {
		return parent::form_fields();
	}

	/**
	 * Build out the widget options.
	 *
	 * @since 4.0.0
	 *
	 * @see APP_Widget::form()
	 *
	 * @param array $instance Current settings.
	 * @return void
	 */
	public function form( $instance ) {
		foreach ( $this->form_fields() as $field ) {
			if ( 'colorpicker' === $field['type'] ) {
				wp_enqueue_script( 'wp-color-picker' );
				wp_enqueue_style( 'wp-color-picker' );
				?>
				<script>
					jQuery(document).ready(function($){
						$( 'input[name="<?php echo esc_attr( $this->get_field_name( $field['name'] ) ); ?>"]' )
							.wpColorPicker()
							.closest( '.wp-picker-container' )
							.css( 'display','block' );
					});
				</script>
				<?php

			}
		}
		parent::form( $instance );
	}

	/**
	 *
	 * @param type $value
	 * @param scbCustomField $inst
	 */
	public function _image_control( $value, $inst ) {

		$name = $inst->name;
		$name = array_pop( $name );

		wp_enqueue_media();

		ob_start();
		?>
		<p style="margin-bottom: 0;">
			<label for="<?php echo esc_attr( $this->get_field_id( $name ) ); ?>"><?php echo $inst->desc; ?></label>
		</p>
		<p style="margin-top: 3px;">
			<a href="#" class="button-secondary <?php echo esc_attr( $this->get_field_id( $name ) ); ?>-add"><?php _e( 'Choose Image', APP_TD ); ?></a>
		</p>
		<p>
			<input type="text" class="widefat" id="<?php echo esc_attr( $this->get_field_id( $name ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( $name ) ); ?>"value="<?php echo esc_attr( $value ); ?>" placeholder="http://" />
		</p>
		<script>
			jQuery( document ).on( 'ready', function( $ ) {
				var <?php echo esc_js( $name ); ?> = new themeImageWidget.MediaManager({
					target: '<?php echo esc_attr( $this->get_field_id( $name ) ); ?>',
				});
			});
		</script>
		<?php

		return ob_get_clean();
	}
}
