<?php
/**
 * Main theme core file
 *
 * @package Vantage
 * @since 1.0.0
 */

/**
 * Retrieve all of the public view supported listing statuses.
 *
 * @todo Use get_post_types() and get_post_type() functions!!!
 *
 * @since 4.0.0
 *
 * @return array List of public listing statuses.
 */
function va_public_listing_statuses() {

	$statuses = array(
	'publish' => __( 'Live', APP_TD ),
	'pending' => __( 'Pending', APP_TD ),
	'expired' => __( 'Expired', APP_TD ),
	'draft'   => __( 'Draft', APP_TD ),
	);

	/**
	 * Filter the custom post public statuses for listings.
	 *
	 * @since 4.0.0
	 */
	return apply_filters( 'va_public_listing_statuses', $statuses );
}

/**
 * Get post statuses used for listings.
 *
 * @return array
 */
function va_listing_post_statuses() {

$post_status['expired'] = array(
		'label'     => _x( 'Expired', 'listing post status label', APP_TD ),
		'protected' => true,
	);

	$post_status['deleted'] = array(
		'label' => _x( 'Deleted', 'listing post status label', APP_TD ),
	);

	/**
	 * Filter the custom post statuses for listings.
	 *
	 * @since 4.0.0
	 */
	return apply_filters( 'va_listing_post_statuses', $post_status );
}


/**
 * Register custom post statuses.
 *
 * @todo Move this to class-business-listing.php?
 *
 * @return void
 */
function va_register_post_statuses() {

	// Get all the declared post statuses.
	$post_statuses = va_listing_post_statuses();

	$defaults = array(
		'public'                    => false,
		'exclude_from_search'       => false,
		'show_in_admin_all_list'    => true,
		'show_in_admin_status_list' => true,
	);

	// Loop through and register post status.
	foreach ( $post_statuses as $key => $args ) {
		$args['label_count'] = _n_noop( $args['label'] . ' <span class="count">(%s)</span>', $args['label'] . ' <span class="count">(%s)</span>' );
		$args = wp_parse_args( $args, $defaults );
		register_post_status( $key, $args );
	}

	va_reorder_post_statuses();
}
add_action( 'init', 'va_register_post_statuses', 1000 );


/**
* Adds custom post statuses to the edit listing admin screen.
*
* @since 4.0.0
*
* @return void
*/
function add_to_post_status_dropdown() {
	global $post, $post_type;

	// Only show on the listing post type screen.
	if ( VA_LISTING_PTYPE !== $post_type ) {
		return;
	}

	$options = $display = '';

	foreach ( va_listing_post_statuses() as $status => $args ) {

		$selected = selected( $post->post_status, $status, false );

		// If post status is selected, remember it.
		$selected && $display = $args[ 'label' ];

		// Build the options.
		$options .= "<option{$selected} value='{$status}'>{$args[ 'label' ]}</option>";
	}
	?>
	<script>
	jQuery( function( $ ) {
		<?php if ( ! empty( $display ) ) : ?>
		$( '#post-status-display' ).html( '<?php echo $display; ?>' );
		<?php endif; ?>
		$( 'select#post_status' ).append( "<?php echo $options; ?>" );
	} );
	</script>
<?php
}
add_action( 'post_submitbox_misc_actions', 'add_to_post_status_dropdown');


/**
 * Reorders post statuses.
 *
 * @return void
 */
function va_reorder_post_statuses() {
	global $wp_post_statuses;

	if ( ! isset( $wp_post_statuses['pending-claimed'] ) ) {
		return;
	}

	$new_statuses = array();
	$pending_claimed = $wp_post_statuses['pending-claimed'];
	unset( $wp_post_statuses['pending-claimed'] );
	foreach ( $wp_post_statuses as $wp_post_status_name => $wp_post_status ) {
		$new_statuses[ $wp_post_status_name ] = $wp_post_status;

		if ( 'pending' == $wp_post_status_name ) {
			$new_statuses['pending-claimed'] = $pending_claimed;
		}
	}

	$wp_post_statuses = $new_statuses;
}


/**
 * Overrides the css class for custom background image.
 *
 * @since 1.x.x
 *
 * @return void
 */
function va_custom_background_cb() {
	ob_start();
	_custom_background_cb(); // Default handler
	$style = ob_get_clean();
	$style = str_replace( 'body.custom-background', '#content.off-canvas-content', $style );
	echo $style;
}

function _va_setup_build_search_index() {

	if ( ! current_theme_supports( 'app-search-index' ) ) {
		return;
	}

	$args = array();

	if ( is_admin() ) {
		$args['limit'] = 50;
	}

	add_filter( 'appthemes_handle_listing_form', 'appthemes_update_search_index' );

	new APP_Build_Search_Index( $args );
}
add_action( 'init', '_va_setup_build_search_index', 100 );


function va_register_search_index_listing_post_type() {

	if ( ! current_theme_supports( 'app-search-index' ) ) {
		return;
	}

	$listing_index_args = array(
		'meta_keys'  => array( 'address', 'facebook', 'twitter', 'website', 'phone' ),
		'taxonomies' => array( VA_LISTING_CATEGORY, VA_LISTING_TAG ),
	);

	APP_Search_Index::register( VA_LISTING_PTYPE, $listing_index_args );
}
add_action( 'init', 'va_register_search_index_listing_post_type', 10 );


function va_search_index_enabled() {

	if ( ! current_theme_supports( 'app-search-index' ) ) {
		return false;
	}

	return apply_filters( 'va_search_index_enabled', appthemes_get_search_index_status() );
}


function va_update_search_index_listing_custom_fields( $args, $post ) {

	$categories = array_keys( get_the_listing_categories( $post->ID ) );

	foreach ( $categories as $category ) {
		foreach ( va_get_fields_for_cat( $category, VA_LISTING_CATEGORY ) as $field ) {
			$args['meta_keys'][] = $field['name'];
		}
	}

	return $args;
}
add_filter( 'appthemes_update_search_index_listing', 'va_update_search_index_listing_custom_fields', 10, 2 );


function va_internal_use_page_templates( $internal_use_templates ) {
	$internal_use_templates[] = 'archive-listing.php';
	return $internal_use_templates;
}
add_filter( 'appthemes_internal_use_page_templates', 'va_internal_use_page_templates' );


/**
 * Make the options object instantly available in templates.
 *
 * @since 1.3.2
 */
function va_set_default_template_vars() {
	global $va_options;

	appthemes_add_template_var( 'va_options', $va_options );
}
add_action( 'template_redirect', 'va_set_default_template_vars' );

/**
 * Disables AppThemes login pages
 *
 * @global scpOptions $va_options
 *
 * @since 1.4
 */
function va_disable_app_login_pages() {
	global $va_options;

	if ( $va_options->wp_login ) {
		remove_theme_support( 'app-login' );
	}
}
add_action( 'after_setup_theme', 'va_disable_app_login_pages', 99 );

/**
 * Retrieves listing data by given reference ID.
 *
 * @since 1.0.0
 *
 * @param string $reference_id An listing reference ID.
 *
 * @return object|bool A listing object, boolean False otherwise.
 */
function va_get_listing_by_ref( $reference_id ) {

	if ( empty( $reference_id ) || ! is_string( $reference_id ) ) {
		return false;
	}

	$reference_id = appthemes_numbers_letters_only( $reference_id );

	$ptypes = array( VA_LISTING_PTYPE );

	$listings = get_posts( array(
		'post_status'      => 'any',
		'post_type'        => $ptypes,
		'meta_key'         => 'va_id',
		'meta_value'       => $reference_id,
		'posts_per_page'   => 1,
		'suppress_filters' => true,
		'no_found_rows'    => true,
	) );

	if ( empty( $listings ) ) {
		return false;
	}
	return $listings[ 0 ];
}


function _va_after_load_payments() {

	if ( is_admin() ) {
		remove_filter( 'set-screen-option', array( 'APP_Connected_Post_Orders', 'save_screen_option' ), 10, 3 );
		add_filter( 'appthemes_save_screen_option_intercept_appthemes_connected_orders_per_post_page', array( 'APP_Connected_Post_Orders', 'save_screen_option' ), 10, 3 );

		remove_filter( 'set-screen-option', array( 'APP_Connected_User_Orders', 'save_screen_option' ), 10, 3 );
		add_filter( 'appthemes_save_screen_option_intercept_appthemes_connected_orders_per_user_page', array( 'APP_Connected_User_Orders', 'save_screen_option' ), 10, 3 );

		add_filter( 'set-screen-option', 'appthemes_save_screen_option_intercept', 10, 3 );
	}
}
add_action( 'after_setup_theme', '_va_after_load_payments', 1001 );


function appthemes_save_screen_option_intercept( $status, $option, $value ) {

	$interceptor = apply_filters( 'appthemes_save_screen_option_intercept_' . $option, false, $option, $value );

	if ( false !== $interceptor ) {
		return $interceptor;
	}

	return false;
}

/**
 * Disable the front-end admin bar for non-admins.
 *
 * @since 4.0.0
 */
function va_disable_admin_bar() {
	/**
	 * Filter the allowed capability to view the front-end admin bar.
	 *
	 * @url https://codex.wordpress.org/Roles_and_Capabilities
	 *
	 * @since 4.0.0
	 *
	 * @param string $capability The minimum WordPress capability allowed.
	 *                           Defaults to 'manage_options'.
	 */
	$capability = apply_filters( 'va_disable_admin_bar', 'manage_options' );

	if ( ! current_user_can( $capability ) && ! is_admin() ) {
		add_filter( 'show_admin_bar', '__return_false' );
	}
}
add_action( 'after_setup_theme', 'va_disable_admin_bar' );

/**
 * Modifies tag cloud widget arguments to have all tags in the widget same font size.
 *
 * @since 4.0.0
 *
 * @param array $args Arguments for the tag cloud widget.
 *
 * @return array      A new modified set of arguments.
 */
function va_widget_tag_cloud_args( $args ) {

	$args['largest']  = 1;
	$args['smallest'] = 1;
	$args['unit']     = 'em';

	return $args;
}
add_filter( 'widget_tag_cloud_args', 'va_widget_tag_cloud_args' );

/**
 * Filters the "Powered by WordPress" text in the Meta widget.
 *
 * @since 4.0.0
 *
 * @param string $title_text Default title text for the link.
 */
function va_widget_meta_poweredby( $title_text ) {

	return sprintf( '<li><a href="%s" title="%s">%s</a></li>',
		esc_url( __( 'https://www.appthemes.com/' ) ),
		esc_attr__( 'Powered by AppThemes, maker of application themes for WordPress.' ),
		_x( 'AppThemes', 'meta widget link text' )
	);

}
add_filter( 'widget_meta_poweredby', 'va_widget_meta_poweredby' );
