<?php
/**
 * Single Plan Details metabox
 *
 * @package Listing\Modules\Plan\Metaboxes
 * @author  AppThemes
 * @since   Listing 1.0
 */

/**
 * Plan Details Meta Box class
 */
class APP_Listing_Plans_Details_Box extends APP_Meta_Box {

	/**
	 * Current plan object.
	 *
	 * @var type APP_Listing_Plans
	 */
	protected $plans;

	/**
	 * Construct Plan details metabox
	 *
	 * @param APP_Listing_Plans $plan Plan module object.
	 */
	public function __construct( APP_Listing_Plans $plan ) {
		$this->plans = $plan;
		$plan_ptype  = $this->plans->get_plan_type();

		parent::__construct( "$plan_ptype-details", __( 'Pricing Plan Details', APP_TD ), $plan_ptype, 'normal', 'high' );
	}

	/**
	 * Displays some extra HTML before the form
	 *
	 * @param WP_Post $post Current plan object.
	 */
	public function before_form( $post ) {
		?><style type="text/css">#notice{ display: none; }</style><?php
	}

	/**
	 * Returns an array of form fields.
	 *
	 * @return array Form fields
	 */
	public function form() {
		$plan_form = array();

		$plan_form[] = array(
			'title' => __( 'Description', APP_TD ),
			'type' => 'textarea',
			'name' => 'description',
			'extra' => array(
				'rows' => 10,
				'cols' => 50,
				'class' => 'large-text code',
			),
		);

		$plan_form[] = array(
			'title' => __( 'Price', APP_TD ),
			'type' => 'text',
			'name' => 'price',
			'desc' => sprintf( __( 'Example: %s ' , APP_TD ), '1.00' ),
			'extra'	 => array(
				'class' => 'small-text',
			),
		);

		return $plan_form;
	}

	/**
	 * Validate posted data.
	 *
	 * @param array $data    Posted data.
	 * @param int   $post_id Plan ID.
	 *
	 * @return bool|object A WP_Error object if posted data are invalid.
	 */
	public function validate_post_data( $data, $post_id ) {

		$errors = new WP_Error();

		if ( ! is_numeric( $data['price'] ) ) {
			$errors->add( 'price', '' );
		}

		return $errors;

	}

	/**
	 * Retrieves post updated messages for the Plan post type
	 *
	 * @param array $messages Messages.
	 *
	 * @return array Modified messages
	 */
	public function post_updated_messages( $messages ) {
		$messages[ $this->plans->get_plan_type() ] = array(
		 	1 => __( 'Plan updated.', APP_TD ),
		 	4 => __( 'Plan updated.', APP_TD ),
		 	6 => __( 'Plan created.', APP_TD ),
		 	7 => __( 'Plan saved.', APP_TD ),
		 	9 => __( 'Plan scheduled.', APP_TD ),
			10 => __( 'Plan draft updated.', APP_TD ),
		);
		return $messages;
	}

}
