<?php
/**
 * Listing Form Field Validator
 *
 * @package Listing\Form
 * @author  AppThemes
 * @since   Listing 1.0
 */

/**
 * General form Validator class
 */
class APP_Form_Field_Validator {

	/**
	 * Errors object.
	 *
	 * @var WP_Error
	 */
	protected $errors;

	/**
	 * Construct Validator object.
	 *
	 * @param WP_Error $errors Errors object.
	 */
	public function __construct( WP_Error $errors ) {
		$this->errors = $errors;
	}

	/**
	 * Validates posted data and adds errors
	 *
	 * @param mixed          $value Posted field value.
	 * @param scbCustomField $inst  Field object.
	 *
	 * @return mixed Validated value.
	 */
	public function validate( $value, $inst ) {
		$sanitizers = (array) $inst->sanitizers;

		foreach ( $sanitizers as $sanitizer ) {
			$value = call_user_func( $sanitizer, $value, $inst, $this->errors );
		}

		return $value;
	}

	/**
	 * Validate required fields.
	 *
	 * @param mixed          $value  Posted field value.
	 * @param scbCustomField $inst   Field object.
	 * @param WP_Error       $errors Errors object.
	 *
	 * @return mixed Validated value.
	 */
	public function required( $value, $inst, $errors ) {

		// Validate required fields.
		if ( $inst->props['required'] && empty( $value ) ) {

			$title = ( isset( $inst->title ) ) ? $inst->title : $inst->desc ;

			$errors->add(
				'required_field',
				sprintf( __( 'ERROR: Field %s is required!', APP_TD ), $title )
			);

		}

		return $value;
	}

}
