<?php

function va_category_dropdown( $taxonomy, $selected_category = array(), $include_category = array() ) {
	wp_dropdown_categories( array(
		'taxonomy'         => $taxonomy,
		'hide_empty'       => false,
		'hierarchical'     => true,
		'name'             => '_'.$taxonomy.'[]',
		'id'               => '_'.$taxonomy,
		'selected'         => $selected_category,
		'show_option_none' => __( 'Select Category', APP_TD ),
		'class'            => 'required',
		'orderby'          => 'name',
		'include'          => $include_category,
	) );
}

/**
 * Generates the contact owner button and form.
 *
 * @param int   $post_id The post ID.
 * @param array $args Custom form arguments.
 *
 * @return string
 */
function va_contact_post_author_button( $post_id = 0, $args = array() ) {

	$post_id = $post_id ? $post_id : get_the_ID();
	$post    = get_post( $post_id );

	if ( ! $post ) {
		return false;
	}

	$post_type_obj = get_post_type_object( $post->post_type );

	$defaults = array(
		'button_text'             => __( 'Contact Owner', APP_TD ),
		'form_title'              => __( 'Contact Owner', APP_TD ),
		'form_title_helper'       => sprintf( __( 'To inquire about this %1$s, complete the form below to send a message to the %1$s owner.', APP_TD ), strtolower( $post_type_obj->labels->singular_name ) ),
		'form_submit_button_text' => __( 'Send Inquiry', APP_TD ),
		'form_class'              => '',
	);

	$args = wp_parse_args( $args, $defaults );
	$args = apply_filters( 'va_contact_post_author_button', $args, $post );

	$button = html( 'button', array(
		'class' => 'va-contact-link '.$post_type_obj->name.'-contact-link expanded success button hollow',
		'href' => '#va-contact-form',
	), $args['button_text'] );


	$elements = '';
	$elements .= html( 'input', array( 'type' => 'hidden', 'value' => $post_id, 'id' => 'va-contact-post_id' ) );
	$elements .= html( 'legend', array( 'class' => 'title' ), $args['form_title'] );
	$elements .= html( 'p', array( 'class' => 'helper' ), $args['form_title_helper'] );
	$elements .= html( 'label', array(), __( 'Name', APP_TD ), html( 'input', array( 'type'=>'text', 'name' => 'va-contact-name', 'id' => 'va-contact-name', 'class' => 'required' ) ) );
	$elements .= html( 'label', array(), __( 'Email', APP_TD ), html( 'input', array( 'type'=>'text', 'name' => 'va-contact-email', 'id' => 'va-contact-email', 'class' => 'required email' ) ) );

	$elements .= html( 'label', array(), __( 'Message', APP_TD ), html( 'textarea', array( 'name' => 'va-contact-message', 'id' => 'va-contact-message', 'class' => 'required' ) ) );

	$elements .= wp_nonce_field( 'va-contact-' . $post_id, 'va-contact-nonce', true, false );

	$elements .= html( 'input', array( 'type' => 'button', 'value' => $args['form_submit_button_text'], 'id' => 'va-contact-send', 'class' => 'button' ) );

	$box = html( 'form', array( 'id' => 'va-contact-form', 'class' => 'va-' . $post_type_obj->name . '-contact-form ' . $args['form_class'] ), $elements );

	$box = html( 'div', array( 'style' => 'display:none;' ), $box );

	return $button . $box;
}

function va_get_term_link_base( $taxonomy ) {
	global $wp_rewrite;

	$termlink = $wp_rewrite->get_extra_permastruct( $taxonomy );
	$termlink = str_replace("%$taxonomy%", '', $termlink);

	$t = get_taxonomy($taxonomy);

	if ( empty($termlink) ) {
		if ( $t->query_var )
			$termlink = "?$t->query_var=";
		else
			$termlink = "?taxonomy=$taxonomy&term=";
		$termlink = home_url($termlink);
	} else {
		$termlink = home_url( user_trailingslashit($termlink, 'category') );
	}

	return $termlink;
}

function get_va_query_var( $var, $fallback = true ) {
	if ( get_query_var( 'va_' . $var ) || !$fallback ) {
		return get_query_var( 'va_' . $var );
	}

	return get_query_var( $var );
}
