<?php
/**
 * Customizer functionality
 *
 * @package Vantage
 *
 * @since 4.0.0
 * @since 4.1.0 Added primary header text color option.
 */

// Allows us to show changes in real-time for default options.
// Also need code in our customize-preview.js file.
$wp_customize->get_setting( 'background_color' )->transport = 'postMessage';

// Remove the core header textcolor control, as it shares the main text color.
$wp_customize->remove_control( 'header_textcolor' );


// Add color scheme setting.
$wp_customize->add_setting( 'color_scheme', array(
	'default'           => 'aqua',
	'transport'         => 'postMessage',
	'sanitize_callback' => 'va_sanitize_color_scheme',
) );

// Add color scheme radio buttons.
// For new colors, make sure to whitelist in va_sanitize_color_scheme().
$wp_customize->add_control( 'color_scheme', array(
	'type'     => 'radio',
	'label'    => __( 'Color Scheme', APP_TD ),
	'choices'  => array(
		'aqua'   => __( 'Aqua', APP_TD ),
		'blue'   => __( 'Blue', APP_TD ),
		'green'  => __( 'Green', APP_TD ),
		'orange' => __( 'Orange', APP_TD ),
		'red'    => __( 'Red', APP_TD ),
		'custom' => __( 'Custom', APP_TD ),
	),
	'section'  => 'colors',
	'priority' => 5,
) );

// Add main color setting.
$wp_customize->add_setting( 'color_scheme_custom', array(
	'default'           => '#1AB394',
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'         => 'postMessage',
) );

// Add main color field.
$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'color_scheme_custom', array(
	'label'    => '',
	'section'  => 'colors',
	'priority' => 6,
) ) );


// Add header background color setting.
$wp_customize->add_setting( 'header_background_color', array(
	'default'           => '#FFFFFF',
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'         => 'postMessage',
) );

// Add header background color field.
$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'header_background_color', array(
	'label'   => __( 'Header Background Color', APP_TD ),
	'section' => 'colors',
) ) );

// Add header text color setting.
$wp_customize->add_setting( 'header_text_color', array(
	'default'           => '#8A8A8A',
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'         => 'postMessage',
) );

// Add header text color field.
$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'header_text_color', array(
	'label'   => __( 'Header Text Color', APP_TD ),
	'section' => 'colors',
) ) );


// Add footer background color setting.
$wp_customize->add_setting( 'footer_background_color', array(
	'default'           => '#233644',
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'         => 'postMessage',
) );

// Add footer background color field.
$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'footer_background_color', array(
	'label'   => __( 'Footer Background Color', APP_TD ),
	'section' => 'colors',
) ) );

/**
 * Sanitize the color scheme.
 *
 * @since 4.0.0
 *
 * @param string $input The value of color scheme.
 */
function va_sanitize_color_scheme( $input ) {

	$valid = array( 'aqua', 'blue', 'green', 'orange', 'red', 'custom' );

	if ( in_array( $input, $valid ) ) {
		return $input;
	}

	return 'aqua';
}
