<?php
/**
 * Customizer colors front-end CSS functionality
 *
 * @package Vantage
 *
 * @since 4.0.0
 */

/**
 * Enqueues front-end CSS for the custom header background color.
 *
 * @since 4.0.0
 */
function va_header_background_color_css() {
	$default = '#FFFFFF';
	$color   = get_theme_mod( 'header_background_color', $default );

	// Don't do anything if the current color is the default.
	if ( $color === $default ) {
		return;
	}

	// Use a hex color generator to create our hover
	// color based off the custom color_scheme.
	include_once( dirname( __FILE__ ) . '/../class-phpcolors.php' );
	$phpColors = new APP_PHPColors( $color );

	// It's missing the hash so append it.
	$sep_color = '#' . $phpColors->darken( 5 );

	$css = "
		/* Vantage Header Background Color */
		#top-bar-primary, #top-bar-primary #menu-primary, .top-bar, .top-bar > ul {
			background-color: {$color};
		}
		.header #top-bar-primary {
			border-bottom: 1px solid {$sep_color};
		}
	";

	// Handle must match main theme stylesheet handle to work.
	wp_add_inline_style( 'theme-styles', $css );
}
add_action( 'wp_enqueue_scripts', 'va_header_background_color_css' );

/**
 * Enqueues front-end CSS for the custom header background color.
 *
 * @since 4.1.0
 */
function va_header_text_color_css() {
	$default = '#8A8A8A';
	$color   = get_theme_mod( 'header_text_color', $default );

	// Don't do anything if the current color is the default.
	if ( $color === $default ) {
		return;
	}

	// Use a hex color generator to create our hover
	// color based off the custom color_scheme.
	include_once( dirname( __FILE__ ) . '/../class-phpcolors.php' );
	$phpColors = new APP_PHPColors( $color );

	// It's missing the hash so append it.
	$hover_color = '#' . $phpColors->darken();

	$css = "
		/* Vantage Primary Header Text Color */
		.top-bar li.menu-item a {
			color: {$color};
		}
		.top-bar li.menu-item a:focus, .top-bar li.menu-item a:hover {
			color: {$hover_color};
		}
	";

	// Handle must match main theme stylesheet handle to work.
	wp_add_inline_style( 'theme-styles', $css );
}
add_action( 'wp_enqueue_scripts', 'va_header_text_color_css' );

/**
 * Enqueues front-end CSS for the custom footer background color.
 *
 * @since 4.0.0
 */
function va_footer_background_color_css() {
	$default = '#233644';
	$color   = get_theme_mod( 'footer_background_color', $default );

	// Don't do anything if the current color is the default.
	if ( $color === $default ) {
		return;
	}

	$css = "
		/* Vantage Footer Background Color */
		#footer {
			background-color: {$color};
		}
	";

	// Handle must match main theme stylesheet handle to work.
	wp_add_inline_style( 'theme-styles', $css );
}
add_action( 'wp_enqueue_scripts', 'va_footer_background_color_css' );

/**
 * Enqueues front-end CSS for the custom color scheme.
 *
 * We can't use wp_enqueue_scripts & wp_add_inline_style b/c
 * this loads the custom css after style.css so it causes inheritance
 * bleed through on colors. Need to use wp_head instead to solve issue.
 * TwentySeventeen does the same thing.
 *
 * @since 4.0.0
 */
function va_color_scheme_css() {
	$default = '#1AB394';
	$color   = get_theme_mod( 'color_scheme_custom', $default );

	// Don't do anything if the current color is the default.
	if ( $color === $default ) {
		return;
	}

	// Use a hex color generator to create our hover
	// color based off the custom color_scheme.
	include_once( dirname( __FILE__ ) . '/../class-phpcolors.php' );
	$phpColors = new APP_PHPColors( $color );

	// It's missing the hash so append it.
	$hover_color = '#' . $phpColors->darken();

	$css = "
		/* Vantage Custom Color Scheme */
		.theme-custom a {
			color: {$color};
		}
		.theme-custom a:hover, .theme-custom a:focus {
			color: {$hover_color};
		}
		.theme-custom .button {
			background-color: {$color};
			color: #FEFEFE;
		}
		.theme-custom .button:hover, .theme-custom .button:focus {
			background-color: {$hover_color};
			color: #FEFEFE;
		}
		.theme-custom .button.primary {
			background-color: {$color};
		}
		.theme-custom .button.primary:hover, .theme-custom .button.primary:focus {
			background-color: {$hover_color};
			color: #FEFEFE;
		}
		.theme-custom .button.hollow {
			border-color: {$color};
			color: {$color};
			background-color: transparent;
		}
		.theme-custom .button.hollow:hover, .theme-custom .button.hollow:focus {
			background-color: {$hover_color};
			border-color: {$hover_color};
			color: #FEFEFE;
		}
		.theme-custom .button.hollowprimary {
			border-color: {$color};
			color: {$color};
		}
		.theme-custom .button.hollowprimary:hover, .theme-custom .button.hollowprimary:focus {
			border-color: {$hover_color};
			color: {$hover_color};
		}
		.theme-custom .button.disabled:hover, .theme-custom .button.disabled:focus {
			background-color: {$color};
		}
		.theme-custom .button.disabled.primary:hover, .theme-custom .button.disabled.primary:focus {
			background-color: {$color};
		}
		.theme-custom .accordion-title {
			color: {$color};
		}
		.theme-custom .is-accordion-submenu-parent > a::after {
			border-color: {$color} transparent transparent;
		}
		.theme-custom .badge {
			background: {$color};
		}
		.theme-custom .breadcrumbs a {
			color: {$color};
		}
		.theme-custom .button-group.primary .button {
			background-color: {$color};
		}
		.theme-custom .button-group.primary .button:hover, .theme-custom .button-group.primary .button:focus {
			background-color: {$hover_color};
			color: #FEFEFE;
		}
		.theme-custom .menu .active > a {
			background: {$color};
		}
		.theme-custom .is-drilldown-submenu-parent > a::after {
			border-color: transparent transparent transparent {$color};
		}
		.theme-custom .js-drilldown-back > a::before {
			border-color: transparent {$color} transparent transparent;
		}
		.theme-custom .dropdown.menu > li.is-dropdown-submenu-parent > a::after {
			border-color: {$color} transparent transparent;
		}
		.theme-custom .dropdown.menu.vertical > li.opens-left > a::after {
			border-color: transparent {$color} transparent transparent;
		}
		.theme-custom .dropdown.menu.vertical > li.opens-right > a::after {
			border-color: transparent transparent transparent {$color};
		}
		.theme-custom .dropdown.menu.medium-horizontal > li.is-dropdown-submenu-parent > a::after {
			border-color: {$color} transparent transparent;
		}
		.theme-custom .dropdown.menu.medium-vertical > li.opens-left > a::after {
			border-color: transparent {$color} transparent transparent;
		}
		.theme-custom .dropdown.menu.medium-vertical > li.opens-right > a::after {
			border-color: transparent transparent transparent {$color};
		}
		.theme-custom .dropdown.menu.large-horizontal > li.is-dropdown-submenu-parent > a::after {
			border-color: {$color} transparent transparent;
		}
		.theme-custom .dropdown.menu.large-vertical > li.opens-left > a::after {
			border-color: transparent {$color} transparent transparent;
		}
		.theme-custom .dropdown.menu.large-vertical > li.opens-right > a::after {
			border-color: transparent transparent transparent {$color};
		}
		.theme-custom .is-dropdown-submenu .is-dropdown-submenu-parent.opens-left > a::after {
			border-color: transparent {$color} transparent transparent;
		}
		.theme-custom .is-dropdown-submenu .is-dropdown-submenu-parent.opens-right > a::after {
			border-color: transparent transparent transparent {$color};
		}
		.theme-custom .label {
			background: {$color};
			color: #FEFEFE;
		}
		.theme-custom .pagination .current {
			background: {$color};
		}
		.theme-custom .pagination .current a:hover, .theme-custom .pagination .current a:focus, .theme-custom .pagination .current a:active {
			color: inherit;
			background: {$color};
		}
		.theme-custom .progress.primary .progress-meter {
			background-color: {$color};
		}
		.theme-custom .progress-meter {
			background-color: {$color};
		}
		.theme-custom .slider-handle {
			background-color: {$color};
		}
		.theme-custom input:checked ~ .switch-paddle {
			background: {$color};
		}
		.theme-custom .tabs.primary {
			background: {$color};
		}
		.theme-custom #topcontrol {
			background: {$color};
		}
		.theme-custom #topcontrol:hover {
			background: {$hover_color};
		}
	";
?>
<style type="text/css" id="custom-theme-colors" <?php if ( is_customize_preview() ) { echo 'data-color="' . $color . '"'; } ?>>
	<?php
	/**
	 * Filters custom color CSS.
	 *
	 * @since 4.0.0
	 *
	 * @param $css         string Custom theme color CSS.
	 * @param $color       string The user's selected color hex.
	 * @param $hover_color string The calculated hover color hex.
	 */
	echo apply_filters( 'va_custom_colors_css', $css, $color, $hover_color );
	?>
</style>
<?php
}
// Priority is very important! Above 7 equals css inheritance issues.
add_action( 'wp_head', 'va_color_scheme_css', 7 );
