<?php
/**
 * @todo Add comments and review functions.
 */

function va_get_dashboard_permalink_setting( $permalink ) {
	global $va_options;

	$permalinks = array(
		'dashboard'        => $va_options->dashboard_permalink,
		'listings'         => $va_options->dashboard_listings_permalink,
		'favorites'        => $va_options->dashboard_faves_permalink,
		'claimed-listings' => $va_options->dashboard_claimed_permalink,
	);

	$permalinks = apply_filters( 'va_dashboard_permalink_settings', $permalinks );

	return $permalinks[ $permalink ];
}

function va_get_dashboard_name() {
	global $wp_query;

	$dashboard_type = $wp_query->get( 'dashboard' );

	if ( $dashboard_type == va_get_dashboard_permalink_setting( 'claimed-listings' ) ) {
		$name = __( 'Claimed Listings', APP_TD );
	} else if ( $dashboard_type == va_get_dashboard_permalink_setting( 'favorites' ) ) {
		$name = __( 'Favorites', APP_TD );
	} else {
		$name = __( 'Listings', APP_TD );
	}

	return apply_filters( 'va_get_dashboard_name', $name, $dashboard_type );
}

function va_get_dashboard_type() {
	global $wp_query;
	$dashboard_type = $wp_query->get( 'dashboard' );

	if ( $dashboard_type == va_get_dashboard_permalink_setting( 'claimed-listings' ) ) {
		$type = 'claimed-listings';
	} elseif ( $dashboard_type == va_get_dashboard_permalink_setting( 'favorites' ) ) {
		$type = 'favorites';
	} else {
		$type = 'listings';
	}
	return apply_filters( 'va_get_dashboard_type', $type, $dashboard_type );
}

function va_is_own_dashboard() {
	global $wp_query;
	$dashboard_author = $wp_query->get( 'dashboard_author' );

	if ( $dashboard_author == 'self' ) {
		return true;
	} else {
		$user = get_user_by( 'slug', $dashboard_author );
		if ( $user && $user->ID == get_current_user_id() ) {
			return true;
		} else {
			return false;
		}
	}
}

function va_get_dashboard_author() {
	global $wp_query;
	$dashboard_author = $wp_query->get( 'dashboard_author' );

	if ( $dashboard_author == 'self' ) {
		$user = wp_get_current_user();
	} else {
		$user = get_user_by( 'slug', $dashboard_author );
	}

	if ( ! $user ) {
		return false;
	}

	$user->twitter     = get_user_meta( $user->ID, 'twitter', true );
	$user->facebook    = get_user_meta( $user->ID, 'facebook', true );

	return $user;
}

/**
 * The text to display for the listing status.
 *
 * @since  3.0.0
 *
 * @param  string $post_status The post status.
 *
 * @return string The post status text string.
 */
function va_get_dashboard_verbiage( $post_status ) {

	$output = apply_filters( 'va_dashboard_verbiage', array(
		'pending'         => __( 'Pending', APP_TD ),
		'pending-claimed' => __( 'Pending Claimed', APP_TD ),
		'publish'         => __( 'Live', APP_TD ),
		'expired'         => __( 'Expired', APP_TD ),
		'draft'           => __( 'Draft', APP_TD ),
	) );

	return ! empty( $output[ $post_status ] ) ? $output[ $post_status ] : '';
}

/**
 * Count the number of user listings and group by type.
 *
 * @todo    Maybe use WP_Object_Cache or transient?
 *
 * @since   4.0.0
 *
 * @global  wpdb $wpdb WordPress database abstraction object.
 *
 * @return  array Returns a count of each user post status.
 */
function va_count_user_listings() {
	global $wpdb;

	$post_stati = array_keys( va_public_listing_statuses() );

	$post_stati_in = implode( "', '", $post_stati );

	$sql = $wpdb->prepare( "
		SELECT post_status, COUNT( * ) AS num_posts
		FROM {$wpdb->posts}
		WHERE post_type = %s
		AND post_status IN ('$post_stati_in')
		AND post_author = %d
		GROUP BY post_status",
		VA_LISTING_PTYPE,
		get_current_user_id()
	);

	$results = (array) $wpdb->get_results( $sql, ARRAY_A );

	// Fill empty results with a zero.
	$counts  = array_fill_keys( $post_stati, 0 );

	foreach ( $results as $row ) {
		$counts[ $row['post_status'] ] = $row['num_posts'];
	}

	// Include the total sum.
	$counts['total'] = array_sum( $counts );

	return (object) $counts;
}

/**
 * Count the number of user listings for one type.
 *
 * @since   4.0.0
 *
 * @global  wpdb $wpdb WordPress database abstraction object.
 *
 * @return  int Returns a count of the user post status.
 */
function va_count_user_listing_status( $post_status = 'publish' ) {
	global $wpdb;

	$sql = $wpdb->prepare( "
		SELECT COUNT( * )
		FROM {$wpdb->posts}
		WHERE post_type = %s
		AND post_status = %s
		AND post_author = %d",
		VA_LISTING_PTYPE,
		$post_status,
		get_current_user_id()
	);

	return intval ( $wpdb->get_var( $sql ) );
}


function va_the_payment_complete_actions( $listing_id = '' ) {
	$listing_id = ! empty( $listing_id ) ? $listing_id : get_the_ID();
	$actions = array();

	$order = appthemes_get_order_connected_to( $listing_id );
	if ( ! $order || ! in_array( $order->get_status(), array( APPTHEMES_ORDER_PENDING, APPTHEMES_ORDER_FAILED ) ) ) {
		return;
	}

	// pay order if order has checkout data
	if ( get_post_meta( $order->get_id(), 'cancel_url', true ) ) {
		$actions['pay_order'] = array(
			'title' => __( 'Pay now', APP_TD ),
			'href'  => appthemes_get_order_url( $order->get_id() ),
		);

		if ( $order->get_gateway() ) {
			// reset gateway
			$actions['reset_gateway'] = array(
				'title' => __( 'Reset Gateway', APP_TD ),
				'href'  => get_the_order_cancel_url( $order->get_id() ),
			);
		}
	} else {
		$actions['purchase'] = array(
			'title' => __( 'Pay now', APP_TD ),
			'href'  => va_get_listing_purchase_url( $listing_id ),
		);
	}

	$output = '';
	foreach ( $actions as $action => $attr ) {
		$attr    = array_merge( $attr, array( 'class' => 'listing-edit-link' ) );
		$output .= html( 'a', $attr, $attr['title'] );
	}

	echo $output;
}

/**
 * Get the listing expiration date.
 *
 * @since  4.0.0
 *
 * @param  WP_Post $listing The listing object.
 *
 * @return string Expired date string.
 */
function va_get_expire_date( $listing ) {

	$listing_module = APP_Listing_Director::get( $listing->post_type );

	$expire_date = 0;

	if ( $listing_module->plans ) {
		$plans = $listing_module->plans;
		$plan  = $plans->get_current_plan( $listing->ID );
		$expire_date = $plan->get_expire_date();
	}

	if ( $expire_date ) {
		$flag        = $expire_date < time() ? 'expired-date' : 'active-date';
		$expire_date = appthemes_display_date( $expire_date, 'date' );
		return '<span class="' . $flag . '">' . $expire_date . '</span>';
	} else {
		return '&ndash;';
	}
}

/**
 * Get the recurring date string if exists.
 *
 * Replaces the overly complex va_get_listing_expiration_notice().
 *
 * @since  4.0.0
 *
 * @todo Deprecate va_get_listing_expiration_notice()
 *
 * @param  int $listing_id The listing ID.
 *
 * @return string|void String if retrieving.
 */
function va_get_recurring_date( $listing_id = 0 ) {

	if ( ! $recurring_order = _va_get_recurring_listing_order( $listing_id ) ) {
		return;
	}

	$recur_date      = date_i18n( get_option( 'date_format' ), strtotime( get_post( $recurring_order->get_id() )->post_date ) );
	$expiration_date = va_get_listing_exipration_date( $listing_id );
	$is_expired      = strtotime( $expiration_date ) < time();

	return ! $is_expired ? $recur_date : '';
}

function va_get_listing_expiration_notice( $listing_id = '' ) {

	$expiration_date = va_get_listing_exipration_date( $listing_id );
	if ( ! $expiration_date ) {
		return;
	}

	$upcoming_recurring_payment_date = va_get_recurring_order_next_payment_date( $listing_id = 0 );
	$is_expired = strtotime( $expiration_date ) < time();

	if ( $is_expired ) {
		$notice = sprintf( __( 'Listing Expired on: %s', APP_TD ), mysql2date( get_option( 'date_format' ), $expiration_date ) );
	} elseif ( $upcoming_recurring_payment_date ) {
		$notice = sprintf( __( 'Upcoming Recurring Payment: %s', APP_TD ), $upcoming_recurring_payment_date );
	} else {
		$notice = sprintf( __( 'Listing Expires on: %s', APP_TD ), mysql2date( get_option( 'date_format' ), $expiration_date ) );
	}

	$output = '<p class="dashboard-expiration-meta">';
	$output .= $notice;
	$output .= '</p>';
	return $output;
}

function va_get_listing_exipration_date( $listing_id = '' ) {

	$listing_id = ! empty( $listing_id ) ? $listing_id : get_the_ID();
	$listing = get_post( $listing_id );

	$duration = get_post_meta( $listing_id, '_listing_duration', true );

	if ( empty( $duration ) ) {
		return 0;
	}

	return va_get_expiration_date( $listing->post_date, $duration );
}

function va_get_expiration_date( $start_date, $duration ) {

	$expiration_date = date( 'm/d/Y', strtotime( $start_date .' + ' . $duration . 'days' ) );

	return $expiration_date;
}

function va_dashboard_url( $page, $user_id = '', $self = false ) {
	$nicename = get_the_author_meta( 'user_nicename', $user_id );

	$url = home_url();
	$permalink = '/' . va_get_dashboard_permalink_setting( 'dashboard' ) . '/' . va_get_dashboard_permalink_setting( $page );

	if ( $self ) {
		if ( get_option( 'permalink_structure' ) != '' ) {
			$url .= $permalink . '/';
		} else {
			$url .= '?dashboard=' . va_get_dashboard_permalink_setting( $page ) . '&dashboard_author=self';
		}
	} else {
		if ( get_option( 'permalink_structure' ) != '' ) {
			$url .=  $permalink . '/' . $nicename . '/';
		} else {
			$url .= '?dashboard=' . va_get_dashboard_permalink_setting( $page ) . '&dashboard_author=' . $nicename;
		}
	}

	return $url;
}

function va_the_author_listings_link( $user_id = '' ) {

	echo va_get_the_author_listings_link( $user_id );
}

function va_get_the_author_listings_link( $user_id = '' ) {

	$url = va_dashboard_url( 'listings', $user_id, false );
	$display_name = get_the_author_meta( 'display_name', $user_id );

	return html_link( $url, $display_name );
}
