<?php
/**
 * Delete listing processing
 *
 * @package Vantage
 * @since   Vantage 1.4
 */


/**
 * Process the ajax delete listing action.
 *
 * @since   4.0.0
 *
 * @return  array The ajax response.
 */
function va_handle_ajax_delete_post() {

	// Make sure it's a legit request.
	check_ajax_referer( 'vantage_delete_listing_' . $_POST[ 'id' ], 'nonce' );

	// We need certain params to proceed.
	if ( ! isset( $_POST[ 'id' ] ) ) {
		wp_send_json_error( __( 'Post ID is required.', APP_TD ) );
	}

	// Mark the post as "Deleted".
	$post_id = wp_update_post( array(
		'ID'          => $_POST[ 'id' ],
		'post_status' => 'deleted',
	) );

	// Listing was not found.
	if ( 0 == $post_id ) {
		wp_send_json_error( __( 'Post not found.', APP_TD ) );
	}

	// Return the response.
	wp_send_json_success();
}
add_action( 'wp_ajax_vantage_delete_listing', 'va_handle_ajax_delete_post' );
add_action( 'wp_ajax_nopriv_vantage_delete_listing', 'va_handle_ajax_delete_post' );


/**
 * Returns or echoes the delete button
 *
 * @param bool    $echo If set to FALSE does not echo the button HTML
 *
 * @return string
 */
function the_listing_delete_link( $echo = true ) {
	global $post;

	$button = '';

	if ( current_user_can( 'delete_listings' ) && va_is_own_dashboard() ) {

		$text = __( 'Delete', APP_TD );

		$icon = html( 'span', array(
			'class' => 'delete-icon listing-delete',
		), '' );

		$button = html( 'a', array(
			'class' => 'delete-button listing-delete-link ',
			'href' => va_get_delete_post_url( $post->ID ),
			'rel' => 'nofollow',
		),  $icon . ' ' . $text );

	}

	if ( $echo ) {
		echo $button;
	} else {
		return $button;
	}
}
