<?php
/**
 * Emails processing
 *
 * @package Vantage
 * @subpackage Emails
 * @since   Vantage 1.0.0
 */

/**
 * A wrapper for appthemes_send_email()
 *
 * @since 1.0.0
 *
 * @uses appthemes_send_email()
 *
 * @param string $id   The unique name of the email.
 * @param array  $args An array of wp_mail() arguments, including the "to",
 *                    "subject", "message", "headers", "attachments" and
 *                    other custom values ("listing" or "order", etc.).
 */
function va_appthemes_send_email( $id, $args = array() ) {

	$defaults = array(
		'to'          => '',
		'subject'     => '',
		'message'     => '',
		'attachments' => array(),
		'headers'     => array(
			'type' => 'Content-Type: text/html; charset="' . get_bloginfo( 'charset' ) . '"',
		),
	);

	/**
	 * Filters the email field values.
	 *
	 * Allows you to change the message or other values for any email.
	 *
	 * @since 1.0.0
	 *
	 * @param string $id   The unique name of the email.
	 * @param array  $args The email field values.
	 */
	$args = wp_parse_args( apply_filters( $id, $args ), $defaults );

	appthemes_send_email( $args['to'], $args['subject'], $args['message'] );
}

/**
 * Sends notification to user when his subscription has expired.
 *
 * @since 1.0.0
 *
 * @param object $post
 *
 * @return void
 */
function va_send_expired_subscription_expired_notification( $post ) {

	$args = func_get_args();

	$recipient = get_user_by( 'id', $post->post_author );

	$content = '';

	$content .= html( 'p', sprintf( __( 'Hello %s,', APP_TD ), $recipient->display_name ) );

	$content .= html( 'p', sprintf(
		__( 'The most recent payment attempt for the subscription plan for listing: "%s" was not successful, either due to the payment gateway subscription period coming to completion or manual cancelation.', APP_TD ),
		html_link( get_permalink( $post ), $post->post_title )
	) );

	$content .= html( 'p', sprintf (
		__( 'Your listing "%1$s" will expire on: %2$s', APP_TD ),
		html_link( get_permalink( $post ), $post->post_title ),
		mysql2date( get_option('date_format'), va_get_listing_exipration_date( $post->ID ) )
	) );

	$content .= html( 'p', __( 'After your Listing expires, you will receive an email with renewal details.', APP_TD ) );

	$blogname = wp_specialchars_decode( get_bloginfo( 'name' ), ENT_QUOTES );

	$subject = sprintf( __( '[%1$s] Subscription Ended - Listing: "%2$s"', APP_TD ), $blogname, $post->post_title );

	$args = array(
		'to'      => $recipient->user_email,
		'subject' => $subject,
		'message' => $content,
		'listing' => $post,
	);

	va_appthemes_send_email( 'va_email_subscription_expired', $args );
}
