<?php
/**
 * Enqueue scripts and styles.
 *
 * @package Vantage
 * @since   4.0.0
 */

/**
 * Load up the scripts and stylesheets
 *
 * @since 4.0.0
 */
function va_scripts_and_styles() {

	// Minimize prod or show expanded in dev.
	$min = ( defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG ) ? '' : '.min';

	// Set the assets path so we don't repeat ourselves.
	$assets_path = get_template_directory_uri() . '/assets';

	/**
	 *  Stylesheets.
	 */

	// Load the Foundation stylesheet.
	wp_enqueue_style( 'foundation', get_template_directory_uri() . "/assets/css/foundation{$min}.css", array(), '6.2.4' );

	// Load the Slick stylesheet.
	wp_enqueue_style( 'slick', $assets_path . "/js/lib/slick/slick{$min}.css", array(), '1.6.0' );

	// Load the Slick theme stylesheet.
	wp_enqueue_style( 'slick-theme', $assets_path . "/js/lib/slick/slick-theme{$min}.css", array(), '1.6.0' );

	//wp_enqueue_style( 'chosen', get_template_directory_uri() . "/assets/js/lib/chosen/chosen{$min}.css", array(), '1.6.2' );

	// Load the font awesome toolkit from framework.
	wp_enqueue_style( 'font-awesome' );

	// Load the Google fonts.
	wp_enqueue_style( 'google-fonts', va_google_fonts_url(), false );

	// Load the theme stylesheet.
	wp_enqueue_style( 'theme-styles', get_template_directory_uri() . "/assets/css/style{$min}.css", array(), VA_VERSION );

	// Load the rtl theme stylesheet.
	wp_style_add_data( 'theme-styles', 'rtl', 'replace' );

	/**
	 * Scripts
	 */

	// Load the Marker Clusterer Plus script.
	wp_enqueue_script( 'markerclustererplus', $assets_path . "/js/lib/markerclustererplus/markerclusterer{$min}.js", array( 'at-google-maps-api' ), '2.1.1', true );

	// Load the Rich Marker script.
	wp_enqueue_script( 'richmarker', $assets_path . "/js/lib/richmarker/richmarker{$min}.js", array( 'at-google-maps-api' ), '2.0.0', true );

	// Load the Rich Marker script.
	wp_enqueue_script( 'infobubble', $assets_path . "/js/lib/infobubble/infobubble{$min}.js", array( 'at-google-maps-api' ), '0.8', true );

	// Load the Foundation script.
	wp_enqueue_script( 'foundation', $assets_path . "/js/lib/foundation/foundation{$min}.js", array( 'jquery' ), '6.2.4', true );

	// Load the Foundation Motion UI script.
	wp_enqueue_script( 'foundation-motion-ui', $assets_path . "/js/lib/foundation/motion-ui{$min}.js", array( 'jquery', 'foundation' ), '1.2.2', true );

	// Load the Typed script.
	wp_enqueue_script( 'typed', $assets_path . "/js/lib/typed/typed{$min}.js", array( 'jquery' ), '1.1.4', true );

	// Load the Slick script.
	wp_enqueue_script( 'slick', $assets_path . "/js/lib/slick/slick{$min}.js", array( 'jquery' ), '1.6.0', true );

	// Load the Scroll to Top script.
	wp_enqueue_script( 'scrolltotop', $assets_path . "/js/lib/scrolltotop/scrolltotop{$min}.js", array( 'jquery' ), '1.1.0', true );

	// Load the Chosen script in the footer.
	//wp_enqueue_script( 'chosen', $assets_path . "/js/lib/chosen/chosen.jquery{$min}.js", array( 'jquery' ), '1.6.2', true );

	// Load the theme script.
	wp_enqueue_script( 'theme-scripts', $assets_path . "/js/theme-scripts{$min}.js", array( 'jquery' ), VA_VERSION, true );

	// Load any global options we want to access via js (e.g. vantageSettings.ajaxurl).
	wp_localize_script( 'theme-scripts', 'vantageSettings', va_theme_scripts_strings() );

	// Comment reply script for threaded comments.
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'va_scripts_and_styles' );

/**
 * Load up the admin scripts and stylesheets
 *
 * @since 4.0.0
 */
function va_scripts_and_styles_admin() {

	// Minimize prod or show expanded in dev.
	$min = ( defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG ) ? '' : '.min';

	// Load the theme admin scripts.
	wp_enqueue_script( 'theme-admin-scripts', get_template_directory_uri() . "/assets/js/theme-admin-scripts{$min}.js", array( 'jquery' ), VA_VERSION, true );

	// Load the theme admin stylesheet.
	wp_enqueue_style( 'theme-styles-admin', get_template_directory_uri() . "/assets/css/style-admin{$min}.css", array(), VA_VERSION );

}
add_action( 'admin_enqueue_scripts', 'va_scripts_and_styles_admin' );

/**
 * Build the url for Google fonts we use.
 *
 * @since 4.0.0
 */
function va_google_fonts_url() {

	// Set the default Google fonts we want to use.
	$defaults = array(
		'Lato'   => array(
			'weights' => array( 400, 900 ),
		),
		'Roboto' => array(
			'weights' => array( 400, 500 ),
		),
		'Rock Salt' => '',
	);

	/**
	 * Filters the default Google fonts used.
	 *
	 * @since 4.0.0
	 *
	 * @param array $defaults The default font values.
	 */
	$fonts = apply_filters( 'va_google_font_args', $defaults );

	foreach ( $fonts as $font => $value ) {
		$weight = '';

		if ( isset( $value['weights'] ) ) {
			$weight = implode( ',', $value['weights'] );
		}

		$output     = ( ! empty( $weight ) ) ? ':' . $weight : '';
		$families[] = urlencode( $font . $output );
	}

	return add_query_arg( 'family', implode( '|', $families ), '//fonts.googleapis.com/css' );
}

/**
 * Global text strings we want to access via js.
 *
 * Add any values we want to access via js.
 * Use var AppThemes to access ajaxurl or current_url.
 *
 * @since 4.0.0
 */
function va_theme_scripts_strings() {

	$strings = array(
		'delete_item'        => __( 'Are you sure want to delete this item?', APP_TD ), // Edit user listings delete icon.
		'invalid_image_type' => __( 'Invalid image type.', APP_TD ), // Edit user profile upload cover photo.
		'image_placeholder'  => va_placeholder_img_src(), // Edit user profile upload cover photo.
	);

	/**
	 * Filters the theme script strings.
	 * Ideal for dynamic values and strings that require translation.
	 *
	 * @since 4.0.0
	 *
	 * @param array $strings List of theme script strings.
	 */
	return apply_filters( 'va_theme_scripts_strings', $strings );
}
