<?php
/**
 * WordPress Critic Plugin integration.
 *
 * @url https://marketplace.appthemes.com/plugins/critic/
 *
 * @package Vantage\Integrations
 * @author AppThemes
 * @since 4.0.0
 */

/**
 * Custom actions and filters to use with plugin.
 */
class VA_Critic {

	/**
	 * Constructor
	 */
	public function __construct() {

		if ( ! current_theme_supports( 'critic-plugin' ) ) {
			return;
		}

		add_action( 'va_listing_single_head_actions', array( $this, 'va_submit_review_link' ) );
		add_action( 'va_listing_single_bar_actions',  array( $this, 'va_star_ratings_review_count' ) );
	}

	/**
	 * Display the listing submit review link.
	 *
	 * @since 4.0.0
	 */
	public function va_submit_review_link() {
		global $post;

		// Exit if the post closed the reviews.
		if ( get_post_meta( $post->ID, CRITIC_PSTATUS_KEY, true ) ) {
			return;
		}

		$review_link = '<a href="#respond" class="submit-review-link button">' . __( '<i class="fa fa-star" aria-hidden="true"></i> Write a Review', APP_TD ) . '</a>';

		/**
		 * Filter the submit review link.
		 *
		 * @since 4.0.0
		 *
		 * @param string  $review_link The html review a href link.
		 * @param WP_Post $post Post object.
		 */
		echo apply_filters( 'va_submit_review_link', $review_link, $post );
	}

	/**
	 * Displays the star ratings and total review count.
	 *
	 * @since 4.0.0
	 */
	function va_star_ratings_review_count() {
		global $post;

		$rating = get_post_meta( $post->ID, CRITIC_PAVG_KEY, true );
		$total  = get_post_meta( $post->ID, CRITIC_PVOTE_KEY, true );

		$results = '<div class="critic-rating-result-wrap"><span class="critic-rating-result" data-rating="' . esc_attr( (float) $rating ) . '"></span> <span class="critic-rating-total">(' . number_format( (int) $total ) . ')</span></div>';

		/**
		 * Filter the total rating stars and results html.
		 *
		 * @since 4.0.0
		 *
		 * @param string  $results The html review star rating and total count.
		 * @param int     $rating  The avg star rating number.
		 * @param int     $total   The total number of reviews.
		 * @param WP_Post $post    Post object.
		 */
	 	echo apply_filters( 'va_star_ratings_review_count', $results, $rating, $total, $post );
	}
}

new VA_Critic();
