<?php
/**
 * Business Listing Builder
 *
 * @package Vantage\Listing
 * @author  AppThemes
 * @since   4.0.0
 */

/**
 * Business Listing Builder class
 */
class VA_Business_Listing_Builder extends APP_Post_Listing_Builder {

	/**
	 * Sets up basic listing options.
	 */
	public function set_options() {
		$options  = new APP_Listing_Options( $this->listing );
		$cat      = VA_LISTING_CATEGORY;
		$ptype    = $this->listing->get_type();
		$defaults = array(
			"notify_new_{$ptype}"     => true,
			"notify_renew_{$ptype}"   => true,
			"notify_pending_{$ptype}" => true,
			'features' => array(
//				'multi_plans',
//				'addons',
//				'recurring',
//				"{$cat}_limit",
//				"{$cat}_surcharge",
//				'geocode',
//				'custom_form',
//				'claim',
			),
		);

		$options->set_defaults( $defaults );
		$this->listing->set_options( $options );
	}

	/**
	 * Instantiates a basic listing functional modules if not loaded yet.
	 */
	public function add_modules() {

		$cat = VA_LISTING_CATEGORY;

		if ( $this->listing->options->charge ) {
			$this->listing->add_module( 'payments', 'APP_Listing_Payments' );
		}

		$this->listing->add_module( 'plans',                 'APP_Listing_Plans_Registry' );
		$this->listing->add_module( 'view_process_new',      'VA_View_Process_New', array(), array( 'new', array( 'process_title' => __( 'Create Listing', APP_TD ) ) ) );
		$this->listing->add_module( 'view_process_edit',     'VA_View_Process_Edit', array(), array( 'edit', array( 'process_title' => __( 'Edit Listing', APP_TD ) ) ) );
		$this->listing->add_module( 'view_process_renew',    'VA_View_Process_Renew', array(), array( 'renew', array( 'process_title' => __( 'Renew Listing', APP_TD ) ) ) );
		$this->listing->add_module( 'view_process_upgrade',  'APP_View_Process_Upgrade', array(), array( 'upgrade', array( 'process_title' => __( 'Upgrade Listing', APP_TD ) ) ) );
		$this->listing->add_module( 'step_select_plan',      'APP_Step_Select_Plan' );
		$this->listing->add_module( 'step_current_plan',     'APP_Step_Current_Plan' );
		$this->listing->add_module( 'step_activate',         'APP_Step_Activate' );
		$this->listing->add_module( 'step_upgrade',          'APP_Step_Upgrade' );
		$this->listing->add_module( 'step_moderate',         'APP_Step_Moderate' );
		$this->listing->add_module( 'step_activate_order',   'APP_Step_Activate_Order', array( 'payments' ) );
		$this->listing->add_module( 'step_edit_info',        'VA_Step_Edit_Info' );
		$this->listing->add_module( 'step_edit_info_new',    'APP_Step_Edit_Info_New' );
		$this->listing->add_module( 'step_edit_info_optional', 'APP_Step_Edit_Info_Optional' );
		$this->listing->add_module( 'step_create_order',     'APP_Step_Create_Order', array( 'payments' ) );
		$this->listing->add_module( 'step_upgrade_order',    'APP_Step_Create_Upgrade_Order', array( 'payments' ) );
		$this->listing->add_module( 'step_gateway_select',   'APP_Step_Gateway_Select', array( 'payments' ) );
		$this->listing->add_module( 'step_gateway_process',  'APP_Step_Gateway_Process', array( 'payments' ) );
		$this->listing->add_module( 'expire',                'APP_Listing_Expire' );
		$this->listing->add_module( 'form',                  'VA_Business_Listing_Form' );
		$this->listing->add_module( 'caps',                  'VA_Business_Listing_Caps' );
		$this->listing->add_module( 'details',               'APP_Listing_Details' );
		$this->listing->add_module( 'process_widget',        'APP_Widget_Process_Listing_Button' );

		if ( is_admin() ) {
			$this->listing->add_module( 'settings',          'VA_Business_Listing_Settings' );
			$this->listing->add_module( 'admin_security',    'APP_Listing_Admin_Security' );
		}

		// Optional features.
		$this->listing->add_module(
			'multi_plans',
			'APP_Listing_Plans',
			array( 'plans', 'payments' ),
			array(),
			array(
//				'optional' => true,
//				'label'    => __( 'Multiple Listing Plans', APP_TD ),
			)
		);

		$this->listing->add_module(
			'addons',
			'APP_Listing_Addons',
			array( 'payments' ),
			array(),
			array(
//				'optional' => true,
//				'label'    => __( 'Listing Pricing Addons', APP_TD ),
			)
		);

		$this->listing->add_module(
			'recurring',
			'APP_Listing_Recurring',
			array( 'payments' ),
			array(),
			array(
//				'optional' => true,
//				'label'    => __( 'Recurring Payments', APP_TD ),
			)
		);

		// Following taxonomy-depended modules must have dynamic names, i.e "{$taxonomy}_limit".
		$this->listing->add_module(
			"{$cat}_limit",
			'APP_Listing_Taxonomy_Limit',
			array( 'form' ),
			array( $cat, 'included_categories' ),
			array(
//				'optional' => true,
//				'label'    => __( 'Category Limit', APP_TD ),
			)
		);

		$this->listing->add_module(
			"{$cat}_surcharge",
			'APP_Listing_Taxonomy_Surcharge',
			array( 'payments' ),
			array( $cat ),
			array(
//				'optional' => true,
//				'label'    => __( 'Category Surcharges', APP_TD ),
			)
		);

		$this->listing->add_module(
			'geocode',
			'VA_Business_Listing_Geocode',
			array( 'form' ),
			array(),
			array(
//				'optional' => true,
//				'label'    => __( 'Geocoding', APP_TD ),
			)
		);

		$this->listing->add_module(
			'custom_form',
			'APP_Listing_Custom_Forms',
			array( 'form' ),
			array( $cat ),
			array(
				'optional' => true,
				'label'    => __( 'Custom Forms', APP_TD ),
			)
		);

		$this->listing->add_module(
			'claim',
			'APP_Listing_Claim',
			array(),
			array(),
			array(
//				'optional' => true,
//				'label'    => __( 'Claim Listings', APP_TD ),
			)
		);

		add_filter( 'admin_head',                        array( $this, 'admin_head' ) );
		add_filter( 'post_updated_messages',             array( $this, 'post_updated_messages' ) );
		add_filter( 'query_vars',                        array( $this, 'add_query_vars' ), 0 );
		add_filter( 'appthemes_tinymce_editor_settings', array( $this, 'wp_editor_defaults' ), 10, 2 );
	}

	/**
	 * Registers taxonomies associated with current listing type
	 */
	protected function _register_taxonomies() {
		global $va_options;

		$labels = array(
			'name'                       => _x( 'Listing Categories', 'taxonomy general name', APP_TD ),
			'singular_name'              => _x( 'Listing Category', 'taxonomy singular name', APP_TD ),
			'search_items'               => __( 'Search Listing Categories', APP_TD ),
			'all_items'                  => __( 'All Categories', APP_TD ),
			'parent_item'                => __( 'Parent Listing Category', APP_TD ),
			'parent_item_colon'          => __( 'Parent Listing Category:', APP_TD ),
			'edit_item'                  => __( 'Edit Listing Category', APP_TD ),
			'update_item'                => __( 'Update Listing Category', APP_TD ),
			'add_new_item'               => __( 'Add New Listing Category', APP_TD ),
			'new_item_name'              => __( 'New Listing Category Name', APP_TD ),
			'add_or_remove_items'        => __( 'Add or remove listing categories', APP_TD ),
			'menu_name'                  => _x( 'Categories', 'taxonomy menu name', APP_TD ),
			'popular_items'              => __( 'Popular Listing Categories', APP_TD ),
			'view_item'                  => __( 'View Listing Category', APP_TD ),
			'separate_items_with_commas' => __( 'Separate listing categories with commas', APP_TD ),
			'add_or_remove_items'        => __( 'Add or remove listing categories', APP_TD ),
			'choose_from_most_used'      => __( 'Choose from the most used listing categories', APP_TD ),
			'not_found'                  => __( 'No listing categories found.', APP_TD ),
			'no_terms'                   => __( 'No listing categories', APP_TD ),
			'items_list_navigation'      => __( 'Listing categories list navigation', APP_TD ),
			'items_list'                 => __( 'Listing categories list', APP_TD ),
		);

		$args = array(
			'labels'            => $labels,
			'public'            => true,
			'show_ui'           => true,
			'show_admin_column' => true,
			'show_in_nav_menus' => true,
			'show_tagcloud'     => false,
			'hierarchical'      => true,
			'query_var'         => true,
			'rewrite'           => array(
				'slug'       => $va_options->listing_permalink . '/' . $va_options->listing_cat_permalink,
				'with_front' => false,
			),
		);

		/**
		 * Filter the arguments for registering the listing category taxonomy.
		 *
		 * @since 4.0.0
		 *
		 * @param array $args Array of arguments for registering the taxonomy.
		 */
		$args = apply_filters( 'va_taxonomy_args_' . VA_LISTING_CATEGORY, $args );

		register_taxonomy( VA_LISTING_CATEGORY, VA_LISTING_PTYPE, $args );

		$labels = array(
			'name'                       => _x( 'Listing Tags', 'taxonomy general name', APP_TD ),
			'singular_name'              => _x( 'Listing Tag', 'taxonomy singular name', APP_TD ),
			'search_items'               => __( 'Search Listing Tags', APP_TD ),
			'popular_items'              => __( 'Popular Listing Tags', APP_TD ),
			'all_items'                  => __( 'All Listing Tags', APP_TD ),
			'parent_item'                => __( 'Parent Listing Tag', APP_TD ),
			'parent_item_colon'          => __( 'Parent Listing Tag:', APP_TD ),
			'edit_item'                  => __( 'Edit Listing Tag', APP_TD ),
			'update_item'                => __( 'Update Listing Tag', APP_TD ),
			'add_new_item'               => __( 'Add New Listing Tag', APP_TD ),
			'new_item_name'              => __( 'New Listing Tag Name', APP_TD ),
			'separate_items_with_commas' => __( 'Separate listing tags with commas', APP_TD ),
			'add_or_remove_items'        => __( 'Add or remove listing tags', APP_TD ),
			'choose_from_most_used'      => __( 'Choose from the most used listing tags', APP_TD ),
			'menu_name'                  => _x( 'Tags', 'taxonomy menu name', APP_TD ),
			'view_item'                  => __( 'View Listing Tag', APP_TD ),
			'not_found'                  => __( 'No listing tags found.', APP_TD ),
			'no_terms'                   => __( 'No listing tags', APP_TD ),
			'items_list_navigation'      => __( 'Listing tags list navigation', APP_TD ),
			'items_list'                 => __( 'Listing tags list', APP_TD ),
		);

		$args = array(
			'labels'            => $labels,
			'public'            => true,
			'show_in_nav_menus' => true,
			'show_ui'           => true,
			'show_admin_column' => true,
			'show_tagcloud'     => true,
			'hierarchical'      => false,
			'query_var'         => true,
			'rewrite'           => array(
				'slug'       => $va_options->listing_permalink . '/' . $va_options->listing_tag_permalink,
				'with_front' => false,
			),
		);

		/**
		 * Filter the arguments for registering the listing tag taxonomy.
		 *
		 * @since 4.0.0
		 *
		 * @param array $args Array of arguments for registering the taxonomy.
		 */
		$args = apply_filters( 'va_taxonomy_args_' . VA_LISTING_TAG, $args );

		register_taxonomy( VA_LISTING_TAG, VA_LISTING_PTYPE, $args );
	}

	/**
	 * Registers listing type as post type
	 */
	protected function _register_listing_type() {
		global $va_options;

		$labels = array(
			'name'                  => _x( 'Listings', 'post type general name', APP_TD ),
			'singular_name'         => _x( 'Listing', 'post type singular name', APP_TD ),
			'add_new'               => __( 'Add New', APP_TD ),
			'add_new_item'          => __( 'Add New Listing', APP_TD ),
			'edit_item'             => __( 'Edit Listing', APP_TD ),
			'new_item'              => __( 'New Listing', APP_TD ),
			'view_item'             => __( 'View Listing', APP_TD ),
			'view_items'            => __( 'View Listings', APP_TD ),
			'search_items'          => __( 'Search Listings', APP_TD ),
			'not_found'             => __( 'No listings found.', APP_TD ),
			'not_found_in_trash'    => __( 'No listings found in Trash.', APP_TD ),
			'parent_item_colon'     => __( 'Parent Listing:', APP_TD ),
			'menu_name'             => _x( 'Listings', 'post type menu name', APP_TD ),
			'all_items'             => __( 'All Listings', APP_TD ),
			'archives'              => __( 'Listing Archives', APP_TD ),
			'attributes'            => __( 'Listing Attributes', APP_TD ),
			'insert_into_item'      => __( 'Insert into listing', APP_TD ),
			'uploaded_to_this_item' => __( 'Uploaded to this listing', APP_TD ),
			'featured_image'        => __( 'Featured Image', APP_TD ),
			'set_featured_image'    => __( 'Set featured image', APP_TD ),
			'remove_featured_image' => __( 'Remove featured image', APP_TD ),
			'use_featured_image'    => __( 'Use as featured image', APP_TD ),
			'filter_items_list'     => __( 'Filter listings list', APP_TD ),
			'items_list_navigation' => __( 'Listings list navigation', APP_TD ),
			'items_list'            => __( 'Listings list', APP_TD ),
		);

		$args = array(
			'labels'              => $labels,
			'hierarchical'        => false,
			'supports'            => array( 'title', 'editor', 'author', 'thumbnail', 'comments', 'revisions' ),
			'public'              => true,
			'show_ui'             => true,
			'show_in_menu'        => true,
			'menu_position'       => 6,
			'menu_icon'           => 'dashicons-list-view',
			'show_in_nav_menus'   => false,
			'show_in_admin_bar'   => true,
			'publicly_queryable'  => true,
			'exclude_from_search' => true,
			'has_archive'         => true,
			'query_var'           => true,
			'can_export'          => true,
			'rewrite'             => array(
				'slug'       => $va_options->listing_permalink,
				'with_front' => false,
			),
			'capability_type'     => 'listing',
			'map_meta_cap'        => true,
		);

		if ( current_user_can( 'edit_others_posts' ) ) {
			$args['supports'][] = 'custom-fields';
		}

		/**
		 * Filter the arguments for registering the listing custom post type.
		 *
		 * @since 4.0.0
		 *
		 * @param array $args Array of arguments for registering the custom post type.
		 */
		$args = apply_filters( 'va_post_type_args_' . VA_LISTING_PTYPE, $args );

		register_post_type( VA_LISTING_PTYPE, $args );
	}

	/**
	 * Add a counter bubble for pending listings in the wp-admin sidebar menu.
	 *
	 * @since   4.0.0
	 *
	 * @return  string Html output of the listings wp-admin menu item.
	 */
	public function admin_head() {
		global $menu, $wp_post_types;

		if ( ! current_user_can( 'edit_posts' ) ) {
			return;
		}

		// Get a count array of all listings.
		$listings = wp_count_posts( VA_LISTING_PTYPE, 'readable' );

		if ( ! empty( $menu ) && is_array( $menu ) ) {
			foreach ( $menu as $key => $menu_item ) {
				if ( 0 === strpos( $menu_item[0], $wp_post_types[ VA_LISTING_PTYPE ]->labels->menu_name ) ) {
					if ( $counter = $listings->pending ) {
						$menu[ $key ][0] .= " <span class='awaiting-mod update-plugins count-$counter'><span class='pending-count'>" . number_format_i18n( $listings->pending ) . "</span></span>" ;
					}

					break;
				}
			}
		}
	}

	/**
	 * Callback for WordPress 'post_updated_messages' filter.
	 *
	 * @since 4.0.0
	 *
	 * @param  array $messages The array of messages.
	 * @return array $messages The array of messages.
	 */
	public function post_updated_messages( $messages ) {
		global $post, $post_ID;

    $messages[ VA_LISTING_PTYPE ] = array(
			0  => '', // Unused. Messages start at index 1.
			1  => sprintf( __( 'Listing updated. <a href="%s">View listing</a>', APP_TD ), esc_url( get_permalink( $post_ID ) ) ),
			2  => __( 'Custom field updated.', APP_TD ),
			3  => __( 'Custom field deleted.', APP_TD ),
			4  => __( 'Listing updated.', APP_TD ),
			5  => isset( $_GET['revision'] ) ? sprintf( __( 'Listing restored to revision from %s', APP_TD ), wp_post_revision_title( (int) $_GET['revision'], false ) ) : false,
			6  => sprintf( __( 'Listing published. <a href="%s">View listing</a>', APP_TD ), esc_url( get_permalink( $post_ID ) ) ),
			7  => __( 'Listing saved.', APP_TD ),
			8  => sprintf( __( 'Listing submitted. <a target="_blank" href="%s">Preview listing</a>', APP_TD ), esc_url( add_query_arg( 'preview', 'true', get_permalink( $post_ID ) ) ) ),
			9  => sprintf( __( 'Listing scheduled for: <strong>%1$s</strong>. <a target="_blank" href="%2$s">Preview listing</a>', APP_TD ), date_i18n( __( 'M j, Y @ G:i', APP_TD ), strtotime( $post->post_date ) ), esc_url( get_permalink( $post_ID ) ) ),
			10 => sprintf( __( 'Listing draft updated. <a target="_blank" href="%s">Preview listing</a>', APP_TD ), esc_url( add_query_arg( 'preview', 'true', get_permalink( $post_ID ) ) ) ),
		);

    return $messages;
	}

	/**
	 * Register custom query variables so we can use them.
	 *
	 * @since 4.0.0
	 *
	 * @access public
	 * @return void
	 */
	public function add_query_vars( $vars ) {
		//$vars[] = 'ls';
		return $vars;
	}


	/**
	 * Use custom values if the tinyMCE editor is enabled on front-end listings.
	 *
	 * @since 4.0.0
	 *
	 * @param array  $defaults   Editor default values.
	 * @param string $inst_name  Field instance name.
	 *
	 * @return string Generated html
	 */
	public function wp_editor_defaults( $defaults, $inst_name ) {

		if ( true === $defaults['tinymce'] ) {

			$defaults['tinymce'] = array(
				'resize'                        => true,
				'wordpress_adv_hidden'          => false,
				'add_unload_trigger'            => false,
				'statusbar'                     => true,
				'autoresize_min_height'         => 300,
				'wp_autoresize_on'              => true,
				'paste_as_text'                 => true,
				'paste_auto_cleanup_on_paste'   => true,
				'paste_remove_spans'            => true,
				'paste_remove_styles'           => true,
				'paste_remove_styles_if_webkit' => true,
				'paste_strip_class_attributes'  => true,
				'plugins'                       => 'lists,paste,tabfocus,wordpress,wpautoresize,wplink',
				'toolbar1'                      => 'formatselect,bold,italic,bullist,numlist,blockquote,link,unlink,undo,redo',
				'toolbar2'                      => '',
				'content_css'                   => get_template_directory_uri() . '/assets/css/editor-style.min.css',
			);

		}

		return $defaults;
	}

}
