<?php
/**
 * Business Listing Capabilities submodule
 *
 * @package Vanatge\Listing
 * @author  AppThemes
 * @since   4.0.0
 */

/**
 * Mapping meta capabilities
 */
class VA_Business_Listing_Caps extends APP_Listing_Caps {

	/**
	 * Constructs meta caps mapper
	 *
	 * @param APP_Listing $listing Current Listing module object.
	 */
	public function __construct( APP_Listing $listing ) {
		add_action( 'appthemes_first_run', array( $this, '_add_caps' ) );

		parent::__construct( $listing );
	}

	/**
	 * Adds custom listing type caps to default user roles.
	 *
	 * @global WP_Roles $wp_roles
	 */
	public function _add_caps() {
		global $wp_roles;

		if ( ! isset( $wp_roles ) ) {
			$wp_roles = new WP_Roles();
		}

		$roles = array_keys( $wp_roles->roles );

		foreach ( $roles as $role ) {

			$caps = array(
				'edit_listings',
				'edit_published_listings',
				'delete_listings',
			);

			if ( in_array( $role, array( 'editor', 'administrator' ), true ) ) {
				$caps = array_merge( $caps, array(
					'edit_others_listings',
					'publish_listings',
					'delete_published_listings',
					'delete_others_listings',
				) );
			}

			foreach ( $caps as $cap ) {
				$wp_roles->add_cap( $role, $cap );
			}
		}
	}
}
