<?php
/**
 * Add the geocoding api flag on the system info page.
 *
 * @since 4.0.0
 *
 * @param array $input The fields array for the system info section.
 */
function appthemes_maps_add_system_info_fields( $input ) {

	$input[] = array(
		'title' => __( 'Google Places API', APP_TD ),
		'type'  => 'text',
		'name'  => array( 'system_info', 'google_places_api' ),
		'tip'   => __( "Checks to make sure the Google Places API is working correctly. This is required for the search by location autocomplete feature.", APP_TD ),
		'desc'  => appthemes_maps_places_api_check(),
		'extra' => array(
			'style' => 'display: none;',
		),
	);

	// Set an address to test geocoding against.
	$results = APP_Google_Geocoding::get_geo_data( '1600 Amphitheatre Parkway, Mountain View, CA' );

	// Show checkmark instead of success message.
	if ( ! is_wp_error( $results ) ) {
		$g_msg = '&#10004;';
	} else {
		$g_msg = '<span class="text-error"><span class="dashicons dashicons-warning"></span> ' . $results->get_error_message() . '</span>';
	}

	$input[] = array(
		'title' => __( 'Google Geocoding API', APP_TD ),
		'type'  => 'text',
		'name'  => array( 'system_info', 'google_geocoding_api' ),
		'tip'   => __( "Checks to make sure the Google Geocoding API is working correctly. This is required to geocode new submissions and allow searches by location.", APP_TD ),
		'desc'  => $g_msg,
		'extra' => array(
			'style' => 'display: none;',
		),
	);

	return $input;
}
add_filter( 'appthemes_other_info_default_fields', 'appthemes_maps_add_system_info_fields' );

/**
 * Tests the Google Places API Web Service.
 *
 * @since 4.0.0
 *
 * @return string
 */
function appthemes_maps_places_api_check() {
	global $va_options;

	$response = wp_remote_get( "https://maps.googleapis.com/maps/api/place/autocomplete/json?input=Vict&types=geocode&key={$va_options->google_maps_api_key}" );

	$error = '<span class="text-error"><span class="dashicons dashicons-warning"></span> ' . __( 'ERROR: Cannot connect to the Google Places API.', APP_TD ) . '</span>';

	if ( is_wp_error( $response ) || 200 != wp_remote_retrieve_response_code( $response ) ) {
		return $error;
	}

	$results = json_decode( wp_remote_retrieve_body( $response ), true );

	if ( ! is_array( $results ) ) {
		return $error;
	}

	if ( 'OK' == $results['status'] ) {
		return '&#10004;';
	}

	$msg = isset( $results['error_message'] ) ? $results['error_message'] : '';

	return $results['status'] . ': ' . $msg;
}

/**
 * Sets geo coordinates for post.
 *
 * FALLBACK! to avoid fatal error on using Geo module API.
 *
 * @param int $post_id
 * @param float $lat
 * @param float $lng
 *
 * @return int|bool Boolean false on failure
 */
function appthemes_set_coordinates( $post_id, $lat, $lng ) {
	APP_Google_Geocoding::insert_geo_data( $post_id, 'dummy', array(
		'lat' => $lat,
		'lng' => $lng,
	) );
}
