<?php
/**
 * Schema.org structured data AggregateRating type classes.
 *
 * @package Components\StructuredData\Type
 * @author AppThemes
 * @since 1.0.0
 */

/**
 * Generates the AggregateRating type schema json-ld.
 *
 * @since 1.0.0
 */
class APP_Schema_Type_AggregateRating {

	/**
	 * Generates the AggregateRating schema type json-ld code.
	 *
	 * @link  https://schema.org/AggregateRating
	 *
	 * @since 1.0.0
	 *
	 * @param array  $type The type of comment(s) we want to include.
	 * @param string $meta_key The wp_postmeta key which stores the rating avg value.
	 */
	public static function type( $type = array( 'comment' ), $meta_key = '' ) {
		global $post;

		$reviews = get_comments( array(
			'post_id' => $post->ID,
			'status'  => 'approve',
			'type'    => $type,
			'parent'  => 0,
		) );

		// No reviews found so return.
		if ( 0 === count( $reviews ) ) {
			return;
		}

		// If we don't have a meta key, just set it to zero.
		$rating_avg = ( $meta_key ) ? get_post_meta( $post->ID, $meta_key, true ) : 0;

		$output[] = array(
			'@type'       => 'AggregateRating',
			'bestRating'  => 5,
			'ratingValue' => (float) $rating_avg,
			'worstRating' => 1,
			'ratingCount' => count( $reviews ),
		);

		/**
		 * Filters the AggregateRating type schema properties.
		 *
		 * @since 1.0.0
		 *
		 * @param array $output List of AggregateRating type schema properties.
		 */
		return apply_filters( 'appthemes_schema_type_aggregaterating', $output );
	}
}
