<?php
/**
 * Schema.org structured data BlogPosting type classes.
 *
 * @package Components\StructuredData
 * @author AppThemes
 * @since 1.0.0
 */

/**
 * Generates the BlogPosting type schema json-ld.
 *
 * @since 1.0.0
 */
class APP_Schema_Type_BlogPosting {

	/**
	 * Generates the BlogPosting schema type json-ld code.
	 *
	 * @link  https://schema.org/BlogPosting
	 *
	 * @since 1.0.0
	 */
	public static function type() {
		global $post;

		$output = array(
			'@context'         => 'http://schema.org',
			'@type'            => 'BlogPosting',
			'headline'         => esc_html( $post->post_title ),
			'datePublished'    => get_the_time( DATE_ISO8601, $post->ID ),
			'dateModified'     => get_post_modified_time( DATE_ISO8601, false, $post->ID ),
			'description'      => wp_trim_words( strip_shortcodes( $post->post_content ), 30, null ),
			'commentCount'     => $post->comment_count,
			'mainEntityOfPage' => APP_Schema_Type_WebPage::type(),
			'image'            => APP_Schema_Type_ImageObject::type(), // Required field so call directly.
			'author'           => APP_Schema_Type_Person::type( get_the_author_meta( 'display_name', $post->post_author ) ),
			'publisher'        => APP_Schema_Type_Organization::type(), // Required field so call directly.
		);

		/**
		 * Filters the BlogPosting type schema properties.
		 *
		 * @since 1.0.0
		 *
		 * @param array $output List of BlogPosting type schema properties.
		 */
		return apply_filters( 'appthemes_schema_type_blogposting', $output );
	}
}
