<?php
/**
 * Schema.org structured data Comment type classes.
 *
 * @package Components\StructuredData
 * @author AppThemes
 * @since 1.0.0
 */

/**
 * Generates the Comment type schema json-ld.
 *
 * @since 1.0.0
 */
class APP_Schema_Type_Comment {

	/**
	 * Generates the Comment schema type json-ld code.
	 *
	 * @link  https://schema.org/Comment
	 *
	 * @since 1.0.0
	 */
	public static function type() {
		global $post;

		$comments_per_page = get_option( 'comments_per_page' );

		/**
		 * Filters the comment number to include.
		 *
		 * @since 1.0.0
		 *
		 * @param int $comments_per_page Number of comments to include.
		 */
		$number	= apply_filters( 'appthemes_schema_type_comments_limit', $comments_per_page );

		$comments = get_comments( array(
			'post_id' => $post->ID,
			'number'  => $number,
			'status'  => 'approve',
			'type'    => 'comment',
		) );

		// No comments found so return.
		if ( 0 === count( $comments ) ) {
			return;
		}

		// We've got comments so build the array.
		foreach ( $comments as $comment ) {
			$output[] = array(
				'@type'       => 'Comment',
				'dateCreated' => mysql2date( DATE_ISO8601, $comment->comment_date ),
				'description' => esc_html( $comment->comment_content ),
				'author'      => APP_Schema_Type_Person::type( $comment->comment_author, array( 'url' => $comment->comment_author_url ) ),
				'url'         => esc_url( get_comment_link( $comment->comment_ID ) ),
			);
		}

		/**
		 * Filters the Comment type schema properties.
		 *
		 * @since 1.0.0
		 *
		 * @param array $output List of Comment type schema properties.
		 */
		return apply_filters( 'appthemes_schema_type_comment', $output );
	}
}
