<?php
/**
 * Schema.org structured data GeoCoordinates type classes.
 *
 * @package Components\StructuredData
 * @author AppThemes
 * @since 1.0.0
 */

/**
 * Generates the GeoCoordinates type schema json-ld.
 *
 * @since 1.0.0
 */
class APP_Schema_Type_GeoCoordinates {

	/**
	 * Generates the GeoCoordinates schema type json-ld code.
	 *
	 * @link  https://schema.org/GeoCoordinates
	 *
	 * @since 1.0.0
	 */
	public static function type() {
		global $post;

		// Grab all the geo fields.
		if ( ! is_array( $fields = APP_Google_Geocoding::get_post_meta( $post->ID ) ) ) {
			return;
		}

		$output = array(
			'@type'     => 'GeoCoordinates',
			'latitude'  => $fields['lat'],
			'longitude' => $fields['lng'],
		);

		/**
		 * Filters the GeoCoordinates type schema properties.
		 *
		 * @since 1.0.0
		 *
		 * @param array $output List of GeoCoordinates type schema properties.
		 */
		return apply_filters( 'appthemes_schema_type_geocoordinates', $output );
	}
}
