<?php
/**
 * Schema.org structured data ImageObject type classes.
 *
 * @package Components\StructuredData
 * @author AppThemes
 * @since 1.0.0
 */

/**
 * Generates the ImageObject type schema json-ld.
 *
 * @since 1.0.0
 */
class APP_Schema_Type_ImageObject {

	/**
	 * Generates the ImageObject schema type json-ld code.
	 *
	 * @link https://schema.org/ImageObject
	 *
	 * @since   4.0.0
	 *
	 * @param string $type The type of image we want. 'logo' or defaults to attached image.
	 */
	public static function type( $type = '' ) {
		global $post;

		// Prefill array and error message since ImageObject is a required type.
		$image = array( __( 'No image found', 'critic' ), 0, 0, 0 );

		if ( 'logo' == $type ) :

			$custom_logo_id = get_theme_mod( 'custom_logo' );

			if ( $custom_logo_id ) {
				$image = wp_get_attachment_image_src( $custom_logo_id, 'full' );
			} else {
				// @todo: Add logo upload field in wp-admin.
			}

		else :

			// Figure out which image to get.
			if ( '' != $post->_thumbnail_id ) {
				$image = wp_get_attachment_image_src( $post->_thumbnail_id, 'full' );
			} else {
				// Grab random image attached to post.
				$attachments = new WP_Query( array(
					'post_parent'            => $post->ID,
					'post_type'              => 'attachment',
					'post_status'            => 'inherit',
					'post_mime_type'         => 'image',
					'posts_per_page'         => 1,
					'orderby'                => 'rand',
					'update_post_term_cache' => false,
				) );

				// Get the first image it finds.
				if ( $attachments->have_posts() ) {
					$image = wp_get_attachment_image_src( $attachments->posts[0]->ID, $args['size'] );
				}
			}

		endif;

		// Set the image properties.
		$output = array(
			'@type'  => 'ImageObject',
			'url'    => $image[0],
			'width'  => $image[1],
			'height' => $image[2],
		);

		/**
		 * Filters the ImageObject type schema properties.
		 *
		 * @since 1.0.0
		 *
		 * @param array  $output List of ImageObject type schema properties.
		 * @param string $type The type of image we want. 'logo' or defaults to attached image.
		 */
		return apply_filters( 'appthemes_schema_type_imageobject', $output, $type );
	}
}
