<?php
/**
 * Schema.org structured data LocalBusiness type classes.
 *
 * @package Components\StructuredData
 * @author AppThemes
 * @since 1.0.0
 */

/**
 * Generates the LocalBusiness type schema json-ld.
 *
 * @since 1.0.0
 */
class APP_Schema_Type_LocalBusiness {

	/**
	 * Generates the LocalBusiness schema type json-ld code.
	 *
	 * @link  https://schema.org/LocalBusiness
	 *
	 * @since 1.0.0
	 *
	 * @param string $type A more specific type of LocalBusiness (e.g. Restaurant, CafeOrCoffeeShop, etc)
	 *                    {@link https://schema.org/docs/full.html#LocalBusiness}
	 */
	public static function type( $type = 'LocalBusiness' ) {
		global $post;

		$output = array(
			'@context'    => 'http://schema.org',
			'@type'       => esc_html( $type ),
			'name'        => esc_html( $post->post_title ),
			'url'         => get_permalink( $post->ID ),
			'description' => wp_trim_words( strip_shortcodes( $post->post_content ), 30, null ),
		);

		/**
		 * Filters the LocalBusiness type schema properties.
		 *
		 * @since 1.0.0
		 *
		 * @param array $output List of LocalBusiness type schema properties.
		 */
		return apply_filters( 'appthemes_schema_type_localbusiness', $output );
	}
}
