<?php
/**
 * Schema.org structured data Organization type classes.
 *
 * @package Components\StructuredData
 * @author AppThemes
 * @since 1.0.0
 */

/**
 * Generates the Organization type schema json-ld.
 *
 * @since 1.0.0
 */
class APP_Schema_Type_Organization {

	/**
	 * Generates the Organization schema type json-ld code.
	 *
	 * @link  https://schema.org/Organization
	 *
	 * @since 1.0.0
	 */
	public static function type() {

		$output = array(
			'@type'        => 'Organization',
			'url'          => get_home_url(),
			'name'         => esc_html( get_bloginfo( 'name' ) ),
			'logo'         => APP_Schema_Type_ImageObject::type( 'logo' ),
		);

		/**
		 * Filters the Organization type schema properties.
		 *
		 * @since 1.0.0
		 *
		 * @param array $output List of Organization type schema properties.
		 */
		return apply_filters( 'appthemes_schema_type_organization', $output );
	}
}
