<?php
/**
 * Schema.org structured data Person type classes.
 *
 * @package Components\StructuredData
 * @author AppThemes
 * @since 1.0.0
 */

/**
 * Generates the Person type schema json-ld.
 *
 * @since 1.0.0
 */
class APP_Schema_Type_Person {

	/**
	 * Generates the Person schema type json-ld code.
	 *
	 * @link  https://schema.org/Person
	 *
	 * @since 1.0.0
	 *
	 * @param string $name The person's full name.
	 * @param array  $args Optional. Other valid Person properties to pass in. Default empty array.
	 */
	public static function type( $name, $args = array() ) {
		global $post;

		$defaults = array(
			'@type'    => 'Person',
			'name'     => esc_html( $name ),
		);

		$output = wp_parse_args( $args, $defaults );

		/**
		 * Filters the Person type schema properties.
		 *
		 * @since 1.0.0
		 *
		 * @param array $output List of Person type schema properties.
		 */
		return apply_filters( 'appthemes_schema_type_person', $output );
	}
}
