<?php
/**
 * Schema.org structured data PostalAddress type classes.
 *
 * @package Components\StructuredData
 * @author AppThemes
 * @since 1.0.0
 */

/**
 * Generates the PostalAddress type schema json-ld.
 *
 * @since 1.0.0
 */
class APP_Schema_Type_PostalAddress {

	/**
	 * Generates the PostalAddress schema type json-ld code.
	 *
	 * @link  https://schema.org/PostalAddress
	 *
	 * @since 1.0.0
	 */
	public static function type() {
		global $post;

		// Grab all the geo fields.
		if ( ! is_array( $fields = APP_Google_Geocoding::get_post_meta( $post->ID ) ) ) {
			return;
		}

		$output = array(
			'@type'           => 'PostalAddress',
			'streetAddress'   => $fields['street_number'] . ' ' . $fields['street'],
			'addressLocality' => $fields['city'],
			'addressRegion'   => $fields['state_short'],
			'postalCode'      => $fields['postal_code'],
			'addressCountry'  => $fields['country_short'],
		);

		/**
		 * Filters the PostalAddress type schema properties.
		 *
		 * @since 1.0.0
		 *
		 * @param array $output List of PostalAddress type schema properties.
		 */
		return apply_filters( 'appthemes_schema_type_postaladdress', $output );
	}
}
