<?php
/**
 * Schema.org structured data Product type classes.
 *
 * @package Components\StructuredData
 * @author AppThemes
 * @since 1.0.0
 */

/**
 * Generates the Product type schema json-ld.
 *
 * @since 1.0.0
 */
class APP_Schema_Type_Product {

	/**
	 * Generates the Product schema type json-ld code.
	 *
	 * @link  https://schema.org/Product
	 * @link  https://developers.google.com/schemas/reference/types/Product
	 *
	 * @since 1.0.0
	 */
	public static function type() {
		global $post;

		$output = array(
			'@context'    => 'http://schema.org',
			'@type'       => 'Product',
			'name'        => esc_html( $post->post_title ),
			'url'         => get_permalink( $post->ID ),
			'description' => wp_trim_words( strip_shortcodes( $post->post_content ), 30, null ),
		);

		/**
		 * Filters the Product type schema properties.
		 *
		 * @since 1.0.0
		 *
		 * @param array $output List of Product type schema properties.
		 */
		return apply_filters( 'appthemes_schema_type_product', $output );
	}
}
