<?php
/**
 * Schema.org structured data SearchAction type classes.
 *
 * @package Components\StructuredData
 * @author AppThemes
 * @since 1.0.0
 */

/**
 * Generates the SearchAction type schema json-ld.
 *
 * @since 1.0.0
 */
class APP_Schema_Type_SearchAction {

	/**
	 * Generates the SearchAction schema type json-ld code.
	 *
	 * @link  https://schema.org/SearchAction
	 *
	 * @since 1.0.0
	 */
	public static function type() {

		/**
		 * Filters the search url.
		 *
		 * @since 1.0.0
		 *
		 * @param string $search_url The search URL for this site with a `{search_term_string}` variable.
		 */
		$search_url = apply_filters( 'appthemes_schema_type_search_url', get_home_url() . '?s={search_term_string}' );

		$output = array(
			'@type'       => 'SearchAction',
			'target'      => $search_url,
			'query-input' => 'required name=search_term_string',
		);

		/**
		 * Filters the SearchAction type schema properties.
		 *
		 * @since 1.0.0
		 *
		 * @param array $output List of SearchAction type schema properties.
		 */
		return apply_filters( 'appthemes_schema_type_searchaction', $output );
	}
}
