<?php
/**
 * Main user account functions
 *
 * @package Vantage
 * @since 4.0.0
 */

/**
 * Set up the user contact methods.
 *
 * @since x.0.0
 *
 * @param array $methods Array of contact methods and their labels.
 */
function va_user_contact_methods( $methods ) {

	// Default contact methods were removed in WP 3.6
	// and Vantage doesn't use them anyways.
	$remove = array( 'aim', 'yim', 'jabber' );

	foreach ( $remove as $service ) {
		if ( isset( $methods[ $service ] ) ) {
			unset( $methods[ $service ] );
		}
	}

	$allowed_networks = va_get_allowed_user_networks();

	foreach ( $allowed_networks as $type ) {
		$user_contacts[ $type ] = va_get_social_network_title( $type );
	}

	return $user_contacts;
}
add_action( 'user_contactmethods', 'va_user_contact_methods' );


/**
 * Set the user profile last updated timestamp.
 *
 * @since 4.0.0
 * @param int   $user_id The user that was updated.
 * @param array $old     The profile fields before update.
 */
function va_update_profile_last_update_time( $user_id, $old ) {
	update_user_meta( $user_id, 'last_update', gmdate( 'Y-m-d H:i:s' ) );
}
add_action( 'profile_update', 'va_update_profile_last_update_time', 10, 2 );
