<?php
/**
 * Listings archive page classes.
 *
 * @package Vantage\Views
 * @author AppThemes
 * @since 4.0.0
 */

/**
 * Logic for the listing archive, listing category, and listing tag pages.
 *
 * @since 4.0.0
 */
class VA_Listing_Archive_View extends APP_View {

	/**
	* Determine what page(s) this class should load on.
	*
	* @since  1.0.0
	* @return bool true if successful, false otherwise
	*/
	function condition() {
		return ( is_post_type_archive( VA_LISTING_PTYPE ) && ! is_admin() ) || is_tax( array( VA_LISTING_CATEGORY, VA_LISTING_TAG ) );
	}

	/**
	 * Called after the query variable object is created, but before the actual query is run.
	 *
	 * @since 1.0.0
	 *
	 * @param WP_Query $wp_query The WP_Query instance (passed by reference).
	 */
	function parse_query( $wp_query ) {
		global $va_options;

		$wp_query->set( 'post_type', VA_LISTING_PTYPE );
		$wp_query->set( 'posts_per_page', $va_options->listings_per_page );

		if ( is_tax( VA_LISTING_CATEGORY ) ) {
			$wp_query->set( 'addon_on_top', VA_ITEM_FEATURED_CAT );
		}
	}

	/**
	 * Which page template should load for this view.
	 *
	 * @since  1.0.0
	 *
	 * @param  string $template The path to located template file or null
	 *
	 * @return string The path to located template fallback file or original path
	 */
	function template_include( $template ) {
		if ( 'index.php' == basename( $template ) ) {
			return appthemes_locate_template( 'archive-listing.php' );
		}
		return $template;
	}

	/**
	 * For changing the breadcrumbs trail.
	 *
	 * @since  1.0.0
	 *
	 * @param  string $trail The breacrumb trail.
	 *
	 * @return string $trail The breacrumb trail.
	 */
	function breadcrumbs( $trail ) {
		if ( count( $trail ) > 2 ) {
			unset( $trail[1] );
		}
		return $trail;
	}

}
