<?php
/**
 * User dashboard classes
 *
 * @todo Remove reviews code. Review all methods and clean up.
 *
 * @package Vantage\Views
 * @author AppThemes
 * @since 4.0.0
 */

/**
 * Logic for the user dashboard pages.
 *
 * @since 1.0.0
 */
class VA_User_Dashboard_View extends APP_View {

	private $error;

	function init() {
		$this->handle_form();
		$this->add_rewrite_rules();
	}

	private function handle_form() {
		if ( ! isset( $_POST['action'] ) || 'dashboard-reviews' != $_POST['action'] ) {
			return;
		}

		if ( empty( $_POST ) || ! wp_verify_nonce( $_POST['_wpnonce'], 'va-dashboard-reviews' ) ) {
			//nonce did not verify
			$this->error = __( 'There was an error. Please try again.', APP_TD );
		} else {
			// process form data
			// nonce did verify
			$review = get_comment( $_POST['review_id'] );
			$user_id = get_current_user_id();
			if ( $user_id == $review->user_id ) {
				va_delete_review( $_POST['review_id'] );
				wp_redirect( './?deleted=true' );
				exit();
			} else {
				$this->error = __( 'Cannot delete review, it belongs to another user.', APP_TD );
			}
		}
	}

	private function add_rewrite_rules() {
		global $wp, $va_options;

		// User dashboard
		$wp->add_query_var( 'dashboard' );
		$wp->add_query_var( 'dashboard_author' );

		$dashboard_permalink = $va_options->dashboard_permalink;
		$dashboard_listings_permalink = $va_options->dashboard_listings_permalink;

		$all_permalinks = array(
			$va_options->dashboard_listings_permalink,
			$va_options->dashboard_reviews_permalink,
			$va_options->dashboard_faves_permalink,
			$va_options->dashboard_claimed_permalink,
		);

		$all_permalinks = apply_filters( 'va_dashboard_all_permalinks', $all_permalinks );
		$all_permalinks = array_filter( $all_permalinks );

		$dashboard_all_permalinks = implode( '?|', $all_permalinks );

		// dashboard default permalink

		appthemes_add_rewrite_rule( $dashboard_permalink . '/?$', array(
			'dashboard' => $dashboard_listings_permalink,
			'dashboard_author' => 'self'
		) );

		appthemes_add_rewrite_rule( $dashboard_permalink . '/page/([0-9]+)/?$', array(
			'dashboard' => $dashboard_listings_permalink,
			'dashboard_author' => 'self',
			'paged' => '$matches[1]',
		) );

		// dashboard author (self) permalinks

		appthemes_add_rewrite_rule( $dashboard_permalink . '/(' . $dashboard_all_permalinks . '?)/?$', array(
			'dashboard' => '$matches[1]',
			'dashboard_author' => 'self'
		) );
		appthemes_add_rewrite_rule( $dashboard_permalink . '/(' . $dashboard_all_permalinks . '?)/?page/([0-9]+)/?$', array(
			'dashboard' => '$matches[1]',
			'dashboard_author' => 'self',
			'paged' => '$matches[2]',
		) );

		// dashboard author permalinks

		appthemes_add_rewrite_rule( $dashboard_permalink . '/(' . $dashboard_all_permalinks . '?)/(.*?)/page/([0-9]+)/?$', array(
			'dashboard' => '$matches[1]',
			'dashboard_author' => '$matches[2]',
			'paged' => '$matches[3]',
		) );
		appthemes_add_rewrite_rule( $dashboard_permalink . '/(' . $dashboard_all_permalinks . '?)/(.*?)/?$', array(
			'dashboard' => '$matches[1]',
			'dashboard_author' => '$matches[2]'
		) );

		do_action( strtolower( __CLASS__ . '_' . __FUNCTION__ ) );

	}

	function condition() {
		return (bool) get_query_var( 'dashboard' );
	}

	function template_redirect() {
		global $wp_query;
		$type = va_get_dashboard_type();
		$is_own = va_is_own_dashboard();

		if ( ( 'favorites' === $type ) && ! $is_own ) {
			wp_redirect( home_url() );
		}
		$wp_query->is_home = false;
		$wp_query->is_archive = true;
		$wp_query->is_404 = false;

		if ( get_query_var( 'dashboard_author' ) == 'self' ) {
			appthemes_auth_redirect_login();
		}

		add_filter( 'body_class', array( $this, 'body_class' ), 0 );

		/**
		 * Replaces the wp_title filter (deprecated since 4.4).
		 * New filter passes in array instead of string.
		 */
		add_filter( 'document_title_parts', array( $this, 'title' ), 0 );
	}

	function template_include( $path ) {
		$dashboard_author = va_get_dashboard_author();

		if ( ! $dashboard_author ) {
			return appthemes_locate_template( '404.php' );
		}

		return appthemes_locate_template( 'dashboard-setup.php' );
	}

	function body_class( $classes ) {
		$classes[] = 'va-dashboard';
		$classes[] = 'va-dashboard-' . va_get_dashboard_type();
		if ( va_is_own_dashboard() ) {
			$classes[] = 'va-dashboard-self';
		}

		return $classes;
	}

	function title( $title ) {
		$title['title'] = va_get_dashboard_name();
		return $title;
	}

	function breadcrumbs( $trail ) {
		array_pop( $trail );
		$trail[] = $this->title();

		return $trail;
	}

	function notices() {
		if ( ! empty( $this->error ) ) {
			appthemes_display_notice( 'success-pending', $this->error );
		} elseif ( isset( $_GET['deleted'] ) ) {
			appthemes_display_notice( 'success', __( 'Review deleted.', APP_TD ) );
		}
	}
}
