<?php
/**
 * Widget for home page callout.
 *
 * @package Vantage\Widgets
 * @author AppThemes
 * @since 4.0.0
 */

/**
 * Callout content widget class
 */
class VA_Widget_Callout_Box extends VA_Widget {

	/**
	 * Constructor
	 *
	 * @param array $args Predefined widget arguments.
	 */
	public function __construct( $args = array() ) {

		$default_args = array(
			'id_base'        => 'va_widget_callout_box',
			'name'           => __( 'Vantage - Page Callout Box', APP_TD ),
			'defaults'       => array(
				'header'              => '',
				'content'             => '',
				'text_align'          => 'center',
				'text_color'          => '#565656',
				'text_padding'        => '10',
				'image'               => '',
				'background'          => 'pull',
				'background_position' => 'center center',
				'background_color'    => '#ffffff',
			),
			'widget_ops'     => array(
				'description' => __( 'Display a full-width callout', APP_TD ),
			),
			'control_options' => array( 'width' => 400 ),
		);

		$args = $this->_array_merge_recursive( $default_args, $args );

		parent::__construct( $args['id_base'], $args['name'], $args['widget_ops'], $args['control_options'], $args['defaults'] );
	}

	/**
	 * Retrieves form fields in scbForm format.
	 *
	 * @return array Form fields array.
	 */
	protected function form_fields() {
		return array(
			array(
				'type' => 'text',
				'name' => 'header',
				'desc' => __( 'Title:', APP_TD ),
			),
			array(
				'type'     => 'textarea',
				'name'     => 'content',
				'extra'    => "style='width: 100%' rows='5'",
				'desc'     => __( 'Content:', APP_TD ),
				'sanitize' => array( $this, 'sanitize' ),
			),
			array(
				'type'	  => 'select',
				'name'	  => 'text_align',
				'choices' => array(
					'left'   => __( 'Left', APP_TD ),
					'center' => __( 'Center', APP_TD ),
					'right'  => __( 'Right', APP_TD ),
				),
				'extra'	  => array( 'class' => 'widefat' ),
				'desc'	  => __( 'Text Align:', APP_TD ),
			),
			array(
				'type'  => 'colorpicker',
				'name'  => 'text_color',
				'desc'  => __( 'Text Color:', APP_TD ),
				'extra' => array(
					'data-default-color' => '#565656',
					'class'              => 'color-picker-hex',
				),
			),
			array(
				'type'  => 'number',
				'name'  => 'text_padding',
				'desc'  => __( 'Padding:', APP_TD ),
				'extra' => array(
					'class' => 'widefat',
				),
			),
			array(
				'type'   => 'custom',
				'name'   => 'image',
				'render' => array( $this, '_image_control' ),
				'desc'   => __( 'Background Image:', APP_TD ),
			),
			array(
				'type'	  => 'select',
				'name'	  => 'background',
				'choices' => array(
					'cover' => __( 'Cover', APP_TD ),
					'pull'  => __( 'Pull Out', APP_TD ),
				),
				'extra'	  => array( 'class' => 'widefat' ),
				'desc'	  => __( 'Style:', APP_TD ),
			),
			array(
				'type'	  => 'select',
				'name'	  => 'background_position',
				'choices' => array(
					'left top'      => __( 'Left Top', APP_TD ),
					'left center'   => __( 'Left Center', APP_TD ),
					'left bottom'   => __( 'Left Bottom', APP_TD ),
					'right top'     => __( 'Right Top', APP_TD ),
					'right center'  => __( 'Right Center', APP_TD ),
					'right bottom'  => __( 'Right Bottom', APP_TD ),
					'center top'    => __( 'Center Top', APP_TD ),
					'center center' => __( 'Center Center', APP_TD ),
					'center bottom' => __( 'Center Bottom', APP_TD ),
					'center top'    => __( 'Center Top', APP_TD ),
				),
				'extra'	  => array( 'class' => 'widefat' ),
				'desc'	  => __( 'Position:', APP_TD ),
			),
			array(
				'type'  => 'colorpicker',
				'name'  => 'background_color',
				'desc'  => __( 'Background Color:', APP_TD ),
				'extra' => array(
					'data-default-color' => '#ffffff',
					'class'              => 'color-picker-hex',
				),
			),
		);
	}

	/**
	 * Custom content sanitizer.
	 *
	 * @param string $text Original text.
	 *
	 * @return string Sanitized text.
	 */
	public function sanitize( $text ) {
		if ( ! current_user_can( 'unfiltered_html' ) ) {
			$text = wp_kses_post( $text );
		}

		return $text;
	}

	/**
	 * This is where the actual widget content goes.
	 *
	 * @param array $instance The settings for the particular instance of the
	 * widget.
	 */
	public function content( $instance ) {
		global $wp_query;

		if ( 'right' === $instance['text_align'] ) {
			$instance['text_align'] = 'medium-6 pull-right';
		} elseif ( 'center' === $instance['text_align'] ) {
			$instance['text_align'] = 'text-center';
		} else {
			$instance['text_align'] = 'medium-6';
		}

		$instance['has_image'] = '';

		if ( $instance['image'] ) {
			$instance['image_css'] = 'background-image:url("' . $instance['image'] . '"); background-size:cover; background-position:' . $instance['background_color'] . ';';
			$instance['has_image'] = 'has-image';
		} ?>

		<style>#<?php echo esc_attr( $this->id ) ?> .callout-wrap a { text-decoration: underline; color: <?php echo esc_attr( $instance['text_color'] ); ?>}</style>

		<?php

		// Safely set query var.
		$wp_query->set( 'instance', $instance );
		appthemes_get_template_part( 'parts/widget', 'callout-box' );
	}
}
