<?php
/**
 * Widget for featured listings.
 *
 * @package Vantage\Widgets
 * @author AppThemes
 * @since 4.0.0
 */

/**
 * Featured listings widget class.
 */
class VA_Widget_Listing_Featured extends VA_Widget_Listing_Latest {

	/**
	 * Constructor
	 *
	 * @param array $args Predefined widget arguments.
	 */
	public function __construct( $args = array() ) {
		$default_args = array(
			'id_base'         => 'va_widget_listing_featured',
			'name'            => __( 'Vantage - Home Featured Listings', APP_TD ),
			'defaults'        => array(
				'header'      => __( 'Featured Listings', APP_TD ),
				'limit'       => 6,
				'description' => __( 'Check out our featured listings', APP_TD ),
			),
			'widget_ops'      => array(
				'description' => __( 'Display your featured listings.', APP_TD ),
			),
			'control_options' => array(),
		);

		$args = $this->_array_merge_recursive( $default_args, $args );

		parent::__construct( $args );
	}

	/**
	 * Retrieves a query arg array to get specific list of items.
	 *
	 * Query featured listings in random order.
	 *
	 * On the Front page displays listings with VA_ITEM_FEATURED_HOME meta, on
	 * the Category page - listings with VA_ITEM_FEATURED_CAT meta.
	 *
	 * Sets Query var 'addon', which used in appthemes_addon_query_filter().
	 *
	 * @param array $instance The settings for the particular instance of the
	 *                         widget.
	 *
	 * @return array Query args array.
	 */
	protected function get_query_args( $instance ) {

		$addon    = ( is_tax( VA_LISTING_CATEGORY ) ) ? VA_ITEM_FEATURED_CAT : VA_ITEM_FEATURED_HOME;
		$instance = array_merge( $this->defaults, (array) $instance );

		return array(
			'post_type'           => VA_LISTING_PTYPE,
			'posts_per_page'      => absint( $instance['limit'] ),
			'ignore_sticky_posts' => true,
			'addon'               => $addon,
			'orderby'             => 'rand',
		);
	}

	/**
	 * This is where the actual widget content goes.
	 *
	 * @param array $instance The settings for the particular instance of the
	 * widget.
	 */
	public function content( $instance ) {
		global $wp_query;

		// Safely set query var.
		$wp_query->set( 'instance', $instance );
		appthemes_get_template_part( 'parts/widget-featured', VA_LISTING_PTYPE );
	}
}
