<?php
/**
 * Widget for latest listings.
 *
 * @package Vantage\Widgets
 * @author AppThemes
 * @since 4.0.0
 */

/**
 * Latest listings widget class.
 */
class VA_Widget_Listing_Latest extends VA_Widget {

	/**
	 * Constructor
	 *
	 * @param array $args Predefined widget arguments.
	 */
	public function __construct( $args = array() ) {
		$default_args = array(
			'id_base'         => 'va_widget_listing_latest',
			'name'            => __( 'Vantage - Home Latest Listings', APP_TD ),
			'defaults'        => array(
				'header'      => __( 'Latest Listings', APP_TD ),
				'limit'       => 6,
				'description' => __( 'Check out our newest listings', APP_TD ),
			),
			'widget_ops'      => array(
				'description' => __( 'Display your latest listings.', APP_TD ),
			),
			'control_options' => array(),
		);

		$args = $this->_array_merge_recursive( $default_args, $args );

		parent::__construct( $args['id_base'], $args['name'], $args['widget_ops'], $args['control_options'], $args['defaults'] );
	}

	/**
	 * Retrieves form fields in scbForm format.
	 *
	 * @return array Form fields array.
	 */
	protected function form_fields() {
		return array(
			array(
				'type' => 'text',
				'name' => 'header',
				'desc' => __( 'Title:', APP_TD ),
			),
			array(
				'type' => 'text',
				'name' => 'description',
				'desc' => __( 'Description:', APP_TD ),
			),
			array(
				'type'  => 'number',
				'name'  => 'limit',
				'desc'  => __( 'Number to show:', APP_TD ),
				'extra' => array(
					'class' => 'widefat',
					'min'   => 3,
					'max'   => 30,
					'step'  => 3,
				),
			),
		);
	}

	/**
	 * Retrieves a query arg array to get specific list of items
	 *
	 * @param array $instance The settings for the particular instance of the
	 *                         widget.
	 *
	 * @return array Query args array.
	 */
	protected function get_query_args( $instance ) {

		$instance = array_merge( $this->defaults, (array) $instance );

		return array(
			'post_type'           => VA_LISTING_PTYPE,
			'posts_per_page'      => absint( $instance['limit'] ),
			'ignore_sticky_posts' => true,
		);
	}

	/**
	 * Echo the widget content.
	 *
	 * @see WP_Widget
	 * @access public
	 *
	 * @param array $args     Display arguments including before_title, after_title,
	 *                        before_widget, and after_widget.
	 * @param array $instance The settings for the particular instance of the widget.
	 */
	function widget( $args, $instance ) {

		// Query the database.
		$items = new WP_Query( $this->get_query_args( $instance ) );

		if ( ! $items->post_count ) {
			wp_reset_postdata();
			return;
		}

		$instance['items']        = $items;
		$instance['before_title'] = $args['before_title'];
		$instance['after_title']  = $args['after_title'];

		parent::widget( $args, $instance );

		wp_reset_postdata();
	}

	/**
	 * This is where the actual widget content goes.
	 *
	 * @param array $instance The settings for the particular instance of the
	 * widget.
	 */
	public function content( $instance ) {
		global $wp_query;

		// Safely set query var.
		$wp_query->set( 'instance', $instance );
		appthemes_get_template_part( 'parts/widget-latest', VA_LISTING_PTYPE );

		echo '<p class="view-more-listings"><a href="' . esc_url( get_post_type_archive_link( VA_LISTING_PTYPE ) ) . '" class="hollow button">' . esc_html__( 'View More Listings', APP_TD ) . '</a></p>';
	}
}
