<?php
/**
 * Widget for single listing map.
 *
 * @package Vantage\Widgets
 * @author AppThemes
 * @since 4.0.0
 */

/**
 * Listing map widget class.
 *
 * @todo Migrate to new widget maps code.
 */
class VA_Widget_Listing_Map extends VA_Widget {

	/**
	 * Constructor
	 *
	 * @param array $args Predefined widget arguments.
	 */
	public function __construct( $args = array() ) {
		$default_args = array(
			'id_base'         => 'va_widget_listing_map',
			'name'            => __( 'Vantage - Single Listing Map &amp; Contact Info', APP_TD ),
			'defaults'        => array(
				'title'      => '',
				'address'    => true,
				'phone'      => true,
				'website'    => true,
				'email'      => true,
				'directions' => true,
				'social'     => true,
			),
			'widget_ops'      => array(
				'description' => __( 'Display the listing map and contact info.', APP_TD ),
			),
			'control_options' => array(),
		);

		$args = $this->_array_merge_recursive( $default_args, $args );

		parent::__construct( $args['id_base'], $args['name'], $args['widget_ops'], $args['control_options'], $args['defaults'] );
	}

	/**
	 * Retrieves form fields in scbForm format.
	 *
	 * @return array Form fields array.
	 */
	protected function form_fields() {
		return array(
			array(
				'type' => 'text',
				'name' => 'title',
				'desc' => __( 'Title:', APP_TD ),
			),
			array(
				'type' => 'checkbox',
				'name' => 'address',
				'desc' => __( 'Show Address', APP_TD ),
			),
			array(
				'type' => 'checkbox',
				'name' => 'phone',
				'desc' => __( 'Show Phone Number', APP_TD ),
			),
			array(
				'type' => 'checkbox',
				'name' => 'website',
				'desc' => __( 'Show Website URL', APP_TD ),
			),
			array(
				'type' => 'checkbox',
				'name' => 'email',
				'desc' => __( 'Show Email', APP_TD ),
			),
			array(
				'type' => 'checkbox',
				'name' => 'directions',
				'desc' => __( 'Show "Get Directions"', APP_TD ),
			),
			array(
				'type' => 'checkbox',
				'name' => 'social',
				'desc' => __( 'Show Social Networks', APP_TD ),
			),
		);
	}

	/**
	 * Echo the widget content.
	 *
	 * @param array $args     Display arguments including before_title, after_title,
	 *                        before_widget, and after_widget.
	 * @param array $instance The settings for the particular instance of the widget.
	 */
	function widget( $args, $instance ) {

		// Only allow this widget on the single listing page.
		if ( ! is_singular( VA_LISTING_PTYPE ) ) {
			return;
		}

		parent::widget( $args, $instance );
	}

	/**
	 * This is where the actual widget content goes.
	 *
	 * @param array $instance The settings for the particular instance of the
	 * widget.
	 */
	public function content( $instance ) {
		global $wp_query;

		$is_geo_coded = false;
		$geo_values = array();

		if ( class_exists( 'APP_Google_Geocoding' ) ) {
			$geo_values = APP_Google_Geocoding::get_post_meta( get_the_ID() );
		}

		// Make sure we've got coordinates to work with.
		if ( ! empty( $geo_values['lat'] ) && ! empty( $geo_values['lng'] ) ) {
			$is_geo_coded = true;
			$address_link = '<a href="' . esc_url( 'https://maps.google.com/maps/place//@' . $geo_values['lat'] . ',' . $geo_values['lng'] . ',16z' ) . '" target="_blank" rel="nofollow">' . the_listing_address() . '</a>';
		} else {
			$address_link = the_listing_address();
		}

		$instance['geo_values'] = $geo_values;
		$instance['address_link'] = $address_link;
		$instance['is_geo_coded'] = $is_geo_coded;

		// Safely set query var.
		$wp_query->set( 'instance', $instance );
		appthemes_get_template_part( 'parts/widget', 'listing-map' );
	}
}
