<?php
/**
 * Widget for single listing image modal gallery.
 *
 * @package Vantage\Widgets
 * @author AppThemes
 * @since 4.0.0
 */

/**
 * Listing gallery widget class.
 */
class VA_Widget_Listing_Reveal_Gallery extends VA_Widget {

	/**
	 * Constructor
	 *
	 * @param array $args Predefined widget arguments.
	 */
	public function __construct( $args = array() ) {
		$default_args = array(
			'id_base'        => 'va_widget_listing_reveal_gallery',
			'name'           => __( 'Vantage - Single Listing Photo Gallery', APP_TD ),
			'defaults'       => array(
				'title' => __( 'Photo Gallery', APP_TD ),
			),
			'widget_ops'     => array(
				'description' => __( 'Display the listing photo gallery.', APP_TD ),
			),
			'control_options' => array(),
		);

		$args = $this->_array_merge_recursive( $default_args, $args );

		parent::__construct( $args['id_base'], $args['name'], $args['widget_ops'], $args['control_options'], $args['defaults'] );
	}

	/**
	 * Echo the widget content.
	 *
	 * @see WP_Widget
	 * @access public
	 *
	 * @param array $args     Display arguments including before_title, after_title,
	 *                        before_widget, and after_widget.
	 * @param array $instance The settings for the particular instance of the widget.
	 */
	function widget( $args, $instance ) {
		global $post;

		// Pass in a gallery array of IDs otherwise query images attached to the post.
		if ( ! empty( $gallery ) ) { // ?.
			$extra_args = array(
				'post__in' => $gallery,
			);
		} else {
			$extra_args = array(
				'post_parent' => $post->ID,
			);
		}

		// Exclude the featured image since it's the hero background.
		$featured_id = get_post_thumbnail_id( $post->ID );

		$default_args = array(
			'post_type'      => 'attachment',
			'post_mime_type' => 'image',
			'post_status'    => 'inherit',
			'posts_per_page' => -1,
			'order'          => 'ASC',
			'orderby'        => 'menu_order',
			'post__not_in'   => array( $featured_id ),
		);

		$query_args = array_merge( $default_args, $extra_args );
		$images     = new WP_Query( $query_args );

		// Don't show the widget if no images exist.
		if ( ! $images->post_count ) {
			return;
		}

		$instance['query'] = $images;

		parent::widget( $args, $instance );
	}

	/**
	 * This is where the actual widget content goes.
	 *
	 * @param array $instance The settings for the particular instance of the
	 * widget.
	 */
	public function content( $instance ) {
		global $wp_query;

		// Safely set query var.
		$wp_query->set( 'instance', $instance );
		appthemes_get_template_part( 'parts/widget', 'listing-reveal-gallery' );
	}
}
