<?php
/**
 * Widget for latest blog posts.
 *
 * @package Vantage\Widgets
 * @author AppThemes
 * @since 4.0.0
 */

/**
 * Latest blog posts widget class.
 */
class VA_Widget_Post_Latest extends VA_Widget_Listing_Latest {

	/**
	 * Constructor
	 *
	 * @param array $args Predefined widget arguments.
	 */
	public function __construct( $args = array() ) {
		$default_args = array(
			'id_base'         => 'va_widget_post_latest',
			'name'            => __( 'Vantage - Home Latest Blog Posts', APP_TD ),
			'defaults'        => array(
				'header'      => __( 'From the Blog', APP_TD ),
				'limit'       => 3,
				'description' => __( 'Check out our newest articles', APP_TD ),
			),
			'widget_ops'      => array(
				'description' => __( 'Display your latest blog posts.', APP_TD ),
			),
			'control_options' => array(),
		);

		$args = $this->_array_merge_recursive( $default_args, $args );

		parent::__construct( $args );
	}

	/**
	 * Retrieves a query arg array to get specific list of items
	 *
	 * @param array $instance The settings for the particular instance of the
	 *                         widget.
	 *
	 * @return array Query args array.
	 */
	protected function get_query_args( $instance ) {
		return array(
			'post_type'           => 'post',
			'posts_per_page'      => absint( $instance['limit'] ),
			'ignore_sticky_posts' => true,
		);
	}

	/**
	 * This is where the actual widget content goes.
	 *
	 * @param array $instance The settings for the particular instance of the
	 * widget.
	 */
	public function content( $instance ) {
		global $wp_query;

		// Safely set query var.
		$wp_query->set( 'instance', $instance );
		appthemes_get_template_part( 'parts/widget-latest', 'post' );
	}
}
