<?php
/**
 * The template for displaying dashboard listings
 *
 * @package Vantage\Templates
 *
 * @since 4.0.0
 */

	$args = apply_filters( 'va_get_dashboard_listings_args', array(
		'post_type'           => VA_LISTING_PTYPE,
		'post_status'         => array_keys( va_public_listing_statuses() ),
		'ignore_sticky_posts' => 1,
		'posts_per_page'      => 25,
		'offset'              => ( max( 1, get_query_var( 'paged' ) ) - 1 ) * 25,
		'orderby'             => 'date',
		'order'               => 'desc',
		'author'              => get_current_user_id(),
	) );

	$listings_query = new WP_Query( $args );

	$listings = $listings_query->get_posts();

	$dashboard_columns = apply_filters( 'va_dashboard_listings_columns', array(
		'listing_title' => __( 'Title', APP_TD ),
		'listed'        => __( 'Listed', APP_TD ),
		'expires'       => __( 'Expires', APP_TD ),
		'actions'       => __( 'Actions', APP_TD ),
	) );
	?>

	<h3 class="widget-title"><?php echo $title; ?></h3>

	<?php
	$pending_claimed = va_count_user_listing_status( 'pending-claimed' );

	if ( 0 > $pending_claimed ) {
		echo '<div class="callout warning"><p>';
		printf( __( 'You have <a href="%1s">%2s</a> pending claimed listing(s).', APP_TD ), va_dashboard_url( 'claimed-listings', get_current_user_id(), true ), number_format_i18n( $pending_claimed ) );
		echo '</p></div>';
	}
	?>

	<div class="content-wrap dashboard-listings">

		<div class="content-inner">

			<table class="table-plain table-bootstrap">
				<thead>
					<tr>
						<?php foreach ( $dashboard_columns as $key => $column ) : ?>
							<th class="<?php echo esc_attr( $key ); ?>"><?php echo esc_html( $column ); ?></th>
						<?php endforeach; ?>
					</tr>
				</thead>

			  <tbody>
			  	<?php if ( ! $listings ) : ?>
						<tr>
							<td colspan="10"><?php _e( 'You do not have any listings.', APP_TD ); ?></td>
						</tr>
					<?php else : ?>

						<?php foreach ( $listings as $listing ) : ?>

							<tr class="listing-row" data-id="<?php echo esc_attr( $listing->ID ); ?>" data-nonce="<?php echo esc_attr( wp_create_nonce( "vantage_delete_listing_$listing->ID" ) ); ?>">
								<?php foreach ( $dashboard_columns as $key => $column ) : ?>

									<td class="<?php echo esc_attr( $key ); ?>">
										<?php if ( 'listing_title' === $key ) : ?>
											<?php if ( 'publish' == $listing->post_status ) : ?>
												<a href="<?php echo get_permalink( $listing->ID ); ?>" target="_blank"><?php echo $listing->post_title; ?></a>
											<?php else : ?>
												<?php echo $listing->post_title; ?>
											<?php endif; ?>
											<span class="label"><?php echo va_get_dashboard_verbiage( $listing->post_status ); ?></span>

											<?php if ( get_post_meta( $listing->ID, 'claimee', true ) ) : ?>
												<span data-tooltip aria-haspopup="true" class="has-tip top renew-icon-wrap" data-disable-hover="false" title="<?php esc_attr_e( sprintf( __( 'Listing claimed on %s', APP_TD ), appthemes_display_date( get_post_meta( $listing->ID, 'claimee_request_date', true ) ) ) ); ?>"><i class="fa fa-check-circle-o" aria-hidden="true"></i></span>
											<?php endif; ?>

										<?php elseif ( 'listed' === $key ) : ?>
											<?php echo date_i18n( get_option( 'date_format' ), strtotime( $listing->post_date ) ); ?>
										<?php elseif ( 'expires' === $key ) : ?>
											<?php echo va_get_expire_date( $listing ); ?>
											<?php if ( $recur = va_get_recurring_date( $listing->ID ) ) : ?>
												<span data-tooltip aria-haspopup="true" class="has-tip top renew-icon-wrap" data-disable-hover="false" title="<?php esc_attr_e( sprintf( __( ' Automatically renews on %s', APP_TD ), $recur ) ); ?>"><i class="fa fa-refresh btn-sm" aria-hidden="true"></i></span>
											<?php endif; ?>
										<?php elseif ( 'actions' === $key ) : ?>
											<ul class="list-inline dashboard-actions">
												<li>
													<a href="<?php echo esc_url( va_get_listing_edit_url( $listing->ID ) ); ?>" class="btn btn-white btn-sm" title="<?php esc_attr_e( __( 'Edit', APP_TD ) ); ?>"><i class="fa fa-pencil" aria-hidden="true"></i></a>
												</li>
												<?php
												$listing_renew_url = va_get_listing_renew_url( $listing->ID );
												if ( $listing_renew_url ) :
												?>
												<li>
													<a href="<?php echo esc_url( $listing_renew_url ); ?>" class="btn btn-white btn-sm" title="<?php esc_attr_e( __( 'Renew', APP_TD ) ); ?>"><i class="fa fa-repeat" aria-hidden="true"></i></a>
												</li>
											<?php endif; ?>
												<li>
													<a href="#" class="btn btn-white btn-sm listing-delete-link" title="<?php esc_attr_e( __( 'Delete', APP_TD ) ); ?>"><i class="fa fa-trash-o" aria-hidden="true"></i></a>
												</li>
											</ul>
										<?php else : ?>
											<?php do_action( 'va_dashboard_listings_column_' . $key, $listing ); ?>
										<?php endif; ?>
									</td>

								<?php endforeach; ?>

							</tr>

						<?php endforeach; ?>

					<?php endif; ?>

				</tbody>
			</table>

			<?php
			va_the_pagination( $listings_query );

			// Reset post data.
			wp_reset_postdata();
			?>

		</div><!-- .content-inner -->

	</div><!-- .content-wrap -->
