<?php
/**
 * Template for displaying Current Plan Form.
 *
 * @package Vantage\Listing\Templates
 * @author  AppThemes
 * @since   4.0.0
 */

/* @var $plan APP_Listing_Current_Plan_I */
?>

<div class="section-head">
	<?php if ( $step = appthemes_get_checkout() ) { ?>
		<h1><?php echo esc_html( $step->get_data( 'title' ) ); ?></h1>
	<?php }  ?>
</div>

<?php
if ( empty( $plans ) ) :
	echo '<p>' . __( 'No plans are available.', APP_TD ) . '</p>';
else :
?>

	<form id="<?php echo esc_attr( "{$nonce_check}-{$action_check}" );?>" class="app-form <?php echo esc_attr( $form_class );?>" enctype="multipart/form-data" method="post" action="<?php echo esc_attr( $action_url ); ?>">

		<?php wp_nonce_field( $nonce_check, $action_check ); ?>

		<fieldset class="fieldset">

			<table class="table-plain table-listing-plans">
				<tbody>

					<?php foreach ( $plans as $key => $plan ) : ?>

						<tr class="plan-option" id="plan-<?php esc_attr_e( $plan->get_type() ); ?>">

							<input type="hidden" name="plan" value="<?php esc_attr_e( $plan->get_type() ); ?>"/>

							<td class="plan-details">

								<h4><?php echo $plan->get_title(); ?> <span class="label"><?php _e( 'Active Subscription', APP_TD ); ?></span></h4>

								<div class="plan-description">
									<?php echo $plan->get_description(); ?>
								</div>

								<div class="plan-info">
									<?php do_action( 'appthemes_purchase_plan_fields', $plan ); ?>
								</div>

							</td>

							<td class="plan-costs text-right">
								<h5>
									<span class="plan-duration"><?php echo $plan->get_period_text(); ?></span>
								</h5>

								<div class="plan-addons">

									<?php if ( $plan->has_options() ) : ?>

										<button class="small dropdown button" type="button" data-toggle="plan-<?php esc_attr_e( $plan->get_type() ); ?>-addon-dropdown"><?php _e( 'Extras', APP_TD ); ?></button>
										<div class="dropdown-pane" id="plan-<?php esc_attr_e( $plan->get_type() ); ?>-addon-dropdown" data-dropdown data-auto-focus="true" data-close-on-click="true">
											<?php $plan->render(); ?>
										</div><!-- .dropdown-pane -->

									<?php endif; ?>

								</div><!-- .plan-addons-->

							</td>

						</tr>

					<?php endforeach; ?>


				</tbody>
			</table>

			<?php
			if ( ! empty( $plans ) && $plan->is_upgradable() ) {
				/**
				 * Fires after the listing plans.
				 *
				 * @since 1.0.0
				 */
				do_action( 'appthemes_purchase_fields' );


				/**
				 * Fires after the listing plans.
				 *
				 * @since 4.0.0
				 */
				do_action( 'appthemes_after_plans_list' );
			} ?>

		</fieldset>

		<?php if ( ! empty( $plans ) && $plan->is_upgradable() ) { ?>

			<input type="submit" class="button primary" value="<?php echo esc_attr( $action_text ); ?>">

		<?php } ?>

	</form>

<?php endif; ?>
